@@ -29,7 +29,7 @@
 #include "tapepreferencesconfigurationpage.h"
 #include "ui_tapepreferencesconfigurationpage.h"
 #include "../../mapplication.h"
-#include "../vmisc/vtapesettings.h"
+#include "../../vtapesettings.h"
 #include "../vpatterndb/variables/vmeasurement.h"
 #include "../vpatterndb/pmsystems.h"
 
@@ -87,6 +87,10 @@ TapePreferencesConfigurationPage::TapePreferencesConfigurationPage(QWidget *pare
 
     //----------------------- Toolbar
     ui->toolBarStyleCheck->setChecked(MApplication::VApp()->TapeSettings()->GetToolBarStyle());
+
+    //----------------------- Update
+    ui->checkBoxAutomaticallyCheckUpdates->setChecked(
+                MApplication::VApp()->TapeSettings()->IsAutomaticallyCheckUpdates());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -133,6 +137,11 @@ QStringList TapePreferencesConfigurationPage::Apply()
         MApplication::VApp()->RetranslateGroups();
     }
 
+    if (settings->IsAutomaticallyCheckUpdates() != ui->checkBoxAutomaticallyCheckUpdates->isChecked())
+    {
+        settings->SetAutomaticallyCheckUpdates(ui->checkBoxAutomaticallyCheckUpdates->isChecked());
+    }
+
     return preferences;
 }
 
