@@ -39,6 +39,7 @@
 #include "../vmisc/qt_dispatch/qt_dispatch.h"
 #include "../qmuparser/qmuparsererror.h"
 #include "../vpatterndb/variables/vmeasurement.h"
+#include "../fervor/fvupdater.h"
 
 #include <QDir>
 #include <QFileOpenEvent>
@@ -382,7 +383,7 @@ bool MApplication::IsTestMode() const
  */
 bool MApplication::IsAppInGUIMode() const
 {
-    return IsTestMode();
+    return not IsTestMode();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -436,8 +437,9 @@ void MApplication::InitOptions()
     ActivateDarkMode();
     QResource::registerResource(diagramsPath());
 }
-// Dark mode
 
+//---------------------------------------------------------------------------------------------------------------------
+// Dark mode
 void MApplication::ActivateDarkMode()
 {
     VTapeSettings *settings = MApplication::VApp()->TapeSettings();
@@ -703,7 +705,7 @@ void MApplication::ParseCommandLine(const SocketConnection &connection, const QS
     {
         if (testMode && args.count() > 1)
         {
-            qCCritical(mApp, "%s\n", qPrintable(tr("Test mode doesn't support openning several files.")));
+            qCCritical(mApp, "%s\n", qPrintable(tr("Test mode doesn't support opening several files.")));
             parser.showHelp(V_EX_USAGE);
         }
 
@@ -785,7 +787,7 @@ void MApplication::ParseCommandLine(const SocketConnection &connection, const QS
             }
         }
 
-        for (auto &arg : args)
+        for (const auto &arg : args)
         {
             NewMainWindow();
             if (not MainWindow()->LoadFile(arg))
@@ -861,6 +863,7 @@ TMainWindow *MApplication::NewMainWindow()
     if (not MApplication::VApp()->IsTestMode())
     {
         tape->show();
+        tape->UpdateWindowTitle();
     }
     return tape;
 }
@@ -869,6 +872,15 @@ TMainWindow *MApplication::NewMainWindow()
 void MApplication::ProcessCMD()
 {
     ParseCommandLine(SocketConnection::Client, arguments());
+
+    if (IsAppInGUIMode() && Settings()->IsAutomaticallyCheckUpdates())
+    {
+        // Set feed URL before doing anything else
+        FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
+
+        // Check for updates automatically
+        FvUpdater::sharedUpdater()->CheckForUpdatesSilent();
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
