@@ -65,8 +65,7 @@ public:
 
     bool LoadFile(const QString &path);
 
-public slots:
-    virtual void ShowToolTip(const QString &toolTip) override;
+    void UpdateWindowTitle();
 
 protected:
     virtual void closeEvent(QCloseEvent *event) override;
@@ -112,6 +111,7 @@ private slots:
 
     void AddCustom();
     void AddKnown();
+    void AddSeparator();
     void ImportFromPattern();
 
     void DimensionABaseChanged();
@@ -145,6 +145,9 @@ private slots:
     void RestrictThirdDimesion();
 
     void EditDimensionLabels();
+    void DimensionCustomNames();
+
+    void SetDefaultGUILanguage();
 
 private:
     Q_DISABLE_COPY(TMainWindow)
@@ -164,7 +167,7 @@ private:
     QComboBox       *comboBoxUnits{nullptr};
     int              formulaBaseHeight;
     QSharedPointer<VLockGuard<char>> lock{nullptr};
-    QSharedPointer<VTableSearch> search{};
+    QSharedPointer<VTableSearch> m_search{};
     QLabel *labelGradationDimensionA{nullptr};
     QLabel *labelGradationDimensionB{nullptr};
     QLabel *labelGradationDimensionC{nullptr};
@@ -172,6 +175,7 @@ private:
     bool isInitialized{false};
     bool mIsReadOnly{false};
     QTimer *gradation;
+    QMenu *m_searchHistory;
 
     QVector<QObject *> hackedWidgets{};
 
@@ -189,6 +193,11 @@ private:
     void InitMeasurementUnits();
     void InitGender(QComboBox *gender);
     void InitMeasurementDimension();
+    void InitSearch();
+
+    void InitSearchHistory();
+    void SaveSearchRequest();
+    void UpdateSearchControlsTooltips();
 
     void RetranslateTableHeaders();
 
@@ -203,6 +212,7 @@ private:
     bool MaybeSave();
 
     QTableWidgetItem *AddCell(const QString &text, int row, int column, int aligment, bool ok = true);
+    QTableWidgetItem* AddSeparatorCell(const QString &text, int row, int column, int aligment, bool ok = true);
 
     void RefreshData(bool freshCall = false);
     void RefreshTable(bool freshCall = false);
@@ -218,7 +228,6 @@ private:
     void MeasurementGUI();
     void Controls();
     void MFields(bool enabled);
-    void UpdateWindowTitle();
 
     void ReadSettings();
     void WriteSettings();
@@ -231,8 +240,6 @@ private:
 
     void CreateWindowMenu(QMenu *menu);
 
-    bool IgnoreLocking(int error, const QString &path);
-
     template <class T>
     void HackWidget(T **widget);
     void HackDimensionBaseValue();
