@@ -32,7 +32,7 @@
 #include "../ifc/xml/vdomdocument.h"
 #include "../vformat/vmeasurements.h"
 #include "../vmisc/commandoptions.h"
-#include "../vmisc/vsettings.h"
+#include "vvalentinasettings.h"
 #include "../vmisc/dialogs/dialogexporttocsv.h"
 #include "../vlayout/vlayoutgenerator.h"
 #include "../vpatterndb/variables/vmeasurement.h"
@@ -46,15 +46,15 @@ VCommandLinePtr VCommandLine::instance = nullptr;
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-qreal Lo2Px(const QString &src, const DialogLayoutSettings &converter)
+qreal Lo2Px(const QString &src, const DialogLayoutSettings &converter, bool *ok)
 {
-    return converter.LayoutToPixels(src.toDouble());
+    return converter.LayoutToPixels(src.toDouble(ok));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal Pg2Px(const QString& src, const DialogLayoutSettings& converter)
+qreal Pg2Px(const QString& src, const DialogLayoutSettings& converter, bool *ok)
 {
-    return converter.PageToPixels(src.toDouble());
+    return converter.PageToPixels(src.toDouble(ok));
 }
 } // anonymous namespace
 
@@ -128,7 +128,7 @@ VLayoutGeneratorPtr VCommandLine::DefaultGenerator() const
         bool a = IsOptionSet(key);
         bool b = IsOptionSet(LONG_OPTION_PAGEUNITS);
 
-        if ((a || b) && !(a && b))
+        if (a && !(a && b))
         {
             qCritical() << message << "\n";
             const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
@@ -175,8 +175,23 @@ VLayoutGeneratorPtr VCommandLine::DefaultGenerator() const
             const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
         }
 
-        diag.SetPaperHeight (Pg2Px(OptionValue(LONG_OPTION_PAGEH), diag));
-        diag.SetPaperWidth  (Pg2Px(OptionValue(LONG_OPTION_PAGEW), diag));
+        bool ok = false;
+        qreal height = Pg2Px(OptionValue(LONG_OPTION_PAGEH), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid page height value.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        diag.SetPaperHeight(height);
+
+        ok = false;
+        qreal width = Pg2Px(OptionValue(LONG_OPTION_PAGEW), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid page width value.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        diag.SetPaperWidth(width);
     }
     else
     { // Not explicit page size
@@ -197,7 +212,14 @@ VLayoutGeneratorPtr VCommandLine::DefaultGenerator() const
 
     if (IsOptionSet(LONG_OPTION_GAPWIDTH))
     {
-        diag.SetLayoutWidth(Lo2Px(OptionValue(LONG_OPTION_GAPWIDTH), diag));
+        bool ok = false;
+        qreal width = Lo2Px(OptionValue(LONG_OPTION_GAPWIDTH), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid gap width.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        diag.SetLayoutWidth(width);
     }
 
     diag.SetAutoCropLength(IsOptionSet(LONG_OPTION_CROP_LENGTH));
@@ -216,22 +238,50 @@ VLayoutGeneratorPtr VCommandLine::DefaultGenerator() const
 
     if (IsOptionSet(LONG_OPTION_LEFT_MARGIN))
     {
-        margins.setLeft(Pg2Px(OptionValue(LONG_OPTION_LEFT_MARGIN), diag));
+        bool ok = false;
+        qreal margin = Pg2Px(OptionValue(LONG_OPTION_LEFT_MARGIN), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid layout page left margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setLeft(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_RIGHT_MARGIN))
     {
-        margins.setRight(Pg2Px(OptionValue(LONG_OPTION_RIGHT_MARGIN), diag));
+        bool ok = false;
+        qreal margin = Pg2Px(OptionValue(LONG_OPTION_RIGHT_MARGIN), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid layout page right margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setRight(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_TOP_MARGIN))
     {
-        margins.setTop(Pg2Px(OptionValue(LONG_OPTION_TOP_MARGIN), diag));
+        bool ok = false;
+        qreal margin = Pg2Px(OptionValue(LONG_OPTION_TOP_MARGIN), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid layout page top margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setTop(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_BOTTOM_MARGIN))
     {
-        margins.setBottom(Pg2Px(OptionValue(LONG_OPTION_BOTTOM_MARGIN), diag));
+        bool ok = false;
+        qreal margin = Pg2Px(OptionValue(LONG_OPTION_BOTTOM_MARGIN), diag, &ok);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid layout page bottom margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setBottom(margin);
     }
 
     diag.SetFields(margins);
@@ -478,7 +528,7 @@ QMap<int, QString> VCommandLine::OptUserMaterials() const
         }
 
         bool ok = false;
-        const int number = parts.first().toInt(&ok);
+        const int number = ConstFirst<QString>(parts).toInt(&ok);
 
         if (not ok or number < 1 or number > userMaterialPlaceholdersQuantity)
         {
@@ -487,7 +537,7 @@ QMap<int, QString> VCommandLine::OptUserMaterials() const
             const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
         }
 
-        userMaterials.insert(number, parts.last());
+        userMaterials.insert(number, ConstLast<QString>(parts));
     }
 
     return userMaterials;
@@ -572,42 +622,70 @@ int VCommandLine::OptDimensionC() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF VCommandLine::TiledPageMargins() const
+auto VCommandLine::TiledPageMargins() const -> QMarginsF
 {
     QMarginsF margins(10, 10, 10, 10); // mm
 
-    if (not IsOptionSet(LONG_OPTION_LEFT_MARGIN))
-    {
-        return margins;
-    }
+    Unit unit = Unit::Cm;
 
-    const QString value = OptionValue(LONG_OPTION_LEFT_MARGIN);
-    const QStringList supportedUnits = QStringList() << unitMM << unitCM << unitINCH;
-    if (not supportedUnits.contains(value))
+    if (IsOptionSet(LONG_OPTION_SHIFTUNITS))
     {
-        qCritical() << translate("VCommandLine", "Unsupported paper units.") << "\n";
-        const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        const QString value = OptionValue(LONG_OPTION_SHIFTUNITS);
+        const QStringList supportedUnits = QStringList() << unitMM << unitCM << unitINCH;
+        if (not supportedUnits.contains(value))
+        {
+            qCritical() << translate("VCommandLine", "Unsupported paper units.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        unit = StrToUnits(value);
     }
-    const Unit unit = StrToUnits(value);
 
     if (IsOptionSet(LONG_OPTION_LEFT_MARGIN))
     {
-        margins.setLeft(UnitConvertor(OptionValue(LONG_OPTION_LEFT_MARGIN).toDouble(), unit, Unit::Mm));
+        bool ok = false;
+        qreal margin = UnitConvertor(OptionValue(LONG_OPTION_LEFT_MARGIN).toDouble(&ok), unit, Unit::Mm);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid tiled page left margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setLeft(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_RIGHT_MARGIN))
     {
-        margins.setRight(UnitConvertor(OptionValue(LONG_OPTION_RIGHT_MARGIN).toDouble(), unit, Unit::Mm));
+        bool ok = false;
+        qreal margin = UnitConvertor(OptionValue(LONG_OPTION_RIGHT_MARGIN).toDouble(&ok), unit, Unit::Mm);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid tiled page right margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setLeft(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_TOP_MARGIN))
     {
-        margins.setTop(UnitConvertor(OptionValue(LONG_OPTION_TOP_MARGIN).toDouble(), unit, Unit::Mm));
+        bool ok = false;
+        qreal margin = UnitConvertor(OptionValue(LONG_OPTION_TOP_MARGIN).toDouble(&ok), unit, Unit::Mm);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid tiled page top margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setLeft(margin);
     }
 
     if (IsOptionSet(LONG_OPTION_BOTTOM_MARGIN))
     {
-        margins.setBottom(UnitConvertor(OptionValue(LONG_OPTION_BOTTOM_MARGIN).toDouble(), unit, Unit::Mm));
+        bool ok = false;
+        qreal margin = UnitConvertor(OptionValue(LONG_OPTION_BOTTOM_MARGIN).toDouble(&ok), unit, Unit::Mm);
+        if (not ok)
+        {
+            qCritical() << translate("VCommandLine", "Invalid tiled page bottom margin.") << "\n";
+            const_cast<VCommandLine*>(this)->parser.showHelp(V_EX_USAGE);
+        }
+        margins.setLeft(margin);
     }
 
     return margins;
@@ -703,7 +781,7 @@ void VCommandLine::InitCommandLineOptions()
          translate("VCommandLine", "The measure unit")},
         {{SINGLE_OPTION_IGNORE_MARGINS, LONG_OPTION_IGNORE_MARGINS},
          translate("VCommandLine", "Ignore printer margins (export mode). Use if need full paper space. In case of "
-         "later printing you must account for the margins himself.")},
+         "later printing you must account for the margins themselves.")},
         {{SINGLE_OPTION_LEFT_MARGIN, LONG_OPTION_LEFT_MARGIN},
          translate("VCommandLine", "Page left margin in current units like 3.0 (export mode). If not set will be used "
          "value from default printer. Or 0 if none printers was found."),
@@ -747,7 +825,7 @@ void VCommandLine::InitCommandLineOptions()
          translate("VCommandLine", "Save length of the sheet if set (export mode). The option tells the program to use "
          "as much as possible width of sheet. Quality of a layout can be worse when this option was used.")},
         {{SINGLE_OPTION_SHIFTUNITS, LONG_OPTION_SHIFTUNITS},
-         translate("VCommandLine", "Layout units (as paper's one except px, export mode)."),
+         translate("VCommandLine", "Layout units (as paper's one except px, export mode). Default units cm."),
          translate("VCommandLine", "The unit")},
         {{SINGLE_OPTION_GAPWIDTH, LONG_OPTION_GAPWIDTH},
          translate("VCommandLine", "The layout gap width x2, measured in layout units (export mode). Set distance "
@@ -834,7 +912,7 @@ QStringList VCommandLine::OptionValues(const QString &option) const
 //---------------------------------------------------------------------------------------------------------------------
 int VCommandLine::OptNestingTime() const
 {
-    int time = VSettings::GetDefNestingTime();
+    int time = VValentinaSettings::GetDefNestingTime();
     if (IsOptionSet(LONG_OPTION_NESTING_TIME))
     {
         bool ok = false;
@@ -854,7 +932,7 @@ int VCommandLine::OptNestingTime() const
 //---------------------------------------------------------------------------------------------------------------------
 qreal VCommandLine::OptEfficiencyCoefficient() const
 {
-    qreal coefficient = VSettings::GetDefEfficiencyCoefficient();
+    qreal coefficient = VValentinaSettings::GetDefEfficiencyCoefficient();
     if (IsOptionSet(LONG_OPTION_EFFICIENCY_COEFFICIENT))
     {
         bool ok = false;
