@@ -30,7 +30,7 @@
 #include "ui_dialoglayoutsettings.h"
 #include "../core/vapplication.h"
 #include "../ifc/xml/vdomdocument.h"
-#include "../vmisc/vsettings.h"
+#include "../vmisc/vvalentinasettings.h"
 #include "../vmisc/vmath.h"
 #include "../vlayout/vlayoutgenerator.h"
 
@@ -516,7 +516,7 @@ QString DialogLayoutSettings::MakeGroupsHelp()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
+    VAbstractLayoutDialog::showEvent( event );
     if ( event->spontaneous() )
     {
         return;
@@ -528,12 +528,28 @@ void DialogLayoutSettings::showEvent(QShowEvent *event)
     }
     // do your init stuff here
 
-    setMaximumSize(size());
-    setMinimumSize(size());
+    const QSize sz = VAbstractApplication::VApp()->Settings()->GetLayoutSettingsDialogSize();
+    if (not sz.isEmpty())
+    {
+        resize(sz);
+    }
 
     isInitialized = true;//first show windows are held
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLayoutSettings::resizeEvent(QResizeEvent *event)
+{
+    // remember the size for the next time this dialog is opened, but only
+    // if widget was already initialized, which rules out the resize at
+    // dialog creating, which would
+    if (isInitialized)
+    {
+        VAbstractApplication::VApp()->Settings()->SetLayoutSettingsDialogSize(size());
+    }
+    VAbstractLayoutDialog::resizeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::ConvertLayoutSize()
 {
@@ -699,17 +715,17 @@ void DialogLayoutSettings::RestoreDefaults()
     InitPrinter();
     ui->comboBoxPrinter->blockSignals(false);
 
-    SetLayoutWidth(VSettings::GetDefLayoutWidth());
-    SetGroup(VSettings::GetDefLayoutGroup());
-    SetFollowGrainline(VSettings::GetDefLayoutFollowGrainline());
-    SetManualPriority(VSettings::GetDefLayoutManualPriority());
+    SetLayoutWidth(VValentinaSettings::GetDefLayoutWidth());
+    SetGroup(VValentinaSettings::GetDefLayoutGroup());
+    SetFollowGrainline(VValentinaSettings::GetDefLayoutFollowGrainline());
+    SetManualPriority(VValentinaSettings::GetDefLayoutManualPriority());
     SetFields(GetDefPrinterFields());
-    SetIgnoreAllFields(VSettings::GetDefIgnoreAllFields());
-    SetMultiplier(VSettings::GetDefMultiplier());
-    SetNestingTime(VSettings::GetDefNestingTime());
-    SetEfficiencyCoefficient(VSettings::GetDefEfficiencyCoefficient());
-    SetNestQuantity(VSettings::GetDefLayoutNestQuantity());
-    SetPreferOneSheetSolution(VSettings::GetDefLayoutPreferOneSheetSolution());
+    SetIgnoreAllFields(VValentinaSettings::GetDefIgnoreAllFields());
+    SetMultiplier(VValentinaSettings::GetDefMultiplier());
+    SetNestingTime(VValentinaSettings::GetDefNestingTime());
+    SetEfficiencyCoefficient(VValentinaSettings::GetDefEfficiencyCoefficient());
+    SetNestQuantity(VValentinaSettings::GetDefLayoutNestQuantity());
+    SetPreferOneSheetSolution(VValentinaSettings::GetDefLayoutPreferOneSheetSolution());
 
     CorrectMaxFileds();
     IgnoreAllFields(ui->checkBoxIgnoreFileds->isChecked());
@@ -1019,7 +1035,7 @@ void DialogLayoutSettings::MinimumLayoutSize()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::ReadSettings()
 {
-    const VSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+    const VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
     SetLayoutWidth(settings->GetLayoutWidth());
     SetNestingTime(settings->GetNestingTime());
     SetEfficiencyCoefficient(settings->GetEfficiencyCoefficient());
@@ -1051,7 +1067,7 @@ void DialogLayoutSettings::ReadSettings()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::WriteSettings() const
 {
-    VSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+    VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
     settings->SetLayoutWidth(GetLayoutWidth());
     settings->SetLayoutGroup(GetGroup());
     settings->SetLayoutPaperHeight(GetPaperHeight());
