@@ -130,13 +130,16 @@ void FvUpdater::showUpdaterWindowUpdatedWithCurrentUpdateProposal()
     // Create a new window
     m_updaterWindow = new FvUpdateWindow(VAbstractValApplication::VApp()->getMainWindow());
     m_updaterWindow->UpdateWindowWithCurrentProposedUpdate();
-    m_updaterWindow->exec();
+    if (m_updaterWindow != nullptr)
+    {
+        m_updaterWindow->exec();
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void FvUpdater::hideUpdaterWindow()
 {
-    if (m_updaterWindow)
+    if (m_updaterWindow != nullptr)
     {
         m_updaterWindow->close();
     }
@@ -281,7 +284,7 @@ bool FvUpdater::CheckForUpdates(bool silentAsMuchAsItCouldGet)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool FvUpdater::CheckForUpdatesSilent()
+auto FvUpdater::CheckForUpdatesSilent() -> bool
 {
     if (VAbstractApplication::VApp()->Settings()->GetDateOfLastRemind().daysTo(QDate::currentDate()) >= 1)
     {
@@ -292,18 +295,16 @@ bool FvUpdater::CheckForUpdatesSilent()
         }
         return success;
     }
-    else
+
+    if (m_dropOnFinnish)
     {
-        if (m_dropOnFinnish)
-        {
-            drop();
-        }
-        return true;
+        drop();
     }
+    return true;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool FvUpdater::CheckForUpdatesNotSilent()
+auto FvUpdater::CheckForUpdatesNotSilent() -> bool
 {
     const bool success = CheckForUpdates(false);
     if (m_dropOnFinnish && not success)
@@ -352,7 +353,7 @@ void FvUpdater::startDownloadFeed(const QUrl &url)
 //---------------------------------------------------------------------------------------------------------------------
 void FvUpdater::cancelDownloadFeed()
 {
-    if (m_reply)
+    if (m_reply != nullptr)
     {
         m_httpRequestAborted = true;
         m_reply->abort();
@@ -532,7 +533,7 @@ bool FvUpdater::VersionIsIgnored(const QString &version)
     //	3) A newer version (don't ignore)
     // 'version' is not likely to contain an older version in any case.
 
-    int decVersion = 0x0;
+    unsigned decVersion = 0x0;
     try
     {
         decVersion = VAbstractConverter::GetFormatVersion(version);
@@ -543,12 +544,12 @@ bool FvUpdater::VersionIsIgnored(const QString &version)
         return true; // Ignore invalid version
     }
 
-    if (decVersion == APP_VERSION)
+    if (decVersion == AppVersion())
     {
         return true;
     }
 
-    const int lastSkippedVersion = VAbstractApplication::VApp()->Settings()->GetLatestSkippedVersion();
+    const unsigned lastSkippedVersion = VAbstractApplication::VApp()->Settings()->GetLatestSkippedVersion();
     if (lastSkippedVersion != 0x0)
     {
         if (decVersion == lastSkippedVersion)
@@ -558,7 +559,7 @@ bool FvUpdater::VersionIsIgnored(const QString &version)
         }
     }
 
-    if (decVersion > APP_VERSION)
+    if (decVersion > AppVersion())
     {
         // Newer version - do not skip
         return false;
@@ -571,7 +572,7 @@ bool FvUpdater::VersionIsIgnored(const QString &version)
 //---------------------------------------------------------------------------------------------------------------------
 void FvUpdater::IgnoreVersion(const QString &version)
 {
-    int decVersion = 0x0;
+    unsigned decVersion = 0x0;
     try
     {
         decVersion = VAbstractConverter::GetFormatVersion(version);
@@ -582,7 +583,7 @@ void FvUpdater::IgnoreVersion(const QString &version)
         return ; // Ignore invalid version
     }
 
-    if (decVersion == APP_VERSION)
+    if (decVersion == AppVersion())
     {
         // Don't ignore the current version
         return;
