@@ -36,6 +36,10 @@
 
 #include "../ifcdef.h"
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
+
 /**
  * @brief The VException class parent for all exception. Could be use for abstract exception
  */
@@ -69,6 +73,8 @@ protected:
     QString         MoreInfo(const QString &detInfo) const;
 };
 
+QT_WARNING_POP
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief What return string with error
