@@ -47,6 +47,8 @@ const QString AttrType        = QStringLiteral("type");
 const QString AttrMx          = QStringLiteral("mx");
 const QString AttrMy          = QStringLiteral("my");
 const QString AttrName        = QStringLiteral("name");
+const QString AttrUUID        = QStringLiteral("uuid");
+const QString AttrGradationLabel = QStringLiteral("gradationLabel");
 const QString AttrMx1         = QStringLiteral("mx1");
 const QString AttrMy1         = QStringLiteral("my1");
 const QString AttrName1       = QStringLiteral("name1");
@@ -141,6 +143,7 @@ const QString AttrCurve1Alias1 = QStringLiteral("curve1Alias1");
 const QString AttrCurve1Alias2 = QStringLiteral("curve1Alias2");
 const QString AttrCurve2Alias1 = QStringLiteral("curve2Alias1");
 const QString AttrCurve2Alias2 = QStringLiteral("curve2Alias2");
+const QString AttrLayoutVersion = QStringLiteral("version");
 
 const QString TypeLineDefault        = QStringLiteral("default");
 const QString TypeLineNone           = QStringLiteral("none");
