@@ -31,10 +31,11 @@
 
 #include <QtGlobal>
 #ifdef Q_OS_WIN
-   extern Q_CORE_EXPORT int qt_ntfs_permission_lookup;
+//   extern Q_CORE_EXPORT int qt_ntfs_permission_lookup;
 #  include <qt_windows.h>
 #endif /*Q_OS_WIN*/
 
+#include <QColor>
 #include <QFont>
 #include <QString>
 #include <QStringList>
@@ -65,6 +66,8 @@ extern const QString AttrType;
 extern const QString AttrMx;
 extern const QString AttrMy;
 extern const QString AttrName;
+extern const QString AttrUUID;
+extern const QString AttrGradationLabel;
 extern const QString AttrMx1;
 extern const QString AttrMy1;
 extern const QString AttrName1;
@@ -159,6 +162,7 @@ extern const QString AttrCurve1Alias1;
 extern const QString AttrCurve1Alias2;
 extern const QString AttrCurve2Alias1;
 extern const QString AttrCurve2Alias2;
+extern const QString AttrLayoutVersion;
 
 extern const QString TypeLineDefault;
 extern const QString TypeLineNone;
@@ -260,6 +264,8 @@ struct VWatermarkData
     QString path{};
     int     imageRotation{0};
     bool    grayscale{false};
+    bool    invalidFile{false};
+    QColor  textColor{Qt::black};
 };
 
 QT_WARNING_POP
