@@ -39,6 +39,7 @@
 #include <QStringList>
 #include <QVector>
 #include <QtGlobal>
+#include <QUuid>
 
 #include "../vmisc/def.h"
 #include "vdomdocument.h"
@@ -48,6 +49,8 @@
 class QDomElement;
 class VPiecePath;
 class VPieceNode;
+class VPatternImage;
+class VBackgroundPatternImage;
 
 enum class Document : qint8 { FullLiteParse, LiteParse, LitePPParse, FullParse };
 enum class LabelType : qint8 {NewPatternPiece, NewLabel};
@@ -83,10 +86,15 @@ struct VGroupData
     QString name{};
     bool visible{true};
     QStringList tags{};
+    vidtype tool{NULL_ID};
+    QVector<QPair<vidtype, vidtype>> items{};
 };
 
 QT_WARNING_POP
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
+
 class VAbstractPattern : public VDomDocument
 {
     Q_OBJECT
@@ -195,11 +203,16 @@ public:
     QString GetPassmarkLengthVariable() const;
     void    SetPassmarkLengthVariable(const QString &name);
 
-    QString        GetImage() const;
-    QString        GetImageExtension() const;
-    void           SetImage(const QString &text, const QString &extension);
+    VPatternImage  GetImage() const;
+    bool           SetImage(const VPatternImage &image);
     void           DeleteImage();
 
+    auto GetBackgroundImages() const -> QVector<VBackgroundPatternImage>;
+    void SaveBackgroundImages(const QVector<VBackgroundPatternImage> &images);
+    auto GetBackgroundImage(const QUuid &id) const -> VBackgroundPatternImage;
+    void SaveBackgroundImage(const VBackgroundPatternImage &image);
+    void DeleteBackgroundImage(const QUuid &id);
+
     QString        GetVersion() const;
     void           SetVersion();
 
@@ -209,7 +222,7 @@ public:
     QDomElement    GetDraw(const QString &name) const;
 
     void           ParseGroups(const QDomElement &domElement);
-    QDomElement    CreateGroups();
+    QDomElement    CreateGroups(const QString &patternPieceName = QString());
     QDomElement    CreateGroup(quint32 id, const QString &name, const QStringList &tags,
                                const QMap<quint32, quint32> &groupData, vidtype tool=null_id);
     vidtype        GroupLinkedToTool(vidtype toolId) const;
@@ -222,11 +235,10 @@ public:
 
     QStringList GetGroupCategories() const;
 
-    QMap<quint32, VGroupData> GetGroups();
+    QMap<quint32, VGroupData> GetGroups(const QString &patternPieceName = QString());
     QMap<quint32, QString> GetGroupsContainingItem(quint32 toolId, quint32 objectId, bool containItem);
     QDomElement           AddItemToGroup(quint32 toolId, quint32 objectId, quint32 groupId);
     QDomElement           RemoveItemFromGroup(quint32 toolId, quint32 objectId, quint32 groupId);
-    bool           GroupIsEmpty(quint32 id);
     bool           GetGroupVisibility(quint32 id);
 
     static QStringList FilterGroupTags(const QString &tags);
@@ -278,6 +290,8 @@ public:
     static const QString TagPath;
     static const QString TagNodes;
     static const QString TagNode;
+    static const QString TagBackgroundImages;
+    static const QString TagBackgroundImage;
 
     static const QString AttrName;
     static const QString AttrVisible;
@@ -314,8 +328,12 @@ public:
     static const QString AttrPassmarkLength;
     static const QString AttrOpacity;
     static const QString AttrTags;
+    static const QString AttrTransform;
+    static const QString AttrHold;
+    static const QString AttrZValue;
+    static const QString AttrImageId;
 
-    static const QString AttrExtension;
+    static const QString AttrContentType;
 
     static const QString AttrFormula;
     static const QString AttrDescription;
@@ -374,6 +392,16 @@ signals:
     void           UpdateGroups();
     void           UpdateToolTip();
 
+    void BackgroundImageTransformationChanged(QUuid id);
+    void BackgroundImagesHoldChanged();
+    void BackgroundImageHoldChanged(const QUuid &id);
+    void BackgroundImageVisibilityChanged(const QUuid &id);
+    void BackgroundImagesVisibilityChanged();
+    void BackgroundImageNameChanged(const QUuid &id);
+    void BackgroundImagesZValueChanged();
+    void BackgroundImagePositionChanged(const QUuid &id);
+    void BackgroundImageOpacityChanged(const QUuid &id);
+
 public slots:
     virtual void   LiteParseTree(const Document &parse)=0;
     void           haveLiteChange();
@@ -469,8 +497,14 @@ private:
 
     QVector<VFinalMeasurement> GetFMeasurements(const QDomElement &element) const;
     void                       SetFMeasurements(QDomElement &element, const QVector<VFinalMeasurement> &measurements);
+
+    auto GetBackgroundPatternImage(const QDomElement &element) const -> VBackgroundPatternImage;
+    auto GetBackgroundImageElement(const QUuid &id) const -> QDomElement;
+    void WriteBackgroundImage(QDomElement &element, const VBackgroundPatternImage &image);
 };
 
+QT_WARNING_POP
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief GetNameActivPP return current pattern piece name.
