@@ -860,38 +860,38 @@ QString VDomDocument::GetFormatVersionStr() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VDomDocument::GetFormatVersion(const QString &version)
+auto VDomDocument::GetFormatVersion(const QString &version) -> unsigned
 {
     ValidateVersion(version);
 
     const QStringList ver = version.split(QChar('.'));
 
     bool ok = false;
-    const int major = ver.at(0).toInt(&ok);
+    const unsigned major = ver.at(0).toUInt(&ok);
     if (not ok)
     {
         return 0x0;
     }
 
     ok = false;
-    const int minor = ver.at(1).toInt(&ok);
+    const unsigned minor = ver.at(1).toUInt(&ok);
     if (not ok)
     {
         return 0x0;
     }
 
     ok = false;
-    const int patch = ver.at(2).toInt(&ok);
+    const unsigned patch = ver.at(2).toUInt(&ok);
     if (not ok)
     {
         return 0x0;
     }
 
-    return (major<<16)|(minor<<8)|(patch);
+    return (major<<16u)|(minor<<8u)|(patch);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::setTagText(const QString &tag, const QString &text)
+auto VDomDocument::setTagText(const QString &tag, const QString &text) -> bool
 {
     const QDomNodeList nodeList = this->elementsByTagName(tag);
     if (nodeList.isEmpty())
@@ -900,10 +900,10 @@ bool VDomDocument::setTagText(const QString &tag, const QString &text)
     }
     else
     {
-        const QDomNode domNode = nodeList.at(0);
-        if (domNode.isNull() == false && domNode.isElement())
+        QDomNode domNode = nodeList.at(0);
+        if (not domNode.isNull() && domNode.isElement())
         {
-            const QDomElement domElement = domNode.toElement();
+            QDomElement domElement = domNode.toElement();
             return setTagText(domElement, text);
         }
     }
@@ -911,17 +911,30 @@ bool VDomDocument::setTagText(const QString &tag, const QString &text)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::setTagText(const QDomElement &domElement, const QString &text)
+auto VDomDocument::setTagText(QDomElement &domElement, const QString &text) -> bool
 {
-    if (domElement.isNull() == false)
+    if (not domElement.isNull())
     {
-        QDomElement parent = domElement.parentNode().toElement();
-        QDomElement newTag = createElement(domElement.tagName());
+        QDomNode oldText = domElement.firstChild();
+        const QDomText newText = createTextNode(text);
 
-        const QDomText newTagText = createTextNode(text);
-        newTag.appendChild(newTagText);
+        if (oldText.isNull())
+        {
+            domElement.appendChild(newText);
+        }
+        else
+        {
+            if (oldText.nodeType() == QDomNode::TextNode)
+            {
+                domElement.replaceChild(newText, oldText);
+            }
+            else
+            {
+                RemoveAllChildren(domElement);
+                domElement.appendChild(newText);
+            }
+        }
 
-        parent.replaceChild(newTag, domElement);
         return true;
     }
     return false;
@@ -973,9 +986,9 @@ bool VDomDocument::SafeCopy(const QString &source, const QString &destination, Q
 {
     bool result = false;
 
-#ifdef Q_OS_WIN32
-    qt_ntfs_permission_lookup++; // turn checking on
-#endif /*Q_OS_WIN32*/
+//#ifdef Q_OS_WIN32
+//    qt_ntfs_permission_lookup++; // turn checking on
+//#endif /*Q_OS_WIN32*/
 
     QTemporaryFile destFile(destination + QLatin1String(".XXXXXX"));
     destFile.setAutoRemove(false);// Will be renamed to be destination file
@@ -1029,9 +1042,9 @@ bool VDomDocument::SafeCopy(const QString &source, const QString &destination, Q
         }
     }
 
-#ifdef Q_OS_WIN32
-    qt_ntfs_permission_lookup--; // turn off check permission again
-#endif /*Q_OS_WIN32*/
+//#ifdef Q_OS_WIN32
+//    qt_ntfs_permission_lookup--; // turn off check permission again
+//#endif /*Q_OS_WIN32*/
 
     return result;
 }
