@@ -42,10 +42,12 @@
 #include <QtGlobal>
 #include <QLocale>
 #include <QLoggingCategory>
+#include <functional>
 
 #include "../ifc/ifcdef.h"
 #include "../vmisc/def.h"
 #include "../vmisc/diagnostic.h"
+#include "../vmisc/literals.h"
 
 class QDomElement;
 class QDomNode;
@@ -103,7 +105,7 @@ public:
 
     template <typename T>
     void SetAttributeOrRemoveIf(QDomElement &domElement, const QString &name, const T &value,
-                                bool removeCondition) const;
+                                const std::function<bool(const T&)> &removeCondition) const;
 
     static quint32 GetParametrUInt(const QDomElement& domElement, const QString &name, const QString &defValue);
     static int     GetParametrInt(const QDomElement& domElement, const QString &name, const QString &defValue);
@@ -127,8 +129,8 @@ public:
     QString        Major() const;
     QString        Minor() const;
     QString        Patch() const;
-    QString        GetFormatVersionStr() const;
-    static int     GetFormatVersion(const QString &version);
+    virtual QString GetFormatVersionStr() const;
+    static unsigned GetFormatVersion(const QString &version);
     static void    RemoveAllChildren(QDomElement &domElement);
 
     QDomNode       ParentNodeById(const quint32 &nodeId);
@@ -148,11 +150,11 @@ public:
 
 protected:
     bool           setTagText(const QString &tag, const QString &text);
-    bool           setTagText(const QDomElement &domElement, const QString &text);
+    bool           setTagText(QDomElement &domElement, const QString &text);
     QString        UniqueTagText(const QString &tagName, const QString &defVal = QString()) const;
     void           CollectId(const QDomElement &node, QVector<quint32> &vector)const;
 
-    static void    ValidateVersion(const QString &version);
+    static void ValidateVersion(const QString &version);
 
 private slots:
     void CacheRefreshed();
@@ -218,9 +220,9 @@ inline void VDomDocument::SetAttribute<MeasurementsType>(QDomElement &domElement
 //---------------------------------------------------------------------------------------------------------------------
 template <typename T>
 inline void VDomDocument::SetAttributeOrRemoveIf(QDomElement &domElement, const QString &name, const T &value,
-                                                 bool removeCondition) const
+                                                 const std::function<bool(const T&)> &removeCondition) const
 {
-    not removeCondition ? SetAttribute(domElement, name, value) : domElement.removeAttribute(name);
+    not removeCondition(value) ? SetAttribute(domElement, name, value) : domElement.removeAttribute(name);
 }
 
 QT_WARNING_POP
