@@ -43,7 +43,7 @@
 
 class QDomElement;
 
-class VPatternConverter : public VAbstractConverter
+class VPatternConverter final : public VAbstractConverter
 {
     Q_DECLARE_TR_FUNCTIONS(VPatternConverter)
 public:
@@ -52,17 +52,19 @@ public:
 
     static const QString PatternMaxVerStr;
     static const QString CurrentSchema;
-    static Q_DECL_CONSTEXPR const int PatternMinVer = FORMAT_VERSION(0, 1, 4);
-    static Q_DECL_CONSTEXPR const int PatternMaxVer = FORMAT_VERSION(0, 8, 11);
+    static Q_DECL_CONSTEXPR const unsigned PatternMinVer = FormatVersion(0, 1, 4);
+    static Q_DECL_CONSTEXPR const unsigned PatternMaxVer = FormatVersion(0, 9, 0);
 
 protected:
-    virtual int     MinVer() const override;
-    virtual int     MaxVer() const override;
+    void Save() override;
+
+    virtual unsigned MinVer() const override;
+    virtual unsigned MaxVer() const override;
 
     virtual QString MinVerStr() const override;
     virtual QString MaxVerStr() const override;
 
-    virtual QString XSDSchema(int ver) const override;
+    virtual QString XSDSchema(unsigned ver) const override;
     virtual void    ApplyPatches() override;
     virtual void    DowngradeToCurrentMaxVersion() override;
 
@@ -74,66 +76,15 @@ private:
 
     void ToV0_2_0();
     void ToV0_2_1();
-    void ToV0_2_2();
-    void ToV0_2_3();
     void ToV0_2_4();
-    void ToV0_2_5();
-    void ToV0_2_6();
-    void ToV0_2_7();
     void ToV0_3_0();
     void ToV0_3_1();
-    void ToV0_3_2();
-    void ToV0_3_3();
-    void ToV0_3_4();
-    void ToV0_3_5();
-    void ToV0_3_6();
-    void ToV0_3_7();
-    void ToV0_3_8();
-    void ToV0_3_9();
     void ToV0_4_0();
-    void ToV0_4_1();
-    void ToV0_4_2();
-    void ToV0_4_3();
     void ToV0_4_4();
-    void ToV0_4_5();
-    void ToV0_4_6();
-    void ToV0_4_7();
-    void ToV0_4_8();
-    void ToV0_5_0();
-    void ToV0_5_1();
     void ToV0_6_0();
-    void ToV0_6_1();
     void ToV0_6_2();
-    void ToV0_6_3();
-    void ToV0_6_4();
-    void ToV0_6_5();
-    void ToV0_6_6();
-    void ToV0_7_0();
-    void ToV0_7_1();
-    void ToV0_7_2();
-    void ToV0_7_3();
-    void ToV0_7_4();
-    void ToV0_7_5();
-    void ToV0_7_6();
-    void ToV0_7_7();
-    void ToV0_7_8();
-    void ToV0_7_9();
-    void ToV0_7_10();
-    void ToV0_7_11();
-    void ToV0_7_12();
-    void ToV0_7_13();
-    void ToV0_8_0();
-    void ToV0_8_1();
-    void ToV0_8_2();
-    void ToV0_8_3();
-    void ToV0_8_4();
-    void ToV0_8_5();
-    void ToV0_8_6();
-    void ToV0_8_7();
     void ToV0_8_8();
-    void ToV0_8_9();
-    void ToV0_8_10();
-    void ToV0_8_11();
+    void ToV0_9_0();
 
     void          TagUnitToV0_2_0();
     void          TagIncrementToV0_2_0();
@@ -188,16 +139,19 @@ private:
     void AddTagPreviewCalculationsV0_6_2();
 
     void RemoveGradationV0_8_8();
+    void AddPieceUUIDV0_8_8();
+
+    void ConvertImageToV0_9_0();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline int VPatternConverter::MinVer() const
+inline unsigned VPatternConverter::MinVer() const
 {
     return PatternMinVer;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline int VPatternConverter::MaxVer() const
+inline unsigned VPatternConverter::MaxVer() const
 {
     return PatternMaxVer;
 }
