@@ -35,7 +35,7 @@ public:
 };
 
 //container class to store entites.
-class dx_ifaceBlock : public DRW_Block {
+class dx_ifaceBlock final : public DRW_Block {
 public:
     dx_ifaceBlock()
         : ent()
@@ -93,7 +93,7 @@ private:
 
 };
 
-class dx_iface : public DRW_Interface
+class dx_iface final : public DRW_Interface
 {
 public:
     dx_iface(const std::string& file, DRW::Version v, VarMeasurement varMeasurement, VarInsunits varInsunits);
@@ -116,6 +116,7 @@ public:
     virtual void writeTextstyles() override;
     virtual void writeVports() override;
     virtual void writeDimstyles() override;
+    virtual void writeObjects() override;
     virtual void writeAppId() override;
 
     void AddEntity(DRW_Entity* e);
