@@ -1,6 +1,7 @@
 /******************************************************************************
 **  libDXFrw - Library to read/write DXF files (ascii & binary)              **
 **                                                                           **
+**  Copyright (C) 2016-2022 A. Stebich (librecad@mail.lordofbikes.de)        **
 **  Copyright (C) 2011-2015 José F. Soriano, rallazz@gmail.com               **
 **                                                                           **
 **  This library is free software, licensed under the terms of the GNU       **
@@ -183,7 +184,7 @@ public:
     
 protected:
     //parses dxf pair to read entity
-    bool parseCode(int code, dxfReader *reader);
+    virtual bool parseCode(int code, dxfReader *reader);
     //calculates extrusion axis (normal vector)
     void calculateAxis(DRW_Coord extPoint);
     //apply extrusion to @extPoint and return data in @point
@@ -239,10 +240,10 @@ public:
         eType = DRW::POINT;
     }
 
-    virtual void applyExtrusion() override{}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     DRW_Coord basePoint;      /*!<  base point, code 10, 20 & 30 */
@@ -262,7 +263,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader);
 
 public:
     double angle{0};  /*!< angle, code 50 */
@@ -282,10 +283,10 @@ public:
         eType = DRW::LINE;
     }
 
-    virtual void applyExtrusion() override{}
+    void applyExtrusion() override{}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     DRW_Coord secPoint;        /*!< second point, code 11, 21 & 31 */
@@ -330,10 +331,10 @@ public:
         eType = DRW::CIRCLE;
     }
 
-    virtual void applyExtrusion() override;
+    void applyExtrusion() override;
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double radious;                 /*!< radius, code 40 */
@@ -355,7 +356,7 @@ public:
         eType = DRW::ARC;
     }
 
-    virtual void applyExtrusion() override;
+    void applyExtrusion() override;
 
     //! center point in OCS
     const DRW_Coord & center() const { return basePoint; }
@@ -372,7 +373,7 @@ public:
 
 protected:
     //! interpret code in dxf reading process or dispatch to inherited class
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double staangle;            /*!< start angle, code 50 in radians*/
@@ -400,11 +401,11 @@ public:
     }
 
     void toPolyline(DRW_Polyline *pol, int parts = 128);
-    virtual void applyExtrusion() override;
+    void applyExtrusion() override;
 
 protected:
     //! interpret code in dxf reading process or dispatch to inherited class
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 private:
     void correctAxis();
@@ -431,10 +432,10 @@ public:
         eType = DRW::TRACE;
     }
 
-    virtual void applyExtrusion() override;
+    void applyExtrusion() override;
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     DRW_Coord thirdPoint;        /*!< third point, code 12, 22 & 32 */
@@ -453,10 +454,6 @@ public:
         eType = DRW::SOLID;
     }
 
-protected:
-    //! interpret code in dxf reading process or dispatch to inherited class
-    void parseCode(int code, dxfReader *reader);
-
 public:
     //! first corner (2D)
     const DRW_Coord & firstCorner() const { return basePoint; }
@@ -498,7 +495,7 @@ public:
         eType = DRW::E3DFACE;
     }
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
     //! first corner in WCS
     const DRW_Coord & firstCorner() const { return basePoint; }
@@ -513,7 +510,7 @@ public:
 
 protected:
     //! interpret code in dxf reading process or dispatch to inherited class
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     int invisibleflag;       /*!< invisible edge flag, code 70 */
@@ -536,10 +533,10 @@ public:
         layer = '0';
     }
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     UTF8STRING name;             /*!< block name, code 2 */
@@ -570,7 +567,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     UTF8STRING name;         /*!< block name, code 2 */
@@ -624,7 +621,7 @@ public:
     ~DRW_LWPolyline() {
         for(DRW_Vertex2D *item : vertlist) delete item;
     }
-    virtual void applyExtrusion() override;
+    void applyExtrusion() override;
     void addVertex (DRW_Vertex2D v) {
         DRW_Vertex2D *vert = new DRW_Vertex2D();
         vert->x = v.x;
@@ -644,7 +641,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     int vertexnum;            /*!< number of vertex, code 90 */
@@ -699,10 +696,10 @@ public:
         eType = DRW::TEXT;
     }
 
-    virtual void applyExtrusion() override {} //RLZ TODO
+    void applyExtrusion() override {} //RLZ TODO
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double height;             /*!< height text, code 40 */
@@ -739,7 +736,7 @@ public:
 
     DRW_MText()
         : interlin(1),
-          haveXAxis(false)//if true needed to recalculate angle
+          hasXAxisVec(false)//if true needed to recalculate angle
     {
         eType = DRW::MTEXT;
         alignV = static_cast<VAlign>(TopLeft);
@@ -747,13 +744,13 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
     void updateAngle();    //recalculate angle if 'haveXAxis' is true
 
 public:
     double interlin;     /*!< width factor, code 44 */
 private:
-    bool haveXAxis;
+    bool hasXAxisVec;
 };
 
 //! Class to handle vertex
@@ -761,7 +758,7 @@ private:
 *  Class to handle vertex  for polyline entity
 *  @author Rallaz
 */
-class DRW_Vertex : public DRW_Point {
+class DRW_Vertex final : public DRW_Point {
     SETENTFRIENDS
 public:
     DRW_Vertex()
@@ -797,7 +794,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double stawidth;          /*!< Start width, code 40 */
@@ -831,7 +828,7 @@ public:
           smoothN(0),
           curvetype(0),
           vertlist(),
-          hadlesList(),
+          handlesList(),
           firstEH(),
           lastEH()
     {
@@ -850,7 +847,7 @@ public:
           smoothN(p.smoothN),
           curvetype(p.curvetype),
           vertlist(),
-          hadlesList(),
+          handlesList(),
           firstEH(),
           lastEH()
     {
@@ -876,7 +873,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     int flags;               /*!< polyline flag, code 70, default 0 */
@@ -892,7 +889,7 @@ public:
 
 private:
     DRW_Polyline &operator=(const DRW_Polyline &) Q_DECL_EQ_DELETE;
-    std::list<duint32>hadlesList; //list of handles, only in 2004+
+    std::list<duint32>handlesList; //list of handles, only in 2004+
     duint32 firstEH;      //handle of first entity, only in pre-2004
     duint32 lastEH;       //handle of last entity, only in pre-2004
 };
@@ -960,10 +957,10 @@ public:
         for(DRW_Coord *item : controllist) delete item;
         for(DRW_Coord *item : fitlist) delete item;
     }
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
 //    double ex;                /*!< normal vector x coordinate, code 210 */
@@ -1074,10 +1071,10 @@ public:
         looplist.push_back(v);
     }
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     UTF8STRING name;           /*!< hatch pattern name, code 2 */
@@ -1171,7 +1168,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     duint32 ref;               /*!< Hard reference to imagedef object, code 340 */
@@ -1255,10 +1252,10 @@ public:
     }
     virtual ~DRW_Dimension() = default;
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     DRW_Coord getDefPoint() const {return defPoint;}      /*!< Definition point, code 10, 20 & 30 */
@@ -1434,7 +1431,7 @@ public:
 
     DRW_Coord getDiameter1Point() const {return getPt5();}      /*!< First definition point for diameter, code 15, 25 & 35 */
     void setDiameter1Point(const DRW_Coord &p){setPt5(p);}
-    DRW_Coord getDiameter2Point() const {return getDefPoint();} /*!< Oposite point for diameter, code 10, 20 & 30 */
+    DRW_Coord getDiameter2Point() const {return getDefPoint();} /*!< Opposite point for diameter, code 10, 20 & 30 */
     void setDiameter2Point(const DRW_Coord &p){setDefPoint(p);}
     double getLeaderLength() const {return getRa40();}          /*!< Leader length, code 40 */
     void setLeaderLength(const double d) {setRa40(d);}
@@ -1561,10 +1558,10 @@ public:
         for(DRW_Coord *item : vertexlist) delete item;
     }
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     UTF8STRING style;          /*!< Dimension style name, code 3 */
@@ -1623,10 +1620,10 @@ public:
         eType = DRW::VIEWPORT;
     }
 
-    virtual void applyExtrusion() override {}
+    void applyExtrusion() override {}
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double pswidth;           /*!< Width in paper space units, code 40 */
