@@ -1,6 +1,7 @@
 /******************************************************************************
 **  libDXFrw - Library to read/write DXF files (ascii & binary)              **
 **                                                                           **
+**  Copyright (C) 2016-2022 A. Stebich (librecad@mail.lordofbikes.de)        **
 **  Copyright (C) 2011-2015 José F. Soriano, rallazz@gmail.com               **
 **                                                                           **
 **  This library is free software, licensed under the terms of the GNU       **
@@ -35,7 +36,8 @@ namespace DRW {
          VPORT,
          BLOCK_RECORD,
          APPID,
-         IMAGEDEF
+         IMAGEDEF,
+         PLOTSETTINGS
      };
 
 //pending VIEW, UCS, APPID, VP_ENT_HDR, GROUP, MLINESTYLE, LONG_TRANSACTION, XRECORD,
@@ -54,20 +56,15 @@ namespace DRW {
 */
 class DRW_TableEntry {
 public:
-    //initializes default values
     DRW_TableEntry()
-        : tType(DRW::UNKNOWNT),
-          handle(),
-          parentHandle(0),
-          name(),
-          flags(0),
-          extData(),
-          curr(nullptr)
     {}
 
-    virtual~DRW_TableEntry() {
-        for (std::vector<DRW_Variant*>::iterator it=extData.begin(); it!=extData.end(); ++it)
+    virtual~DRW_TableEntry()
+    {
+        for (std::vector<DRW_Variant*>::iterator it = extData.begin(); it != extData.end(); ++it)
+        {
             delete *it;
+        }
 
         extData.clear();
     }
@@ -79,34 +76,45 @@ public:
           name(e.name),
           flags(e.flags),
           extData(),
-          curr(e.curr)
+          curr(nullptr)
     {
-        for (std::vector<DRW_Variant*>::const_iterator it=e.extData.begin(); it!=e.extData.end(); ++it){
-            extData.push_back(new DRW_Variant(*(*it)));
+        for (std::vector<DRW_Variant*>::const_iterator it = e.extData.begin(); it != e.extData.end(); ++it)
+        {
+            DRW_Variant *src = *it;
+            DRW_Variant *dst = new DRW_Variant(*src);
+            extData.push_back(dst);
+            if (src == e.curr)
+            {
+                curr = dst;
+            }
         }
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
-    void reset(){
+    virtual bool parseCode(int code, dxfReader *reader);
+    void reset()
+    {
         flags = 0;
-        for (std::vector<DRW_Variant*>::iterator it=extData.begin(); it!=extData.end(); ++it)
+        for (std::vector<DRW_Variant*>::iterator it = extData.begin(); it != extData.end(); ++it)
+        {
             delete *it;
+        }
         extData.clear();
+        curr = nullptr;
     }
 
 public:
-    enum DRW::TTYPE tType;     /*!< enum: entity type, code 0 */
-    duint32 handle;            /*!< entity identifier, code 5 */
-    int parentHandle;          /*!< Soft-pointer ID/handle to owner object, code 330 */
-    UTF8STRING name;           /*!< entry name, code 2 */
-    int flags;                 /*!< Flags relevant to entry, code 70 */
-    std::vector<DRW_Variant*> extData; /*!< FIFO list of extended data, codes 1000 to 1071*/
+    enum DRW::TTYPE tType {DRW::UNKNOWNT};  /*!< enum: entity type, code 0 */
+    duint32 handle {0};                     /*!< entity identifier, code 5 */
+    int parentHandle {0};                   /*!< Soft-pointer ID/handle to owner object, code 330 */
+    UTF8STRING name{};                      /*!< entry name, code 2 */
+    int flags {0};                          /*!< Flags relevant to entry, code 70 */
+    std::vector<DRW_Variant*> extData{};    /*!< FIFO list of extended data, codes 1000 to 1071*/
 
 private:
     DRW_TableEntry &operator=(const DRW_TableEntry &) Q_DECL_EQ_DELETE;
     // cppcheck-suppress unsafeClassCanLeak
-    DRW_Variant* curr;
+    DRW_Variant* curr{nullptr};
 };
 
 
@@ -115,7 +123,7 @@ private:
 *  Class to handle dim style symbol table entries
 *  @author Rallaz
 */
-class DRW_Dimstyle : public DRW_TableEntry {
+class DRW_Dimstyle final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_Dimstyle()
@@ -220,7 +228,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     //V12
@@ -302,7 +310,7 @@ public:
 *  @author Rallaz
 */
 /*TODO: handle complex lineType*/
-class DRW_LType : public DRW_TableEntry {
+class DRW_LType final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_LType()
@@ -323,7 +331,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
     void update();
 
 public:
@@ -343,7 +351,7 @@ private:
 *  Class to handle layer symbol table entries
 *  @author Rallaz
 */
-class DRW_Layer : public DRW_TableEntry {
+class DRW_Layer final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_Layer()
@@ -367,7 +375,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     UTF8STRING lineType;            /*!< line type, code 6 */
@@ -410,7 +418,7 @@ public:
 *  Class to handle text style symbol table entries
 *  @author Rallaz
 */
-class DRW_Textstyle : public DRW_TableEntry {
+class DRW_Textstyle final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_Textstyle()
@@ -435,7 +443,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     double height;          /*!< Fixed text height (0 not set), code 40 */
@@ -453,7 +461,7 @@ public:
 *  Class to handle vport symbol table entries
 *  @author Rallaz
 */
-class DRW_Vport : public DRW_TableEntry {
+class DRW_Vport final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_Vport()
@@ -504,7 +512,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
     DRW_Coord lowerLeft;     /*!< Lower left corner, code 10 & 20 */
@@ -535,7 +543,7 @@ public:
     * bit 1 (1) show out of limits
     * bit 2 (2) adaptive grid
     * bit 3 (4) allow subdivision
-    * bit 4 (8) follow dinamic SCP
+    * bit 4 (8) follow dynamic SCP
     **/
 };
 
@@ -545,7 +553,7 @@ public:
 *  Class to handle image definitions object entries
 *  @author Rallaz
 */
-class DRW_ImageDef : public DRW_TableEntry {//
+class DRW_ImageDef final : public DRW_TableEntry {//
     SETOBJFRIENDS
 public:
     DRW_ImageDef()
@@ -569,7 +577,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader);
+    bool parseCode(int code, dxfReader *reader) override;
 
 public:
 //    std::string handle;       /*!< entity identifier, code 5 */
@@ -585,12 +593,44 @@ public:
     std::map<std::string,std::string> reactors;
 };
 
+//! Class to handle plotsettings entries
+/*!
+*  Class to handle plot settings object entries
+*  @author baranovskiykonstantin@gmail.com
+*/
+class DRW_PlotSettings : public DRW_TableEntry {
+    SETOBJFRIENDS
+public:
+    DRW_PlotSettings() {
+        reset();
+    }
+
+    void reset(){
+        tType = DRW::PLOTSETTINGS;
+        marginLeft = 0.0;
+        marginBottom = 0.0;
+        marginRight = 0.0;
+        marginTop = 0.0;
+        DRW_TableEntry::reset();
+    }
+
+protected:
+    bool parseCode(int code, dxfReader *reader) override;
+
+public:
+    UTF8STRING plotViewName {}; /*!< Plot view name, code 6 */
+    double marginLeft {0.0};    /*!< Size, in millimeters, of unprintable margin on left side of paper, code 40 */
+    double marginBottom {0.0};  /*!< Size, in millimeters, of unprintable margin on bottom side of paper, code 41 */
+    double marginRight {0.0};   /*!< Size, in millimeters, of unprintable margin on right side of paper, code 42 */
+    double marginTop {0.0};     /*!< Size, in millimeters, of unprintable margin on top side of paper, code 43 */
+};
+
 //! Class to handle AppId entries
 /*!
 *  Class to handle AppId symbol table entries
 *  @author Rallaz
 */
-class DRW_AppId : public DRW_TableEntry {
+class DRW_AppId final : public DRW_TableEntry {
     SETOBJFRIENDS
 public:
     DRW_AppId() { reset();}
@@ -602,7 +642,7 @@ public:
     }
 
 protected:
-    void parseCode(int code, dxfReader *reader){DRW_TableEntry::parseCode(code, reader);}
+    bool parseCode(int code, dxfReader *reader){return DRW_TableEntry::parseCode(code, reader);}
 };
 
 namespace DRW {
