@@ -3,6 +3,7 @@
 
 #include <string>
 #include <QtGlobal>
+#include "../drw_base.h"
 
 class QTextCodec;
 class QStringList;
@@ -15,10 +16,9 @@ public:
     std::string fromUtf8(const std::string &s);
     std::string toUtf8(const std::string &s);
     int getVersion() const {return version;}
-    void setVersion(std::string *v, bool dxfFormat);
-    void setVersion(int v, bool dxfFormat);
-    void setCodePage(const std::string *c, bool dxfFormat);
-    void setCodePage(const std::string &c, bool dxfFormat){setCodePage(&c, dxfFormat);}
+    void setVersion(const std::string &v, bool dxfFormat);
+    void setVersion(DRW::Version v, bool dxfFormat);
+    void setCodePage(const std::string &c, bool dxfFormat);
     std::string getCodePage() const {return cp;}
 
     static QMap<QString, QStringList> DXFCodePageMap();
@@ -29,9 +29,9 @@ private:
 
 private:
     Q_DISABLE_COPY(DRW_TextCodec)
-    int version;
-    std::string cp;
-    QTextCodec *conv;
+    DRW::Version version{DRW::UNKNOWNV};
+    std::string cp{};
+    QTextCodec *conv{nullptr};
 };
 
 #endif // DRW_TEXTCODEC_H
