@@ -14,6 +14,7 @@
 #define LIBDXFRW_H
 
 #include <string>
+#include <unordered_map>
 #include "drw_entities.h"
 #include "drw_objects.h"
 #include "drw_header.h"
@@ -27,7 +28,7 @@ class dxfRW {
 public:
     explicit dxfRW(const char* name);
     ~dxfRW();
-    static void setDebug(DRW::DBG_LEVEL lvl);
+    static void setDebug(DRW::DebugLevel lvl);
     /// reads the file specified in constructor
     /*!
      * An interface must be provided. It is used by the class to signal various
@@ -70,9 +71,12 @@ public:
     DRW_ImageDef *writeImage(DRW_Image *ent, const std::string &name);
     bool writeLeader(DRW_Leader *ent);
     bool writeDimension(DRW_Dimension *ent);
-    void setEllipseParts(int parts){elParts = parts;} /*!< set parts munber when convert ellipse to polyline */
+    void setEllipseParts(int parts){elParts = parts;} /*!< set parts number when convert ellipse to polyline */
+    bool writePlotSettings(DRW_PlotSettings *ent);
 
     std::string ErrorString() const;
+    DRW::Version getVersion() const;
+    DRW::error getError() const;
 
 private:
     Q_DISABLE_COPY(dxfRW)
@@ -115,6 +119,7 @@ private:
     bool processImageDef();
     bool processDimension();
     bool processLeader();
+    bool processPlotSettings();
 
 //    bool writeHeader();
     bool writeEntity(DRW_Entity *ent);
@@ -123,9 +128,13 @@ private:
     bool writeObjects();
     bool writeExtData(const std::vector<DRW_Variant*> &ed);
     static std::string toHexStr(int n);//RLZ removeme
+    bool writeAppData(const std::list<std::list<DRW_Variant>> &appData);
+
+    bool setError(const DRW::error lastError);
 
 private:
     DRW::Version version;
+    DRW::error error {DRW::BAD_NONE};
     std::string fileName;
     std::string codePage;
     bool binFile;
@@ -140,8 +149,8 @@ private:
     bool dimstyleStd;
     bool applyExt;
     bool writingBlock;
-    int elParts;  /*!< parts munber when convert ellipse to polyline */
-    std::map<std::string,int> blockMap;
+    int elParts;  /*!< parts number when convert ellipse to polyline */
+    std::unordered_map<std::string,int> blockMap;
     std::vector<DRW_ImageDef*> imageDef;  /*!< imageDef list */
 
     int currHandle;
