@@ -162,7 +162,7 @@ void VDxfEngine::drawPath(const QPainterPath &path)
 {
     const QList<QPolygonF> subpaths = path.toSubpathPolygons(matrix);
 
-    for (auto polygon : subpaths)
+    for (const auto& polygon : subpaths)
     {
         if (polygon.isEmpty())
         {
@@ -171,13 +171,13 @@ void VDxfEngine::drawPath(const QPainterPath &path)
 
         if (m_version > DRW::AC1009)
         { // Use lwpolyline
-            DRW_LWPolyline *poly = new DRW_LWPolyline();
+            auto *poly = new DRW_LWPolyline();
             poly->layer = '0';
             poly->color = getPenColor();
             poly->lWeight = DRW_LW_Conv::widthByLayer;
             poly->lineType = getPenStyle();
 
-            if (polygon.size() > 1 && polygon.first() == polygon.last())
+            if (polygon.size() > 1 && ConstFirst<QPointF>(polygon) == ConstLast<QPointF>(polygon))
             {
                 poly->flags |= 0x1; // closed
             }
@@ -194,12 +194,12 @@ void VDxfEngine::drawPath(const QPainterPath &path)
         }
         else
         { // Use polyline
-            DRW_Polyline *poly = new DRW_Polyline();
+            auto *poly = new DRW_Polyline();
             poly->layer = '0';
             poly->color = getPenColor();
             poly->lWeight = DRW_LW_Conv::widthByLayer;
             poly->lineType = getPenStyle();
-            if (polygon.size() > 1 && polygon.first() == polygon.last())
+            if (polygon.size() > 1 && ConstFirst<QPointF>(polygon) == ConstLast<QPointF>(polygon))
             {
                 poly->flags |= 0x1; // closed
             }
@@ -727,7 +727,7 @@ void VDxfEngine::ExportAAMADraw(dx_ifaceBlock *detailBlock, const VLayoutPiece &
         }
     }
 
-    const QVector<QVector<QPointF>> drawIntCut = detail.InternalPathsForCut(false);
+    const QVector<QVector<QPointF>> drawIntCut = detail.MappedInternalPathsForCut(false);
     for(auto &intCut : drawIntCut)
     {
         if (DRW_Entity *e = AAMAPolygon(intCut, QChar('8'), false))
@@ -736,7 +736,7 @@ void VDxfEngine::ExportAAMADraw(dx_ifaceBlock *detailBlock, const VLayoutPiece &
         }
     }
 
-    const QVector<VLayoutPlaceLabel> labels = detail.GetPlaceLabels();
+    const QVector<VLayoutPlaceLabel> labels = detail.GetMappedPlaceLabels();
     for(auto &label : labels)
     {
         if (label.type != PlaceLabelType::Doubletree && label.type != PlaceLabelType::Button
@@ -756,7 +756,7 @@ void VDxfEngine::ExportAAMADraw(dx_ifaceBlock *detailBlock, const VLayoutPiece &
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportAAMAIntcut(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    QVector<QVector<QPointF>> drawIntCut = detail.InternalPathsForCut(true);
+    QVector<QVector<QPointF>> drawIntCut = detail.MappedInternalPathsForCut(true);
     for(auto &intCut : drawIntCut)
     {
         if (DRW_Entity *e = AAMAPolygon(intCut, "11", false))
@@ -771,7 +771,7 @@ void VDxfEngine::ExportAAMANotch(dx_ifaceBlock *detailBlock, const VLayoutPiece
 {
     if (detail.IsSeamAllowance())
     {
-        const QVector<VLayoutPassmark> passmarks = detail.GetPassmarks();
+        const QVector<VLayoutPassmark> passmarks = detail.GetMappedPassmarks();
         for(auto &passmark : passmarks)
         {
             for (auto &line : passmark.lines)
@@ -788,10 +788,10 @@ void VDxfEngine::ExportAAMANotch(dx_ifaceBlock *detailBlock, const VLayoutPiece
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportAAMAGrainline(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    const QVector<QPointF> grainline = detail.GetGrainline();
+    const QVector<QPointF> grainline = detail.GetMappedGrainline();
     if (grainline.count() > 1)
     {
-        if (DRW_Entity *e = AAMALine(QLineF(grainline.first(), grainline.last()), QChar('7')))
+        if (DRW_Entity *e = AAMALine(QLineF(ConstFirst(grainline), ConstLast(grainline)), QChar('7')))
         {
             detailBlock->ent.push_back(e);
         }
@@ -833,7 +833,7 @@ void VDxfEngine::ExportStyleSystemText(const QSharedPointer<dx_iface> &input, co
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportAAMADrill(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    const QVector<VLayoutPlaceLabel> labels = detail.GetPlaceLabels();
+    const QVector<VLayoutPlaceLabel> labels = detail.GetMappedPlaceLabels();
 
     for(auto &label : labels)
     {
@@ -953,7 +953,7 @@ void VDxfEngine::ExportASTMSewLine(dx_ifaceBlock *detailBlock, const VLayoutPiec
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportASTMInternalLine(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    const QVector<QVector<QPointF>> drawIntCut = detail.InternalPathsForCut(false);
+    const QVector<QVector<QPointF>> drawIntCut = detail.MappedInternalPathsForCut(false);
     for(auto &intCut : drawIntCut)
     {
         // Internal line
@@ -969,7 +969,7 @@ void VDxfEngine::ExportASTMInternalLine(dx_ifaceBlock *detailBlock, const VLayou
         }
     }
 
-    const QVector<VLayoutPlaceLabel> labels = detail.GetPlaceLabels();
+    const QVector<VLayoutPlaceLabel> labels = detail.GetMappedPlaceLabels();
     for(auto &label : labels)
     {
         if (label.type != PlaceLabelType::Doubletree && label.type != PlaceLabelType::Button
@@ -996,7 +996,7 @@ void VDxfEngine::ExportASTMInternalLine(dx_ifaceBlock *detailBlock, const VLayou
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportASTMInternalCutout(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    QVector<QVector<QPointF>> drawIntCut = detail.InternalPathsForCut(true);
+    QVector<QVector<QPointF>> drawIntCut = detail.MappedInternalPathsForCut(true);
     for(auto &intCut : drawIntCut)
     {
         // Internal cutout
@@ -1026,7 +1026,7 @@ void VDxfEngine::ExportASTMAnnotationText(dx_ifaceBlock *detailBlock, const VLay
 //---------------------------------------------------------------------------------------------------------------------
 void VDxfEngine::ExportASTMDrill(dx_ifaceBlock *detailBlock, const VLayoutPiece &detail)
 {
-    const QVector<VLayoutPlaceLabel> labels = detail.GetPlaceLabels();
+    const QVector<VLayoutPlaceLabel> labels = detail.GetMappedPlaceLabels();
 
     for(auto &label : labels)
     {
@@ -1053,7 +1053,7 @@ void VDxfEngine::ExportASTMNotch(dx_ifaceBlock *detailBlock, const VLayoutPiece
 {
     if (detail.IsSeamAllowance())
     {
-        const QVector<VLayoutPassmark> passmarks = detail.GetPassmarks();
+        const QVector<VLayoutPassmark> passmarks = detail.GetMappedPassmarks();
         for(auto &passmark : passmarks)
         {
             DRW_ASTMNotch *notch = new DRW_ASTMNotch();
@@ -1072,22 +1072,22 @@ void VDxfEngine::ExportASTMNotch(dx_ifaceBlock *detailBlock, const VLayoutPiece
             }
             else if (passmark.type == PassmarkLineType::VMark || passmark.type == PassmarkLineType::VMark2)
             {
-                QLineF boundaryLine = QLineF(passmark.lines.first().p2(), passmark.lines.last().p2());
+                QLineF boundaryLine(ConstFirst(passmark.lines).p2(), ConstLast(passmark.lines).p2());
                 notch->thickness = FromPixel(boundaryLine.length(), varInsunits); // width
 
                 notch->layer = "4";
             }
             else if (passmark.type == PassmarkLineType::TMark)
             {
-                qreal width = FromPixel(passmark.lines.last().length(), varInsunits);
+                qreal width = FromPixel(ConstLast(passmark.lines).length(), varInsunits);
                 notch->thickness = FromPixel(width, varInsunits);
 
                 notch->layer = "80";
             }
             else if (passmark.type == PassmarkLineType::BoxMark)
             {
-                QPointF start = passmark.lines.first().p1();
-                QPointF end = passmark.lines.last().p2();
+                QPointF start = ConstFirst(passmark.lines).p1();
+                QPointF end = ConstLast(passmark.lines).p2();
 
                 notch->layer = "81";
 
@@ -1095,8 +1095,8 @@ void VDxfEngine::ExportASTMNotch(dx_ifaceBlock *detailBlock, const VLayoutPiece
             }
             else if (passmark.type == PassmarkLineType::UMark)
             {
-                QPointF start = passmark.lines.first().p1();
-                QPointF end = passmark.lines.last().p2();
+                QPointF start = ConstFirst(passmark.lines).p1();
+                QPointF end = ConstLast(passmark.lines).p2();
 
                 notch->thickness = FromPixel(QLineF(start, end).length(), varInsunits);
 
@@ -1184,7 +1184,7 @@ P *VDxfEngine::CreateAAMAPolygon(const QVector<QPointF> &polygon, const QString
     }
     else
     {
-        if (polygon.size() > 1 && polygon.first() == polygon.last())
+        if (polygon.size() > 1 && ConstFirst<QPointF>(polygon) == ConstLast<QPointF>(polygon))
         {
             poly->flags |= 0x1; // closed
         }
