@@ -55,6 +55,7 @@
 #include "../vpatterndb/measurements.h"
 #include "../vpatterndb/pmsystems.h"
 #include "../vmisc/projectversion.h"
+#include "def.h"
 
 const QString VMeasurements::TagVST              = QStringLiteral("vst");
 const QString VMeasurements::TagVIT              = QStringLiteral("vit");
@@ -96,6 +97,7 @@ const QString VMeasurements::AttrCircumference     = QStringLiteral("circumferen
 const QString VMeasurements::AttrFullCircumference = QStringLiteral("fullCircumference");
 const QString VMeasurements::AttrLabel             = QStringLiteral("label");
 const QString VMeasurements::AttrDimension         = QStringLiteral("dimension");
+const QString VMeasurements::AttrCustomName        = QStringLiteral("customName");
 
 const QString VMeasurements::GenderMale    = QStringLiteral("male");
 const QString VMeasurements::GenderFemale  = QStringLiteral("female");
@@ -174,7 +176,7 @@ bool VMeasurements::SaveDocument(const QString &fileName, QString &error)
 //---------------------------------------------------------------------------------------------------------------------
 void VMeasurements::AddEmpty(const QString &name, const QString &formula)
 {
-    const QDomElement element = MakeEmpty(name, formula);
+    const QDomElement element = MakeEmpty(name, formula, MeasurementType::Measurement);
 
     const QDomNodeList list = elementsByTagName(TagBodyMeasurements);
     list.at(0).appendChild(element);
@@ -183,7 +185,34 @@ void VMeasurements::AddEmpty(const QString &name, const QString &formula)
 //---------------------------------------------------------------------------------------------------------------------
 void VMeasurements::AddEmptyAfter(const QString &after, const QString &name, const QString &formula)
 {
-    const QDomElement element = MakeEmpty(name, formula);
+    const QDomElement element = MakeEmpty(name, formula, MeasurementType::Measurement);
+    const QDomElement sibling = FindM(after);
+
+    const QDomNodeList list = elementsByTagName(TagBodyMeasurements);
+
+    if (sibling.isNull())
+    {
+        list.at(0).appendChild(element);
+    }
+    else
+    {
+        list.at(0).insertAfter(element, sibling);
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VMeasurements::AddSeparator(const QString &name)
+{
+    const QDomElement element = MakeEmpty(name, QString(), MeasurementType::Separator);
+
+    const QDomNodeList list = elementsByTagName(TagBodyMeasurements);
+    list.at(0).appendChild(element);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VMeasurements::AddSeparatorAfter(const QString &after, const QString &name)
+{
+    const QDomElement element = MakeEmpty(name, QString(), MeasurementType::Separator);
     const QDomElement sibling = FindM(after);
 
     const QDomNodeList list = elementsByTagName(TagBodyMeasurements);
@@ -307,94 +336,105 @@ void VMeasurements::ReadMeasurements(qreal baseA, qreal baseB, qreal baseC) cons
 
         const QString name = GetParametrString(dom, AttrName).simplified();
         const QString description = GetParametrEmptyString(dom, AttrDescription);
-        const QString fullName = GetParametrEmptyString(dom, AttrFullName);
-        const bool specialUnits = GetParametrBool(dom, AttrSpecialUnits, falseStr);
+        const MeasurementType varType = StringToMeasurementType(GetParametrString(dom, AttrType, strTypeMeasurement));
 
         QSharedPointer<VMeasurement> meash;
         QSharedPointer<VMeasurement> tempMeash;
-        if (type == MeasurementsType::Multisize)
+
+        if (varType != MeasurementType::Separator)
         {
-            qreal base = GetParametrDouble(dom, AttrBase, QChar('0'));
-            qreal shiftA = GetParametrDouble(dom, AttrShiftA, QChar('0'));
-            qreal shiftB = GetParametrDouble(dom, AttrShiftB, QChar('0'));
-            qreal shiftC = GetParametrDouble(dom, AttrShiftC, QChar('0'));
-            QMap<QString, qreal> corrections = ReadCorrections(dom);
+            const QString fullName = GetParametrEmptyString(dom, AttrFullName);
+            const bool specialUnits = GetParametrBool(dom, AttrSpecialUnits, falseStr);
 
-            qreal convertedBaseA = DimensionABase();
-            qreal convertedBaseB = DimensionBBase();
-            qreal convertedBaseC = DimensionCBase();
-            qreal convertedStepA = DimensionAStep();
-            qreal convertedStepB = DimensionBStep();
-            qreal convertedStepC = DimensionCStep();
-
-            if (not specialUnits)
+            if (type == MeasurementsType::Multisize)
             {
-                base = UnitConvertor(base, Units(), *data->GetPatternUnit());
-                shiftA = UnitConvertor(shiftA, Units(), *data->GetPatternUnit());
-                shiftB = UnitConvertor(shiftB, Units(), *data->GetPatternUnit());
-                shiftC = UnitConvertor(shiftC, Units(), *data->GetPatternUnit());
+                qreal base = GetParametrDouble(dom, AttrBase, QChar('0'));
+                qreal shiftA = GetParametrDouble(dom, AttrShiftA, QChar('0'));
+                qreal shiftB = GetParametrDouble(dom, AttrShiftB, QChar('0'));
+                qreal shiftC = GetParametrDouble(dom, AttrShiftC, QChar('0'));
+                QMap<QString, qreal> corrections = ReadCorrections(dom);
 
-                QMutableMapIterator<QString, qreal> iterator(corrections);
-                while (iterator.hasNext())
+                qreal convertedBaseA = DimensionABase();
+                qreal convertedBaseB = DimensionBBase();
+                qreal convertedBaseC = DimensionCBase();
+                qreal convertedStepA = DimensionAStep();
+                qreal convertedStepB = DimensionBStep();
+                qreal convertedStepC = DimensionCStep();
+
+                if (not specialUnits)
                 {
-                    iterator.next();
-                    iterator.setValue(UnitConvertor(iterator.value(), Units(), *data->GetPatternUnit()));
+                    base = UnitConvertor(base, Units(), *data->GetPatternUnit());
+                    shiftA = UnitConvertor(shiftA, Units(), *data->GetPatternUnit());
+                    shiftB = UnitConvertor(shiftB, Units(), *data->GetPatternUnit());
+                    shiftC = UnitConvertor(shiftC, Units(), *data->GetPatternUnit());
+
+                    QMutableMapIterator<QString, qreal> iterator(corrections);
+                    while (iterator.hasNext())
+                    {
+                        iterator.next();
+                        iterator.setValue(UnitConvertor(iterator.value(), Units(), *data->GetPatternUnit()));
+                    }
+
+                    convertedBaseA = UnitConvertor(convertedBaseA, Units(), *data->GetPatternUnit());
+                    convertedBaseB = UnitConvertor(convertedBaseB, Units(), *data->GetPatternUnit());
+                    convertedBaseC = UnitConvertor(convertedBaseC, Units(), *data->GetPatternUnit());
+
+                    convertedStepA = UnitConvertor(convertedStepA, Units(), *data->GetPatternUnit());
+                    convertedStepB = UnitConvertor(convertedStepB, Units(), *data->GetPatternUnit());
+                    convertedStepC = UnitConvertor(convertedStepC, Units(), *data->GetPatternUnit());
                 }
 
-                convertedBaseA = UnitConvertor(convertedBaseA, Units(), *data->GetPatternUnit());
-                convertedBaseB = UnitConvertor(convertedBaseB, Units(), *data->GetPatternUnit());
-                convertedBaseC = UnitConvertor(convertedBaseC, Units(), *data->GetPatternUnit());
+                meash = QSharedPointer<VMeasurement>::create(static_cast<quint32>(i), name,
+                                                             convertedBaseA, convertedBaseB, convertedBaseC, base);
+                meash->SetBaseA(baseA);
+                meash->SetBaseB(baseB);
+                meash->SetBaseC(baseC);
 
-                convertedStepA = UnitConvertor(convertedStepA, Units(), *data->GetPatternUnit());
-                convertedStepB = UnitConvertor(convertedStepB, Units(), *data->GetPatternUnit());
-                convertedStepC = UnitConvertor(convertedStepC, Units(), *data->GetPatternUnit());
+                meash->SetShiftA(shiftA);
+                meash->SetShiftB(shiftB);
+                meash->SetShiftC(shiftC);
+
+                meash->SetStepA(convertedStepA);
+                meash->SetStepB(convertedStepB);
+                meash->SetStepC(convertedStepC);
+
+                meash->SetSpecialUnits(specialUnits);
+                meash->SetCorrections(corrections);
+                meash->SetGuiText(fullName);
+                meash->SetDescription(description);
             }
+            else
+            {
+                const IMD dimension =
+                    VMeasurements::StrToIMD(GetParametrString(dom, AttrDimension, VMeasurements::IMDToStr(IMD::N)));
+                const QString formula = GetParametrString(dom, AttrValue, QChar('0'));
+                bool ok = false;
+                qreal value = EvalFormula(tempData.data(), formula, &ok);
 
-            meash = QSharedPointer<VMeasurement>::create(static_cast<quint32>(i), name,
-                                                         convertedBaseA, convertedBaseB, convertedBaseC, base);
-            meash->SetBaseA(baseA);
-            meash->SetBaseB(baseB);
-            meash->SetBaseC(baseC);
+                tempMeash = QSharedPointer<VMeasurement>::create(tempData.data(), static_cast<quint32>(i), name, value,
+                                                                 formula, ok);
 
-            meash->SetShiftA(shiftA);
-            meash->SetShiftB(shiftB);
-            meash->SetShiftC(shiftC);
+                if (not specialUnits)
+                {
+                    value = UnitConvertor(value, Units(), *data->GetPatternUnit());
+                }
 
-            meash->SetStepA(convertedStepA);
-            meash->SetStepB(convertedStepB);
-            meash->SetStepC(convertedStepC);
-
-            meash->SetSpecialUnits(specialUnits);
-            meash->SetCorrections(corrections);
-            meash->SetGuiText(fullName);
-            meash->SetDescription(description);
+                meash = QSharedPointer<VMeasurement>::create(data, static_cast<quint32>(i), name, value, formula, ok);
+                meash->SetGuiText(fullName);
+                meash->SetDescription(description);
+                meash->SetSpecialUnits(specialUnits);
+                meash->SetDimension(dimension);
+            }
         }
         else
         {
-            const IMD dimension =
-                VMeasurements::StrToIMD(GetParametrString(dom, AttrDimension, VMeasurements::IMDToStr(IMD::N)));
-            const QString formula = GetParametrString(dom, AttrValue, QChar('0'));
-            bool ok = false;
-            qreal value = EvalFormula(tempData.data(), formula, &ok);
-
-            tempMeash = QSharedPointer<VMeasurement>::create(tempData.data(), static_cast<quint32>(i), name, value,
-                                                             formula, ok);
-
-            if (not specialUnits)
-            {
-                value = UnitConvertor(value, Units(), *data->GetPatternUnit());
-            }
-
-            meash = QSharedPointer<VMeasurement>::create(data, static_cast<quint32>(i), name, value, formula, ok);
-            meash->SetGuiText(fullName);
+            meash = QSharedPointer<VMeasurement>::create(static_cast<quint32>(i), name);
             meash->SetDescription(description);
-            meash->SetSpecialUnits(specialUnits);
-            meash->SetDimension(dimension);
         }
 
         if (m_keepNames)
         {
-            if (not tempData.isNull())
+            if (not tempData.isNull() && not tempMeash.isNull())
             {
                 tempData->AddUniqueVariable(tempMeash);
             }
@@ -402,7 +442,7 @@ void VMeasurements::ReadMeasurements(qreal baseA, qreal baseB, qreal baseC) cons
         }
         else
         {
-            if (not tempData.isNull())
+            if (not tempData.isNull() && not tempMeash.isNull())
             {
                 tempData->AddVariable(tempMeash);
             }
@@ -649,7 +689,7 @@ void VMeasurements::SetFullCircumference(bool fc)
     QDomElement dimenstionsTag = documentElement().firstChildElement(TagDimensions);
     if (not dimenstionsTag.isNull())
     {
-        SetAttributeOrRemoveIf(dimenstionsTag, AttrFullCircumference, fc, not fc);
+        SetAttributeOrRemoveIf<bool>(dimenstionsTag, AttrFullCircumference, fc, [](bool fc) noexcept {return not fc;});
     }
     else
     {
@@ -747,7 +787,7 @@ void VMeasurements::SetMSpecialUnits(const QString &name, bool special)
     QDomElement node = FindM(name);
     if (not node.isNull())
     {
-        SetAttributeOrRemoveIf(node, AttrSpecialUnits, special, not special);
+        SetAttributeOrRemoveIf<bool>(node, AttrSpecialUnits, special, [](bool special) noexcept {return not special;});
     }
     else
     {
@@ -819,7 +859,9 @@ void VMeasurements::SetMDimension(const QString &name, IMD type)
     QDomElement node = FindM(name);
     if (not node.isNull())
     {
-        SetAttributeOrRemoveIf(node, AttrDimension, VMeasurements::IMDToStr(type), type == IMD::N);
+        SetAttributeOrRemoveIf<QString>(node, AttrDimension, VMeasurements::IMDToStr(type),
+                                        [](const QString &type) noexcept
+        {return type == VMeasurements::IMDToStr(IMD::N);});
     }
     else
     {
@@ -844,7 +886,7 @@ QString VMeasurements::MeasurementForDimension(IMD type) const
             }
         }
     }
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -893,10 +935,12 @@ void VMeasurements::SetRestrictions(const QMap<QString, VDimensionRestriction> &
         QDomElement restrictionTag = createElement(TagRestriction);
 
         SetAttribute(restrictionTag, AttrCoordinates, i.key());
-        SetAttributeOrRemoveIf(restrictionTag, AttrMin, i.value().GetMin(), qFuzzyIsNull(i.value().GetMin()));
-        SetAttributeOrRemoveIf(restrictionTag, AttrMax, i.value().GetMax(), qFuzzyIsNull(i.value().GetMax()));
-        SetAttributeOrRemoveIf(restrictionTag, AttrExclude, i.value().GetExcludeString(),
-                               i.value().GetExcludeString().isEmpty());
+        SetAttributeOrRemoveIf<qreal>(restrictionTag, AttrMin, i.value().GetMin(),
+                                      [](qreal min) noexcept {return qFuzzyIsNull(min);});
+        SetAttributeOrRemoveIf<qreal>(restrictionTag, AttrMax, i.value().GetMax(),
+                                      [](qreal max) noexcept {return qFuzzyIsNull(max);});
+        SetAttributeOrRemoveIf<QString>(restrictionTag, AttrExclude, i.value().GetExcludeString(),
+                                        [](const QString &exlcuded) noexcept {return exlcuded.isEmpty();});
 
         restrictionsTag.appendChild(restrictionTag);
         ++i;
@@ -929,6 +973,25 @@ void VMeasurements::SetDimensionLabels(const QMap<MeasurementDimension, Dimesion
     m_dimensions = ReadDimensions(); // Refresh cache
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VMeasurements::SetDimensionCustomNames(const QMap<MeasurementDimension, QString> &names)
+{
+    const QDomNodeList list = elementsByTagName(TagDimension);
+    for (int i=0; i < list.size(); ++i)
+    {
+        QDomElement dom = list.at(i).toElement();
+        const MeasurementDimension type = StrToDimensionType(GetParametrString(dom, AttrType));
+
+        if (names.contains(type))
+        {
+            SetAttributeOrRemoveIf<QString>(dom, AttrCustomName, names.value(type),
+                                            [](const QString &name) noexcept {return name.isEmpty();});
+        }
+    }
+
+    m_dimensions = ReadDimensions(); // Refresh cache
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QString VMeasurements::GenderToStr(const GenderType &sex)
 {
@@ -1042,15 +1105,15 @@ QString VMeasurements::IMDName(IMD type)
         case IMD::N:
             return tr("None");
         case IMD::X:
-            return tr("Height");
+            return tr("Height") + " (X)";
         case IMD::Y:
-            return tr("Size");
+            return tr("Size") + " (Y)";
         case IMD::W:
-            return tr("Waist");
+            return tr("Waist") + " (W)";
         case IMD::Z:
-            return tr("Hip");
+            return tr("Hip") + " (Z)";
         default:
-            return QString();
+            return {};
     }
 }
 
@@ -1180,7 +1243,7 @@ QDomElement VMeasurements::CreateDimensions(const QVector<MeasurementDimension_p
 {
     QDomElement dimensionsTag = createElement(TagDimensions);
 
-    for(auto &dimension : dimensions)
+    for(const auto &dimension : dimensions)
     {
         QDomElement dimensionTag = createElement(TagDimension);
 
@@ -1189,11 +1252,10 @@ QDomElement VMeasurements::CreateDimensions(const QVector<MeasurementDimension_p
         SetAttribute(dimensionTag, AttrMin, dimension->MinValue());
         SetAttribute(dimensionTag, AttrMax, dimension->MaxValue());
         SetAttribute(dimensionTag, AttrStep, dimension->Step());
-
-        if (dimension->Type() == MeasurementDimension::Y)
-        {
-            SetAttribute(dimensionTag, AttrCircumference, dimension->IsCircumference());
-        }
+        SetAttributeOrRemoveIf<bool>(dimensionTag, AttrCircumference, dimension->IsCircumference(),
+                                     [](bool c) noexcept {return c;});
+        SetAttributeOrRemoveIf<QString>(dimensionTag, AttrCustomName, dimension->CustomName(),
+                                     [](const QString &name) noexcept {return name.isEmpty();});
 
         dimensionsTag.appendChild(dimensionTag);
     }
@@ -1227,19 +1289,26 @@ qreal VMeasurements::UniqueTagAttr(const QString &tag, const QString &attr, qrea
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VMeasurements::MakeEmpty(const QString &name, const QString &formula)
+QDomElement VMeasurements::MakeEmpty(const QString &name, const QString &formula, MeasurementType varType)
 {
     QDomElement element = createElement(TagMeasurement);
 
     SetAttribute(element, AttrName, name);
 
-    if (type == MeasurementsType::Multisize)
+    if (varType == MeasurementType::Measurement)
     {
-        SetAttribute(element, AttrBase, QChar('0'));
+        if (type == MeasurementsType::Multisize)
+        {
+            SetAttribute(element, AttrBase, QChar('0'));
+        }
+        else
+        {
+            SetAttribute(element, AttrValue, formula.isEmpty() ? QChar('0') : formula);
+        }
     }
     else
     {
-        SetAttribute(element, AttrValue, formula.isEmpty() ? QChar('0') : formula);
+        SetAttribute(element, AttrType, MeasurementTypeToString(varType));
     }
 
     return element;
@@ -1322,39 +1391,35 @@ auto VMeasurements::ReadDimensions() const -> VDimensions
         const qreal min = GetParametrDouble(dom, AttrMin, QChar('0'));
         const qreal max = GetParametrDouble(dom, AttrMax, QChar('0'));
         const qreal step = GetParametrDouble(dom, AttrStep, QStringLiteral("-1"));
-        const qreal base = GetParametrDouble(dom, AttrBase, QChar('0'));
 
-        const DimesionLabels labels = ReadDimensionLabels(dom);
+        MeasurementDimension_p dimension;
 
         if (type == MeasurementDimension::X)
         {
-            auto dimension = QSharedPointer<VXMeasurementDimension>::create(units, min, max, step);
-            dimension->SetBaseValue(base);
-            dimension->SetLabels(labels);
-            dimensions.insert(type, dimension);
+            dimension = QSharedPointer<VXMeasurementDimension>::create(units, min, max, step);
         }
         else if (type == MeasurementDimension::Y)
         {
-            auto dimension = QSharedPointer<VYMeasurementDimension>::create(units, min, max, step);
-            dimension->SetBaseValue(base);
-            dimension->SetCircumference(GetParametrBool(dom, AttrCircumference, trueStr));
-            dimension->SetLabels(labels);
-            dimensions.insert(type, dimension);
+            dimension = QSharedPointer<VYMeasurementDimension>::create(units, min, max, step);
         }
         else if (type == MeasurementDimension::W)
         {
-            auto dimension = QSharedPointer<VWMeasurementDimension>::create(units, min, max, step);
-            dimension->SetBaseValue(base);
-            dimension->SetLabels(labels);
-            dimensions.insert(type, dimension);
+            dimension = QSharedPointer<VWMeasurementDimension>::create(units, min, max, step);
         }
         else if (type == MeasurementDimension::Z)
         {
-            auto dimension = QSharedPointer<VZMeasurementDimension>::create(units, min, max, step);
-            dimension->SetBaseValue(base);
-            dimension->SetLabels(labels);
-            dimensions.insert(type, dimension);
+            dimension = QSharedPointer<VZMeasurementDimension>::create(units, min, max, step);
         }
+        else
+        {
+            continue;
+        }
+
+        dimension->SetBaseValue(GetParametrDouble(dom, AttrBase, QChar('0')));
+        dimension->SetCircumference(GetParametrBool(dom, AttrCircumference, trueStr));
+        dimension->SetCustomName(GetParametrEmptyString(dom, AttrCustomName));
+        dimension->SetLabels(ReadDimensionLabels(dom));
+        dimensions.insert(type, dimension);
     }
 
     return dimensions;
