@@ -61,6 +61,8 @@ public:
 
     void AddEmpty(const QString &name, const QString &formula = QString());
     void AddEmptyAfter(const QString &after, const QString &name, const QString &formula = QString());
+    void AddSeparator(const QString &name);
+    void AddSeparatorAfter(const QString &after, const QString &name);
     void Remove(const QString &name);
     void MoveTop(const QString &name);
     void MoveUp(const QString &name);
@@ -128,6 +130,7 @@ public:
     auto Restriction(qreal base, qreal base2=0) const -> VDimensionRestriction;
 
     void SetDimensionLabels(const QMap<MeasurementDimension, DimesionLabels> &labels);
+    void SetDimensionCustomNames(const QMap<MeasurementDimension, QString> &names);
 
     static const QString TagVST;
     static const QString TagVIT;
@@ -169,6 +172,7 @@ public:
     static const QString AttrFullCircumference;
     static const QString AttrLabel;
     static const QString AttrDimension;
+    static const QString AttrCustomName;
 
     static const QString GenderMale;
     static const QString GenderFemale;
@@ -219,7 +223,7 @@ private:
 
     qreal UniqueTagAttr(const QString &tag, const QString &attr, qreal defValue) const;
 
-    QDomElement MakeEmpty(const QString &name, const QString &formula);
+    QDomElement MakeEmpty(const QString &name, const QString &formula, MeasurementType varType);
     QDomElement FindM(const QString &name) const;
     MeasurementsType ReadType() const;
     auto ReadUnits() const -> Unit;
