@@ -87,7 +87,7 @@ VPatternRecipe::VPatternRecipe(VAbstractPattern *pattern, QObject *parent)
 
     QDomElement recipeElement = createElement(QStringLiteral("recipe"));
     recipeElement.appendChild(createComment(FileComment()));
-    SetAttribute(recipeElement, QStringLiteral("version"), QStringLiteral("1.3.0"));
+    SetAttribute(recipeElement, QStringLiteral("version"), QStringLiteral("1.3.1"));
 
     recipeElement.appendChild(Prerequisite());
     recipeElement.appendChild(Content());
@@ -135,7 +135,7 @@ QDomElement VPatternRecipe::Measurements()
     QDomElement measurements = createElement(QStringLiteral("measurements"));
 
     VContainer data = m_pattern->GetCompleteData();
-    QList<QSharedPointer<VMeasurement>> patternMeasurements = data.DataMeasurements().values();
+    QList<QSharedPointer<VMeasurement>> patternMeasurements = data.DataMeasurementsWithSeparators().values();
 
     // Resore order
     std::sort(patternMeasurements.begin(), patternMeasurements.end(),
@@ -160,11 +160,28 @@ QDomElement VPatternRecipe::Measurement(const QSharedPointer<VMeasurement> &m)
      */
     QDomElement measurement = createElement(QStringLiteral("measurement"));
 
-    SetAttribute(measurement, QStringLiteral("description"), m->GetDescription());
-    SetAttribute(measurement, QStringLiteral("fullName"), m->GetGuiText());
     SetAttribute(measurement, QStringLiteral("name"), m->GetName());
-    SetAttribute(measurement, QStringLiteral("formula"), m->GetFormula()); // TODO: localize
-    SetAttribute(measurement, QStringLiteral("value"), *m->GetValue());
+    SetAttribute(measurement, QStringLiteral("description"), m->GetDescription());
+
+    if (m->GetType() != VarType::MeasurementSeparator)
+    {
+        SetAttribute(measurement, QStringLiteral("fullName"), m->GetGuiText());
+
+        QString formula = m->GetFormula();
+        if (not formula.isEmpty())
+        {
+            SetAttribute(measurement, QStringLiteral("formula"), m->GetFormula());
+        }
+        else
+        {
+            SetAttribute(measurement, QStringLiteral("formula"), *m->GetValue());
+        }
+        SetAttribute(measurement, QStringLiteral("value"), *m->GetValue());
+    }
+    else
+    {
+        SetAttribute(measurement, QStringLiteral("separator"), true);
+    }
 
     return measurement;
 }
@@ -290,7 +307,7 @@ QDomElement VPatternRecipe::Draft(const QDomElement &draft)
 QDomElement VPatternRecipe::Step(const VToolRecord &tool, const VContainer &data)
 {
     // This check helps to find missed tools in the switch
-    Q_STATIC_ASSERT_X(static_cast<int>(Tool::LAST_ONE_DO_NOT_USE) == 55, "Not all tools were used in history.");
+    Q_STATIC_ASSERT_X(static_cast<int>(Tool::LAST_ONE_DO_NOT_USE) == 59, "Not all tools were used in history.");
 
     const QDomElement domElem = m_pattern->elementById(tool.getId());
     if (not domElem.isElement() && tool.IsMandatory())
@@ -311,6 +328,10 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
             case Tool::Cut:
             case Tool::Midpoint:// Same as Tool::AlongLine, but tool will never has such type
             case Tool::ArcIntersectAxis:// Same as Tool::CurveIntersectAxis, but tool will never has such type
+            case Tool::BackgroundImage:
+            case Tool::BackgroundImageControls:
+            case Tool::BackgroundPixmapImage:
+            case Tool::BackgroundSVGImage:
             case Tool::LAST_ONE_DO_NOT_USE:
                 Q_UNREACHABLE(); //-V501
                 break;
@@ -1117,7 +1138,8 @@ void VPatternRecipe::CurveAttributes(QDomElement &step, T *tool)
     SetAttribute(step, AttrPenStyle, tool->GetPenStyle());
     SetAttribute(step, AttrAScale, tool->GetApproximationScale());
     SetAttribute(step, AttrDuplicate, tool->GetDuplicate());
-    SetAttributeOrRemoveIf(step, AttrAlias, tool->GetAliasSuffix(), tool->GetAliasSuffix().isEmpty());
+    SetAttributeOrRemoveIf<QString>(step, AttrAlias, tool->GetAliasSuffix(),
+                                    [](const QString &suffix) noexcept {return suffix.isEmpty();});
 }
 
 
@@ -1125,8 +1147,10 @@ void VPatternRecipe::CurveAttributes(QDomElement &step, T *tool)
 template<typename T>
 void VPatternRecipe::CutCurveAttributes(QDomElement &step, T *tool)
 {
-    SetAttributeOrRemoveIf(step, AttrAlias1, tool->GetAliasSuffix1(), tool->GetAliasSuffix1().isEmpty());
-    SetAttributeOrRemoveIf(step, AttrAlias2, tool->GetAliasSuffix2(), tool->GetAliasSuffix2().isEmpty());
+    SetAttributeOrRemoveIf<QString>(step, AttrAlias1, tool->GetAliasSuffix1(),
+                                    [](const QString &suffix) noexcept {return suffix.isEmpty();});
+    SetAttributeOrRemoveIf<QString>(step, AttrAlias2, tool->GetAliasSuffix2(),
+                                    [](const QString &suffix) noexcept {return suffix.isEmpty();});
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1168,7 +1192,8 @@ QDomElement VPatternRecipe::GroupOperationSource(VAbstractOperation *tool, quint
         }
 
         SetAttribute(node, AttrItem, obj->ObjectName());
-        SetAttributeOrRemoveIf(node, AttrAlias, item.alias, item.alias.isEmpty());
+        SetAttributeOrRemoveIf<QString>(node, AttrAlias, item.alias,
+                                        [](const QString &alias) noexcept {return alias.isEmpty();});
 
         if (obj->getType() != GOType::Point)
         {
