@@ -39,6 +39,7 @@
 #include "../vmisc/vmath.h"
 #include "../vgeometry/vpointf.h"
 #include "../vmisc/vabstractapplication.h"
+#include "../ifc/exception/vexception.h"
 
 namespace
 {
@@ -365,12 +366,9 @@ QVector<QPointF> PointBezier_r(qreal x1, qreal y1, qreal x2, qreal y2, qreal x3,
         const QVector<QPointF> tail = BezierTailPoints();
         return futureBezier.result() + tail;
     }
-    else
-    {
-        return BezierPoints() + BezierTailPoints();
-    }
-}
+    return BezierPoints() + BezierTailPoints();
 }
+}  // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractCubicBezier::VAbstractCubicBezier(const GOType &type, const quint32 &idObject, const Draw &mode)
@@ -420,6 +418,11 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
     if (fullLength <= minLength)
     {
         spl1p2 = spl1p3 = spl2p2 = spl2p3 = QPointF();
+
+        const QString errorMsg = QObject::tr("Unable to cut curve '%1'. The curve is too short.").arg(name());
+        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
+                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+
         return QPointF();
     }
 
@@ -428,10 +431,20 @@ QPointF VAbstractCubicBezier::CutSpline(qreal length, QPointF &spl1p2, QPointF &
     if (length < minLength)
     {
         length = minLength;
+
+        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal "
+                                             "value.").arg(name());
+        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
+                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
     else if (length > maxLength)
     {
         length = maxLength;
+
+        const QString errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal "
+                                             "value.").arg(name());
+        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
+                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
 
     const qreal parT = GetParmT(length);
@@ -487,28 +500,38 @@ QString VAbstractCubicBezier::NameForHistory(const QString &toolName) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VAbstractCubicBezier::GetParmT(qreal length) const
+auto VAbstractCubicBezier::GetParmT(qreal length) const -> qreal
 {
+    const qreal base = GetRealLength();
     if (length < 0)
     {
         return 0;
     }
-    else if (length > GetLength())
+
+    if (length > base)
     {
-        length = GetLength();
+        length = base;
     }
 
-    const qreal eps = 0.001 * length;
+    Q_DECL_RELAXED_CONSTEXPR qreal eps = ToPixel(0.001, Unit::Mm);
     qreal parT = 0.5;
     qreal step = parT;
-    qreal splLength = LengthT(parT);
+    qreal splLength = 0;
 
-    while (qAbs(splLength - length) > eps)
+    do
     {
+        splLength = RealLengthByT(parT);
         step /= 2.0;
+
+        if (qFuzzyIsNull(step))
+        {
+            break;
+        }
+
         splLength > length ? parT -= step : parT += step;
-        splLength = LengthT(parT);
     }
+    while (qAbs(splLength - length) > eps);
+
     return parT;
 }
 
@@ -575,7 +598,7 @@ qreal VAbstractCubicBezier::LengthBezier(const QPointF &p1, const QPointF &p2, c
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VAbstractCubicBezier::LengthT(qreal t) const
+qreal VAbstractCubicBezier::RealLengthByT(qreal t) const
 {
     if (t < 0 || t > 1)
     {
@@ -606,5 +629,5 @@ qreal VAbstractCubicBezier::LengthT(qreal t) const
     seg123_234.setLength(seg123_234.length () * t);
     const QPointF p1234 = seg123_234.p2();
 
-    return LengthBezier ( static_cast<QPointF>(GetP1()), p12, p123, p1234, GetApproximationScale());
+    return LengthBezier ( static_cast<QPointF>(GetP1()), p12, p123, p1234, maxCurveApproximationScale);
 }
