@@ -95,8 +95,8 @@ QVector<QPointF> VAbstractCurve::GetSegmentPoints(const QVector<QPointF> &points
 
     if (begin == end)
     {
-        start = segment.first();
-        finish = segment.last();
+        start = ConstFirst(segment);
+        finish = ConstLast(segment);
     }
 
     bool ok = false;
@@ -157,7 +157,7 @@ QVector<QPointF> VAbstractCurve::FromBegin(const QVector<QPointF> &points, const
 {
     if (points.count() >= 2)
     {
-        if (points.first().toPoint() == begin.toPoint())
+        if (ConstFirst(points).toPoint() == begin.toPoint())
         {
             if (ok != nullptr)
             {
@@ -170,7 +170,7 @@ QVector<QPointF> VAbstractCurve::FromBegin(const QVector<QPointF> &points, const
         bool theBegin = false;
         for (qint32 i = 0; i < points.count()-1; ++i)
         {
-            if (theBegin == false)
+            if (not theBegin)
             {
                 if (IsPointOnLineSegment(begin, points.at(i), points.at(i+1)))
                 {
@@ -258,7 +258,7 @@ qreal VAbstractCurve::GetLengthByPoint(const QPointF &point) const
         return -1;
     }
 
-    if (points.first().toPoint() == point.toPoint())
+    if (ConstFirst(points).toPoint() == point.toPoint())
     {
         return 0;
     }
@@ -481,7 +481,7 @@ bool VAbstractCurve::CurveIntersectAxis(const QPointF &point, qreal angle, const
     axis = QLineF(point, VGObject::BuildRay(point, angle + 180, rec));
     points += VAbstractCurve::CurveIntersectLine(curvePoints, axis);
 
-    if (points.size() > 0)
+    if (not points.isEmpty())
     {
         if (points.size() == 1)
         {
@@ -516,11 +516,26 @@ bool VAbstractCurve::CurveIntersectAxis(const QPointF &point, qreal angle, const
             *intersectionPoint = points.at(forward.first());
             return true;
         }
-        else if (not backward.isEmpty())
+
+        if (not backward.isEmpty())
         {
             *intersectionPoint = points.at(backward.first());
             return true;
         }
+
+        if (VAbstractCurve::IsPointOnCurve(curvePoints, point))
+        {
+            *intersectionPoint = point;
+            return true;
+        }
+    }
+    else
+    {
+        if (VAbstractCurve::IsPointOnCurve(curvePoints, point))
+        {
+            *intersectionPoint = point;
+            return true;
+        }
     }
 
     return false;
