@@ -92,6 +92,16 @@ public:
     uint GetPriority() const;
     void SetPriority(uint value);
 
+    QUuid GetUUID() const;
+    void  SetUUID(const QUuid &uuid);
+    void  SetUUID(const QString &uuid);
+
+    /**
+     * @brief GetUniqueID returns unique piece id. Combines UUID and gradation label.
+     * @return unique piece id.
+     */
+    virtual QString GetUniqueID() const;
+
     static QVector<QPointF> Equidistant(QVector<VSAPoint> points, qreal width, const QString &name);
     static qreal            SumTrapezoids(const QVector<QPointF> &points);
     static QVector<QPointF> CheckLoops(const QVector<QPointF> &points);
@@ -212,9 +222,9 @@ QVector<T> VAbstractPiece::CorrectEquidistantPoints(const QVector<T> &points, bo
         }
     }
 
-    if (not buf2.isEmpty() && buf2.first() != buf2.last())
+    if (not buf2.isEmpty() && ConstFirst(buf2) != ConstLast(buf2))
     {
-        buf2.append(buf2.first());
+        buf2.append(ConstFirst(buf2));
     }
 
     buf2 = RemoveDublicates(buf2, false);
@@ -227,7 +237,28 @@ QVector<T> VAbstractPiece::CorrectEquidistantPoints(const QVector<T> &points, bo
 template <class T>
 QVector<T> VAbstractPiece::RemoveDublicates(const QVector<T> &points, bool removeFirstAndLast)
 {
-    QVector<T> p = points;
+    if (points.size() < 4)
+    {
+        return points;
+    }
+
+    QVector<T> p;
+    p.reserve(points.size());
+
+    p.append(ConstFirst(points));
+
+    for (int i = 0; i < points.size(); ++i)
+    {
+        for (int j = i+1; j < points.size(); ++j)
+        {
+            if (not VFuzzyComparePoints(points.at(i), points.at(j)))
+            {
+                p.append(points.at(j));
+                i = j-1;
+                break;
+            }
+        }
+    }
 
     if (removeFirstAndLast)
     {
@@ -235,29 +266,13 @@ QVector<T> VAbstractPiece::RemoveDublicates(const QVector<T> &points, bool remov
         {
             // Path can't be closed
             // See issue #686
-            if (VFuzzyComparePoints(p.first(), p.last()))
+            if (VFuzzyComparePoints(ConstFirst(p), ConstLast(p)))
             {
                 p.removeLast();
             }
         }
     }
 
-    for (int i = 0; i < p.size()-1; ++i)
-    {
-        if (VFuzzyComparePoints(p.at(i), p.at(i+1)))
-        {
-            if (not removeFirstAndLast && (i == p.size()-2))
-            {
-                p.erase(p.begin() + i);
-            }
-            else
-            {
-                p.erase(p.begin() + i + 1);
-            }
-            --i;
-        }
-    }
-
     return p;
 }
 
