@@ -45,6 +45,10 @@
 #include "../vmisc/def.h"
 #include "../vobj/vobjpaintdevice.h"
 #include "../vdxf/vdxfpaintdevice.h"
+#include "vrawlayout.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "../ifc/exception/vexception.h"
+#include "vprintlayout.h"
 
 namespace
 {
@@ -63,21 +67,18 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, (QLatin1String("pdftops")))
  *
  * @param placeholder placeholder that will be appended to each QGraphicsSimpleTextItem item's text string.
  */
-void PrepareTextForDXF(const QString &placeholder, const QList<QList<QGraphicsItem *> > &details)
+void PrepareTextForDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
 {
-    for (const auto &paperItems : details)
+    for (auto *item : paperItems)
     {
-        for (auto *item : paperItems)
+        QList<QGraphicsItem *> pieceChildren = item->childItems();
+        for (auto *child : qAsConst(pieceChildren))
         {
-            QList<QGraphicsItem *> pieceChildren = item->childItems();
-            for (auto *child : qAsConst(pieceChildren))
+            if (child->type() == QGraphicsSimpleTextItem::Type)
             {
-                if (child->type() == QGraphicsSimpleTextItem::Type)
+                if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
                 {
-                    if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
-                    {
-                        textItem->setText(textItem->text() + placeholder);
-                    }
+                    textItem->setText(textItem->text() + placeholder);
                 }
             }
         }
@@ -93,23 +94,20 @@ void PrepareTextForDXF(const QString &placeholder, const QList<QList<QGraphicsIt
  *
  * @param placeholder placeholder that will be removed from each QGraphicsSimpleTextItem item's text string.
  */
-void RestoreTextAfterDXF(const QString &placeholder, const QList<QList<QGraphicsItem *> > &details)
+void RestoreTextAfterDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
 {
-    for (const auto &paperItems : details)
+    for (auto *item : paperItems)
     {
-        for (auto *item : paperItems)
+        QList<QGraphicsItem *> pieceChildren = item->childItems();
+        for (auto *child : qAsConst(pieceChildren))
         {
-            QList<QGraphicsItem *> pieceChildren = item->childItems();
-            for (auto *child : qAsConst(pieceChildren))
+            if (child->type() == QGraphicsSimpleTextItem::Type)
             {
-                if (child->type() == QGraphicsSimpleTextItem::Type)
+                if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
                 {
-                    if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
-                    {
-                        QString text = textItem->text();
-                        text.replace(placeholder, QString());
-                        textItem->setText(text);
-                    }
+                    QString text = textItem->text();
+                    text.replace(placeholder, QString());
+                    textItem->setText(text);
                 }
             }
         }
@@ -206,46 +204,7 @@ void VLayoutExporter::ExportToTIF(QGraphicsScene *scene) const
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutExporter::ExportToPDF(QGraphicsScene *scene) const
 {
-    QPrinter printer;
-    printer.setCreator(QGuiApplication::applicationDisplayName() + QChar(QChar::Space) +
-                       QCoreApplication::applicationVersion());
-    printer.setOutputFormat(QPrinter::PdfFormat);
-    printer.setOutputFileName(m_fileName);
-    printer.setDocName(QFileInfo(m_fileName).fileName());
-    printer.setResolution(static_cast<int>(PrintDPI));
-    printer.setPageOrientation(QPageLayout::Portrait);
-    printer.setFullPage(m_ignorePrinterMargins);
-
-    qreal width = FromPixel(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right(), Unit::Mm);
-    qreal height = FromPixel(m_imageRect.height() * m_yScale + m_margins.top() + m_margins.bottom(), Unit::Mm);
-
-    if (not printer.setPageSize(QPageSize(QSizeF(width, height), QPageSize::Millimeter)))
-    {
-        qWarning() << tr("Cannot set printer page size");
-    }
-
-    const qreal left = FromPixel(m_margins.left(), Unit::Mm);
-    const qreal top = FromPixel(m_margins.top(), Unit::Mm);
-    const qreal right = FromPixel(m_margins.right(), Unit::Mm);
-    const qreal bottom = FromPixel(m_margins.bottom(), Unit::Mm);
-
-    if (not printer.setPageMargins(QMarginsF(left, top, right, bottom), QPageLayout::Millimeter))
-    {
-        qWarning() << tr("Cannot set printer margins");
-    }
-
-    QPainter painter;
-    if (not painter.begin(&printer))
-    { // failed to open file
-        qCritical() << qUtf8Printable(tr("Can't open file '%1'").arg(m_fileName));
-        return;
-    }
-    painter.setRenderHint(QPainter::Antialiasing, true);
-    painter.setPen(m_pen);
-    painter.setBrush(QBrush(Qt::NoBrush));
-    painter.scale(m_xScale, m_yScale);
-    scene->render(&painter, m_imageRect, m_imageRect, Qt::IgnoreAspectRatio);
-    painter.end();
+    ExportToPDF(scene, m_fileName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -268,8 +227,9 @@ void VLayoutExporter::ExportToPS(QGraphicsScene *scene) const
     QTemporaryFile tmp;
     if (tmp.open())
     {
-        ExportToPDF(scene);
-        PdfToPs(QStringList{tmp.fileName(), m_fileName});
+        const QString fileName = m_fileName;
+        ExportToPDF(scene, tmp.fileName());
+        PdfToPs(QStringList{tmp.fileName(), fileName});
     }
 }
 
@@ -279,13 +239,14 @@ void VLayoutExporter::ExportToEPS(QGraphicsScene *scene) const
     QTemporaryFile tmp;
     if (tmp.open())
     {
-        ExportToPDF(scene);
-        PdfToPs(QStringList{QStringLiteral("-eps"), tmp.fileName(), m_fileName});
+        const QString fileName = m_fileName;
+        ExportToPDF(scene, tmp.fileName());
+        PdfToPs(QStringList{QStringLiteral("-eps"), tmp.fileName(), fileName});
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToFlatDXF(QGraphicsScene *scene, const QList<QList<QGraphicsItem *> > &details) const
+void VLayoutExporter::ExportToFlatDXF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
     PrepareTextForDXF(endStringPlaceholder, details);
 
@@ -304,7 +265,7 @@ void VLayoutExporter::ExportToFlatDXF(QGraphicsScene *scene, const QList<QList<Q
         scene->render(&painter, m_imageRect, m_imageRect, Qt::IgnoreAspectRatio);
         if (not painter.end())
         {
-            qCritical() << tr("Can't create an flat dxf file.")
+            qCritical() << tr("Can't create a flat dxf file.")
                         << generator.ErrorString();
         }
     }
@@ -350,6 +311,29 @@ void VLayoutExporter::ExportToASTMDXF(const QVector<VLayoutPiece> &details) cons
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::ExportToRLD(const QVector<VLayoutPiece> &details) const
+{
+    QVector<VLayoutPiece> scaledPieces;
+    scaledPieces.reserve(details.size());
+
+    for(auto detail : details)
+    {
+        detail.Scale(m_xScale, m_yScale);
+        scaledPieces.append(detail);
+    }
+
+    VRawLayoutData layoutData;
+    layoutData.pieces = scaledPieces;
+
+    VRawLayout generator;
+    if (not generator.WriteFile(m_fileName, layoutData))
+    {
+        const QString errorMsg = tr("Export raw layout data failed. %1.").arg(generator.ErrorString());
+        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) : qCritical() << errorMsg;
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VLayoutExporter::SupportPDFConversion() -> bool
 {
@@ -382,7 +366,7 @@ QPointF VLayoutExporter::offset() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::SetOffset(QPointF newOffset)
+void VLayoutExporter::SetOffset(const QPointF &newOffset)
 {
     m_offset = newOffset;
 }
@@ -418,9 +402,208 @@ void VLayoutExporter::PdfToPs(const QStringList &params)
     QGuiApplication::restoreOverrideCursor();
 #endif
 
-    QFile f(params.last());
+    QFile f(ConstLast<QString>(params));
     if (not f.exists())
     {
-        qCritical() << qUtf8Printable(tr("Creating file '%1' failed! %2").arg(params.last(), proc.errorString()));
+        qCritical() << qUtf8Printable(tr("Creating file '%1' failed! %2")
+                                      .arg(ConstLast<QString>(params), proc.errorString()));
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QString &filename) const
+{
+    QPrinter printer;
+    printer.setCreator(QGuiApplication::applicationDisplayName() + QChar(QChar::Space) +
+                       QCoreApplication::applicationVersion());
+    printer.setOutputFormat(QPrinter::PdfFormat);
+    printer.setOutputFileName(filename);
+    printer.setDocName(QFileInfo(filename).fileName());
+    printer.setResolution(static_cast<int>(PrintDPI));
+    printer.setFullPage(m_ignorePrinterMargins);
+
+    QPageLayout::Orientation imageOrientation = m_imageRect.height() >= m_imageRect.width() ? QPageLayout::Portrait
+                                                                                            : QPageLayout::Landscape;
+
+    qreal width = FromPixel(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right(), Unit::Mm);
+    qreal height = FromPixel(m_imageRect.height() * m_yScale + m_margins.top() + m_margins.bottom(), Unit::Mm);
+
+    QSizeF pageSize = imageOrientation == QPageLayout::Portrait ? QSizeF(width, height) : QSizeF(height, width);
+    if (not printer.setPageSize(QPageSize(pageSize, QPageSize::Millimeter)))
+    {
+        qWarning() << tr("Cannot set printer page size");
+    }
+
+    printer.setPageOrientation(imageOrientation);
+
+    if (not m_ignorePrinterMargins)
+    {
+        const qreal left = FromPixel(m_margins.left(), Unit::Mm);
+        const qreal top = FromPixel(m_margins.top(), Unit::Mm);
+        const qreal right = FromPixel(m_margins.right(), Unit::Mm);
+        const qreal bottom = FromPixel(m_margins.bottom(), Unit::Mm);
+
+        if (not printer.setPageMargins(QMarginsF(left, top, right, bottom), QPageLayout::Millimeter))
+        {
+            qWarning() << tr("Cannot set printer margins");
+        }
+    }
+
+    QPainter painter;
+    if (not painter.begin(&printer))
+    { // failed to open file
+        qCritical() << qUtf8Printable(tr("Can't open file '%1'").arg(m_fileName));
+        return;
+    }
+    painter.setRenderHint(QPainter::Antialiasing, true);
+    painter.setPen(m_pen);
+    painter.setBrush(QBrush(Qt::NoBrush));
+    painter.scale(m_xScale, m_yScale);
+    scene->render(&painter, VPrintLayout::SceneTargetRect(&printer, m_imageRect), m_imageRect, Qt::IgnoreAspectRatio);
+    painter.end();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QString VLayoutExporter::ExportFormatDescription(LayoutExportFormats format)
+{
+    const QString dxfSuffix = QStringLiteral("(*.dxf)");
+    const QString dxfFlatFilesStr = tr("(flat) files");
+    const QString filesStr = tr("files");
+
+    switch(format)
+    {
+        case LayoutExportFormats::SVG:
+            return QStringLiteral("Svg %1 (*.svg)").arg(filesStr);
+        case LayoutExportFormats::PDF:
+            return QStringLiteral("PDF %1 (*.pdf)").arg(filesStr);
+        case LayoutExportFormats::PNG:
+            return tr("Image files") + QStringLiteral(" (*.png)");
+        case LayoutExportFormats::OBJ:
+            return QStringLiteral("Wavefront OBJ (*.obj)");
+        case LayoutExportFormats::PS:
+            return QStringLiteral("PS %1 (*.ps)").arg(filesStr);
+        case LayoutExportFormats::EPS:
+            return QStringLiteral("EPS %1 (*.eps)").arg(filesStr);
+        case LayoutExportFormats::DXF_AC1006_Flat:
+            return QStringLiteral("AutoCAD DXF R10 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1009_Flat:
+            return QStringLiteral("AutoCAD DXF R11/12 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1012_Flat:
+            return QStringLiteral("AutoCAD DXF R13 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1014_Flat:
+            return QStringLiteral("AutoCAD DXF R14 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1015_Flat:
+            return QStringLiteral("AutoCAD DXF 2000 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1018_Flat:
+            return QStringLiteral("AutoCAD DXF 2004 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1021_Flat:
+            return QStringLiteral("AutoCAD DXF 2007 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1024_Flat:
+            return QStringLiteral("AutoCAD DXF 2010 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1027_Flat:
+            return QStringLiteral("AutoCAD DXF 2013 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1006_AAMA:
+            return QStringLiteral("AutoCAD DXF R10 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1009_AAMA:
+            return QStringLiteral("AutoCAD DXF R11/12 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1012_AAMA:
+            return QStringLiteral("AutoCAD DXF R13 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1014_AAMA:
+            return QStringLiteral("AutoCAD DXF R14 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1015_AAMA:
+            return QStringLiteral("AutoCAD DXF 2000 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1018_AAMA:
+            return QStringLiteral("AutoCAD DXF 2004 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1021_AAMA:
+            return QStringLiteral("AutoCAD DXF 2007 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1024_AAMA:
+            return QStringLiteral("AutoCAD DXF 2010 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1027_AAMA:
+            return QStringLiteral("AutoCAD DXF 2013 AAMA %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1006_ASTM:
+            return QStringLiteral("AutoCAD DXF R10 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1009_ASTM:
+            return QStringLiteral("AutoCAD DXF R11/12 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1012_ASTM:
+            return QStringLiteral("AutoCAD DXF R13 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1014_ASTM:
+            return QStringLiteral("AutoCAD DXF R14 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1015_ASTM:
+            return QStringLiteral("AutoCAD DXF 2000 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1018_ASTM:
+            return QStringLiteral("AutoCAD DXF 2004 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1021_ASTM:
+            return QStringLiteral("AutoCAD DXF 2007 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1024_ASTM:
+            return QStringLiteral("AutoCAD DXF 2010 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::DXF_AC1027_ASTM:
+            return QStringLiteral("AutoCAD DXF 2013 ASTM %1 %2").arg(filesStr, dxfSuffix);
+        case LayoutExportFormats::PDFTiled:
+            return QStringLiteral("PDF %1 %2 (*.pdf)").arg(tr("tiled"), filesStr);
+        case LayoutExportFormats::NC:
+            return QStringLiteral("%1 %2 (*.nc)").arg(tr("Numerical control"), filesStr);
+        case LayoutExportFormats::RLD:
+            return QStringLiteral("%1 %2 (*.rld)").arg(tr("Raw Layout Data"), filesStr);
+        case LayoutExportFormats::TIF:
+            return QStringLiteral("TIFF %1 (*.tif)").arg(filesStr);
+        default:
+            return QString();
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QString VLayoutExporter::ExportFormatSuffix(LayoutExportFormats format)
+{
+    switch(format)
+    {
+        case LayoutExportFormats::SVG:
+            return QStringLiteral(".svg");
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PDFTiled:
+            return QStringLiteral(".pdf");
+        case LayoutExportFormats::PNG:
+            return QStringLiteral(".png");
+        case LayoutExportFormats::OBJ:
+            return QStringLiteral(".obj");
+        case LayoutExportFormats::PS:
+            return QStringLiteral(".ps");
+        case LayoutExportFormats::EPS:
+            return QStringLiteral(".eps");
+        case LayoutExportFormats::DXF_AC1006_Flat:
+        case LayoutExportFormats::DXF_AC1009_Flat:
+        case LayoutExportFormats::DXF_AC1012_Flat:
+        case LayoutExportFormats::DXF_AC1014_Flat:
+        case LayoutExportFormats::DXF_AC1015_Flat:
+        case LayoutExportFormats::DXF_AC1018_Flat:
+        case LayoutExportFormats::DXF_AC1021_Flat:
+        case LayoutExportFormats::DXF_AC1024_Flat:
+        case LayoutExportFormats::DXF_AC1027_Flat:
+        case LayoutExportFormats::DXF_AC1006_AAMA:
+        case LayoutExportFormats::DXF_AC1009_AAMA:
+        case LayoutExportFormats::DXF_AC1012_AAMA:
+        case LayoutExportFormats::DXF_AC1014_AAMA:
+        case LayoutExportFormats::DXF_AC1015_AAMA:
+        case LayoutExportFormats::DXF_AC1018_AAMA:
+        case LayoutExportFormats::DXF_AC1021_AAMA:
+        case LayoutExportFormats::DXF_AC1024_AAMA:
+        case LayoutExportFormats::DXF_AC1027_AAMA:
+        case LayoutExportFormats::DXF_AC1006_ASTM:
+        case LayoutExportFormats::DXF_AC1009_ASTM:
+        case LayoutExportFormats::DXF_AC1012_ASTM:
+        case LayoutExportFormats::DXF_AC1014_ASTM:
+        case LayoutExportFormats::DXF_AC1015_ASTM:
+        case LayoutExportFormats::DXF_AC1018_ASTM:
+        case LayoutExportFormats::DXF_AC1021_ASTM:
+        case LayoutExportFormats::DXF_AC1024_ASTM:
+        case LayoutExportFormats::DXF_AC1027_ASTM:
+            return QStringLiteral(".dxf");
+        case LayoutExportFormats::NC:
+            return QStringLiteral(".nc");
+        case LayoutExportFormats::RLD:
+            return QStringLiteral(".rld");
+        case LayoutExportFormats::TIF:
+            return QStringLiteral(".tif");
+        default:
+            return QString();
     }
 }
