@@ -44,12 +44,14 @@
 #include <QTransform>
 #include <Qt>
 #include <QtDebug>
+#include <QUuid>
 
 #include "../vpatterndb/floatItemData/vpatternlabeldata.h"
 #include "../vpatterndb/floatItemData/vpiecelabeldata.h"
 #include "../vmisc/vmath.h"
 #include "../vmisc/vabstractvalapplication.h"
 #include "../vmisc/compatibility.h"
+#include "../vmisc/literals.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/calculator.h"
 #include "../vpatterndb/vpassmark.h"
@@ -62,7 +64,7 @@
 #include "vgraphicsfillitem.h"
 
 const quint32 VLayoutPieceData::streamHeader = 0x80D7D009; // CRC-32Q string "VLayoutPieceData"
-const quint16 VLayoutPieceData::classVersion = 2;
+const quint16 VLayoutPieceData::classVersion = 3;
 
 namespace
 {
@@ -338,11 +340,11 @@ QVector<VLayoutPassmark> ConvertPassmarks(const VPiece &piece, const VContainer
 
                     if (side == PassmarkSide::All || side == PassmarkSide::Right)
                     {
-                        layoutPassmark.baseLine = baseLines.first();
+                        layoutPassmark.baseLine = ConstFirst(baseLines);
                     }
                     else if (side == PassmarkSide::Right)
                     {
-                        layoutPassmark.baseLine = baseLines.last();
+                        layoutPassmark.baseLine = ConstLast(baseLines);
                     }
 
                     const QVector<QLineF> lines = passmark.SAPassmark(piece, pattern, side);
@@ -428,6 +430,101 @@ QVector<VLayoutPassmark> ConvertPassmarks(const VPiece &piece, const VContainer
 
     return layoutPassmarks;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto PrepareGradationPlaceholders(const VContainer *data) -> QMap<QString, QString>
+{
+    SCASSERT(data != nullptr)
+
+    QMap<QString, QString> placeholders;
+
+    QString heightValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHeight());
+    placeholders.insert(pl_height, heightValue);
+    placeholders.insert(pl_dimensionX, heightValue);
+
+    QString sizeValue = QString::number(VAbstractValApplication::VApp()->GetDimensionSize());
+    placeholders.insert(pl_size, sizeValue);
+    placeholders.insert(pl_dimensionY, sizeValue);
+
+    QString hipValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHip());
+    placeholders.insert(pl_hip, hipValue);
+    placeholders.insert(pl_dimensionZ, hipValue);
+
+    QString waistValue = QString::number(VAbstractValApplication::VApp()->GetDimensionWaist());
+    placeholders.insert(pl_waist, waistValue);
+    placeholders.insert(pl_dimensionW, waistValue);
+
+    {
+        QString label = VAbstractValApplication::VApp()->GetDimensionHeightLabel();
+        placeholders.insert(pl_heightLabel, not label.isEmpty() ? label : heightValue);
+        placeholders.insert(pl_dimensionXLabel, not label.isEmpty() ? label : heightValue);
+
+        label = VAbstractValApplication::VApp()->GetDimensionSizeLabel();
+        placeholders.insert(pl_sizeLabel, not label.isEmpty() ? label : sizeValue);
+        placeholders.insert(pl_dimensionYLabel, not label.isEmpty() ? label : heightValue);
+
+        label = VAbstractValApplication::VApp()->GetDimensionHipLabel();
+        placeholders.insert(pl_hipLabel, not label.isEmpty() ? label : hipValue);
+        placeholders.insert(pl_dimensionZLabel, not label.isEmpty() ? label : heightValue);
+
+        label = VAbstractValApplication::VApp()->GetDimensionWaistLabel();
+        placeholders.insert(pl_waistLabel, not label.isEmpty() ? label : waistValue);
+        placeholders.insert(pl_dimensionWLabel, not label.isEmpty() ? label : heightValue);
+    }
+
+    {
+        const QMap<QString, QSharedPointer<VMeasurement> > measurements = data->DataMeasurements();
+        auto i = measurements.constBegin();
+        while (i != measurements.constEnd())
+        {
+            placeholders.insert(pl_measurement + i.key(), QString::number(*i.value()->GetValue()));
+            ++i;
+        }
+    }
+
+    return placeholders;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto ReplacePlaceholders(const QMap<QString, QString> &placeholders, QString line) -> QString
+{
+    QChar per('%');
+
+    auto TestDimension = [per, placeholders, line](const QString &placeholder, const QString &errorMsg)
+    {
+        if (line.contains(per+placeholder+per) && placeholders.value(placeholder) == QChar('0'))
+        {
+            VAbstractApplication::VApp()->IsPedantic()
+                    ? throw VException(errorMsg)
+                    : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+        }
+    };
+
+    TestDimension(pl_height, QObject::tr("No data for the height dimension."));
+    TestDimension(pl_size, QObject::tr("No data for the size dimension."));
+    TestDimension(pl_hip, QObject::tr("No data for the hip dimension."));
+    TestDimension(pl_waist, QObject::tr("No data for the waist dimension."));
+
+    TestDimension(pl_dimensionX, QObject::tr("No data for the X dimension."));
+    TestDimension(pl_dimensionY, QObject::tr("No data for the Y dimension."));
+    TestDimension(pl_dimensionZ, QObject::tr("No data for the Z dimension."));
+    TestDimension(pl_dimensionW, QObject::tr("No data for the W dimension."));
+
+    auto i = placeholders.constBegin();
+    while (i != placeholders.constEnd())
+    {
+        line.replace(per+i.key()+per, i.value());
+        ++i;
+    }
+    return line;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto PrepareGradationId(const QString &label, const VContainer *pattern) -> QString
+{
+    const QMap<QString, QString> placeholders = PrepareGradationPlaceholders(pattern);
+    return ReplacePlaceholders(placeholders, label);
+}
 }
 
 // Friend functions
@@ -504,6 +601,8 @@ VLayoutPiece VLayoutPiece::Create(const VPiece &piece, vidtype id, const VContai
     det.SetMy(piece.GetMy());
 
     det.SetName(piece.GetName());
+    det.SetUUID(piece.GetUUID());
+    det.SetGradationId(PrepareGradationId(piece.GetGradationLabel(), pattern));
 
     det.SetSAWidth(VAbstractValApplication::VApp()->toPixel(piece.GetSAWidth()));
     det.SetForbidFlipping(piece.IsForbidFlipping());
@@ -528,7 +627,7 @@ VLayoutPiece VLayoutPiece::Create(const VPiece &piece, vidtype id, const VContai
     det.SetPriority(piece.GetPriority());
 
     // Very important to set main path first!
-    if (det.ContourPath().isEmpty())
+    if (det.MappedContourPath().isEmpty())
     {
         throw VException (tr("Piece %1 doesn't have shape.").arg(piece.GetName()));
     }
@@ -548,7 +647,7 @@ VLayoutPiece VLayoutPiece::Create(const VPiece &piece, vidtype id, const VContai
     }
 
     const VGrainlineData& grainlineGeom = piece.GetGrainlineGeometry();
-    if (grainlineGeom.IsVisible() == true)
+    if (grainlineGeom.IsVisible())
     {
         det.SetGrainline(grainlineGeom, pattern);
     }
@@ -556,9 +655,22 @@ VLayoutPiece VLayoutPiece::Create(const VPiece &piece, vidtype id, const VContai
     return det;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetUniqueID() const -> QString
+{
+    QString id = VAbstractPiece::GetUniqueID();
+
+    if (not d->m_gradationId.isEmpty())
+    {
+        id = id + '_' + d->m_gradationId;
+    }
+
+    return id;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 template <class T>
-QVector<T> VLayoutPiece::Map(QVector<T> points) const
+auto VLayoutPiece::Map(QVector<T> points) const -> QVector<T>
 {
     std::transform(points.begin(), points.end(), points.begin(),
                    [this](const T &point) { return d->matrix.map(point); });
@@ -648,17 +760,23 @@ void VLayoutPiece::SetSeamAllowancePoints(const QVector<QPointF> &points, bool s
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QPointF> VLayoutPiece::GetLayoutAllowancePoints() const
+QVector<QPointF> VLayoutPiece::GetMappedLayoutAllowancePoints() const
 {
     return Map(d->layoutAllowance);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QVector<QPointF> VLayoutPiece::GetLayoutAllowancePoints() const
+{
+    return d->layoutAllowance;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QPointF VLayoutPiece::GetPieceTextPosition() const
 {
     if (d->detailLabel.count() > 2)
     {
-        return d->matrix.map(d->detailLabel.first());
+        return d->matrix.map(ConstFirst(d->detailLabel));
     }
     else
     {
@@ -711,12 +829,36 @@ void VLayoutPiece::SetPieceText(const QString& qsName, const VPieceLabelData& da
     d->m_tmDetail.FitFontSize(labelWidth, labelHeight);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetPieceLabelRect() const -> QVector<QPointF>
+{
+    return d->detailLabel;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetPieceLabelRect(const QVector<QPointF> &rect)
+{
+    d->detailLabel = rect;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetPieceLabelData() const -> VTextManager
+{
+    return d->m_tmDetail;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetPieceLabelData(const VTextManager &data)
+{
+    d->m_tmDetail = data;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QPointF VLayoutPiece::GetPatternTextPosition() const
 {
     if (d->patternInfo.count() > 2)
     {
-        return d->matrix.map(d->patternInfo.first());
+        return d->matrix.map(ConstFirst(d->patternInfo));
     }
     else
     {
@@ -769,6 +911,30 @@ void VLayoutPiece::SetPatternInfo(VAbstractPattern* pDoc, const VPatternLabelDat
     d->m_tmPattern.FitFontSize(labelWidth, labelHeight);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetPatternLabelRect() const -> QVector<QPointF>
+{
+    return d->patternInfo;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetPatternLabelRect(const QVector<QPointF> &rect)
+{
+    d->patternInfo = rect;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetPatternLabelData() const -> VTextManager
+{
+    return d->m_tmPattern;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetPatternLabelData(const VTextManager &data)
+{
+    d->m_tmPattern = data;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutPiece::SetGrainline(const VGrainlineData& geom, const VContainer* pattern)
 {
@@ -789,17 +955,47 @@ void VLayoutPiece::SetGrainline(const VGrainlineData& geom, const VContainer* pa
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QPointF> VLayoutPiece::GetGrainline() const
+QVector<QPointF> VLayoutPiece::GetMappedGrainline() const
 {
     return Map(d->grainlinePoints);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QVector<QPointF> VLayoutPiece::GetGrainline() const
+{
+    return d->grainlinePoints;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 bool VLayoutPiece::IsGrainlineEnabled() const
 {
     return d->grainlineEnabled;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetGrainlineEnabled(bool enabled)
+{
+    d->grainlineEnabled = enabled;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetGrainlineAngle(qreal angle)
+{
+    d->grainlineAngle = angle;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetGrainlineArrowType(GrainlineArrowDirection type)
+{
+    d->grainlineArrowType = type;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetGrainlinePoints(const QVector<QPointF> &points)
+{
+    d->grainlinePoints = points;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 qreal VLayoutPiece::GrainlineAngle() const
 {
@@ -862,15 +1058,24 @@ void VLayoutPiece::SetId(vidtype id)
 
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutPiece::Translate(qreal dx, qreal dy)
+{
+    Translate(QPointF(dx, dy));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::Translate(const QPointF &p)
 {
     QTransform m;
-    m.translate(dx, dy);
+    m.translate(p.x(), p.y());
     d->matrix *= m;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutPiece::Scale(qreal sx, qreal sy)
 {
+    d->m_xScale *= sx;
+    d->m_yScale *= sy;
+
     QTransform m;
     m.scale(sx, sy);
     d->matrix *= m;
@@ -954,22 +1159,27 @@ int VLayoutPiece::LayoutEdgeByPoint(const QPointF &p1) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QRectF VLayoutPiece::DetailBoundingRect() const
+QRectF VLayoutPiece::MappedDetailBoundingRect() const
 {
-    return IsSeamAllowance() && not IsSeamAllowanceBuiltIn() ? BoundingRect(GetMappedSeamAllowancePoints()) :
-                                                               BoundingRect(GetMappedContourPoints());
+    return BoundingRect(GetMappedExternalContourPoints());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QRectF VLayoutPiece::LayoutBoundingRect() const
+QRectF VLayoutPiece::DetailBoundingRect() const
 {
-    return BoundingRect(GetLayoutAllowancePoints());
+    return BoundingRect(GetExternalContourPoints());
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QRectF VLayoutPiece::MappedLayoutBoundingRect() const
+{
+    return BoundingRect(GetMappedLayoutAllowancePoints());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 qreal VLayoutPiece::Diagonal() const
 {
-    const QRectF rec = LayoutBoundingRect();
+    const QRectF rec = MappedLayoutBoundingRect();
     return qSqrt(pow(rec.height(), 2) + pow(rec.width(), 2));
 }
 
@@ -1035,11 +1245,31 @@ void VLayoutPiece::SetLayoutAllowancePoints()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLayoutPassmark> VLayoutPiece::GetPassmarks() const
+QVector<QPointF> VLayoutPiece::GetMappedExternalContourPoints() const
+{
+    return IsSeamAllowance() && not IsSeamAllowanceBuiltIn() ? GetMappedSeamAllowancePoints() :
+                                                               GetMappedContourPoints();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QVector<QPointF> VLayoutPiece::GetExternalContourPoints() const
+{
+    return IsSeamAllowance() && not IsSeamAllowanceBuiltIn() ? GetSeamAllowancePoints() :
+                                                               GetContourPoints();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QVector<VLayoutPassmark> VLayoutPiece::GetMappedPassmarks() const
 {
     return Map(d->passmarks);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QVector<VLayoutPassmark> VLayoutPiece::GetPassmarks() const
+{
+    return d->passmarks;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutPiece::SetPassmarks(const QVector<VLayoutPassmark> &passmarks)
 {
@@ -1050,11 +1280,17 @@ void VLayoutPiece::SetPassmarks(const QVector<VLayoutPassmark> &passmarks)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLayoutPlaceLabel> VLayoutPiece::GetPlaceLabels() const
+QVector<VLayoutPlaceLabel> VLayoutPiece::GetMappedPlaceLabels() const
 {
     return Map(d->m_placeLabels);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QVector<VLayoutPlaceLabel> VLayoutPiece::GetPlaceLabels() const
+{
+    return d->m_placeLabels;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutPiece::SetPlaceLabels(const QVector<VLayoutPlaceLabel> &labels)
 {
@@ -1062,11 +1298,11 @@ void VLayoutPiece::SetPlaceLabels(const QVector<VLayoutPlaceLabel> &labels)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QVector<QPointF> > VLayoutPiece::InternalPathsForCut(bool cut) const
+QVector<QVector<QPointF> > VLayoutPiece::MappedInternalPathsForCut(bool cut) const
 {
     QVector<QVector<QPointF> > paths;
 
-    for (auto &path : d->m_internalPaths)
+    for (const auto &path : d->m_internalPaths)
     {
         if (path.IsCutPath() == cut)
         {
@@ -1089,6 +1325,12 @@ void VLayoutPiece::SetInternalPaths(const QVector<VLayoutPiecePath> &internalPat
     d->m_internalPaths = internalPaths;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+QPainterPath VLayoutPiece::MappedContourPath() const
+{
+    return d->matrix.map(ContourPath());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QPainterPath VLayoutPiece::ContourPath() const
 {
@@ -1097,7 +1339,7 @@ QPainterPath VLayoutPiece::ContourPath() const
     // contour
     if (not IsHideMainPath() || not IsSeamAllowance() || IsSeamAllowanceBuiltIn())
     {
-        path = PainterPath(GetMappedContourPoints());
+        path = PainterPath(GetContourPoints());
     }
 
     // seam allowance
@@ -1106,9 +1348,9 @@ QPainterPath VLayoutPiece::ContourPath() const
         if (not IsSeamAllowanceBuiltIn())
         {
             // Draw seam allowance
-            QVector<QPointF>points = GetMappedSeamAllowancePoints();
+            QVector<QPointF>points = GetSeamAllowancePoints();
 
-            if (points.last().toPoint() != points.first().toPoint())
+            if (ConstLast(points).toPoint() != ConstFirst(points).toPoint())
             {
                 points.append(points.at(0));// Should be always closed
             }
@@ -1126,9 +1368,9 @@ QPainterPath VLayoutPiece::ContourPath() const
         // Draw passmarks
         QPainterPath passmaksPath;
         const QVector<VLayoutPassmark> passmarks = GetPassmarks();
-        for(auto &passmark : passmarks)
+        for(const auto &passmark : passmarks)
         {
-            for (auto &line : passmark.lines)
+            for (const auto &line : passmark.lines)
             {
                 passmaksPath.moveTo(line.p1());
                 passmaksPath.lineTo(line.p2());
@@ -1143,9 +1385,45 @@ QPainterPath VLayoutPiece::ContourPath() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPainterPath VLayoutPiece::LayoutAllowancePath() const
+QPainterPath VLayoutPiece::MappedLayoutAllowancePath() const
 {
-    return PainterPath(GetLayoutAllowancePoints());
+    return PainterPath(GetMappedLayoutAllowancePoints());
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::DrawMiniature(QPainter &painter) const
+{
+    painter.drawPath(ContourPath());
+
+    for (const auto &path : d->m_internalPaths)
+    {
+        painter.save();
+
+        QPen pen = painter.pen();
+        pen.setStyle(path.PenStyle());
+        painter.setPen(pen);
+
+        painter.drawPath(path.GetPainterPath());
+
+        painter.restore();
+    }
+
+    for (const auto &label : d->m_placeLabels)
+    {
+        painter.drawPath(VPlaceLabelItem::LabelShapePath(label.shape));
+    }
+
+    QVector<QPointF> gPoints = GetGrainline();
+    if (not gPoints.isEmpty())
+    {
+        QPainterPath path;
+        path.moveTo(gPoints.at(0));
+        for (auto p : qAsConst(gPoints))
+        {
+            path.lineTo(p);
+        }
+        painter.drawPath(path);
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1155,7 +1433,7 @@ QGraphicsItem *VLayoutPiece::GetItem(bool textAsPaths) const
 
     for (auto &path : d->m_internalPaths)
     {
-        QGraphicsPathItem* pathItem = new QGraphicsPathItem(item);
+        auto* pathItem = new QGraphicsPathItem(item);
         pathItem->setPath(d->matrix.map(path.GetPainterPath()));
 
         QPen pen = pathItem->pen();
@@ -1164,9 +1442,9 @@ QGraphicsItem *VLayoutPiece::GetItem(bool textAsPaths) const
         pathItem->setPen(pen);
     }
 
-    for (auto &label : d->m_placeLabels)
+    for (const auto &label : d->m_placeLabels)
     {
-        QGraphicsPathItem* pathItem = new QGraphicsPathItem(item);
+        auto* pathItem = new QGraphicsPathItem(item);
         QPen pen = pathItem->pen();
         pen.setWidthF(VAbstractApplication::VApp()->Settings()->WidthHairLine());
         pathItem->setPen(pen);
@@ -1212,7 +1490,7 @@ qreal VLayoutPiece::BiggestEdge() const
 //---------------------------------------------------------------------------------------------------------------------
 QRectF VLayoutPiece::BoundingRect(QVector<QPointF> points)
 {
-    points.append(points.first());
+    points.append(ConstFirst(points));
     return QPolygonF(points).boundingRect();
 }
 
@@ -1251,11 +1529,7 @@ void VLayoutPiece::CreateLabelStrings(QGraphicsItem *parent, const QVector<QPoin
             }
 
             QString qsText = tl.m_qsText;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-            if (fm.horizontalAdvance(qsText) > dW)
-#else
-            if (fm.width(qsText) > dW)
-#endif
+            if (TextWidth(fm, qsText) > dW)
             {
                 qsText = fm.elidedText(qsText, Qt::ElideMiddle, static_cast<int>(dW));
             }
@@ -1267,19 +1541,11 @@ void VLayoutPiece::CreateLabelStrings(QGraphicsItem *parent, const QVector<QPoin
             }
             else if ((tl.m_eAlign & Qt::AlignHCenter) > 0)
             {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-                dX = (dW - fm.horizontalAdvance(qsText))/2;
-#else
-                dX = (dW - fm.width(qsText))/2;
-#endif
+                dX = (dW - TextWidth(fm, qsText))/2;
             }
             else if ((tl.m_eAlign & Qt::AlignRight) > 0)
             {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-                dX = dW - fm.horizontalAdvance(qsText);
-#else
-                dX = dW - fm.width(qsText);
-#endif
+                dX = dW - TextWidth(fm, qsText);
             }
 
             // set up the rotation around top-left corner matrix
@@ -1305,7 +1571,7 @@ void VLayoutPiece::CreateLabelStrings(QGraphicsItem *parent, const QVector<QPoin
                 QPainterPath path;
                 path.addText(0, - static_cast<qreal>(fm.ascent())/6., fnt, qsText);
 
-                QGraphicsPathItem* item = new QGraphicsPathItem(parent);
+                auto* item = new QGraphicsPathItem(parent);
                 item->setPath(path);
                 item->setBrush(QBrush(Qt::black));
                 item->setTransform(labelMatrix);
@@ -1314,7 +1580,7 @@ void VLayoutPiece::CreateLabelStrings(QGraphicsItem *parent, const QVector<QPoin
             }
             else
             {
-                QGraphicsSimpleTextItem* item = new QGraphicsSimpleTextItem(parent);
+                auto* item = new QGraphicsSimpleTextItem(parent);
                 item->setFont(fnt);
                 item->setText(qsText);
                 item->setTransform(labelMatrix);
@@ -1339,7 +1605,7 @@ void VLayoutPiece::CreateGrainlineItem(QGraphicsItem *parent) const
 
     QPainterPath path;
 
-    QVector<QPointF> gPoints = GetGrainline();
+    QVector<QPointF> gPoints = GetMappedGrainline();
     path.moveTo(gPoints.at(0));
     for (auto p : qAsConst(gPoints))
     {
@@ -1368,7 +1634,7 @@ QGraphicsPathItem *VLayoutPiece::GetMainItem() const
     QPen pen = item->pen();
     pen.setWidthF(VAbstractApplication::VApp()->Settings()->WidthHairLine());
     item->setPen(pen);
-    item->setPath(ContourPath());
+    item->setPath(MappedContourPath());
     return item;
 }
 
@@ -1408,6 +1674,42 @@ void VLayoutPiece::SetMirror(bool value)
     d->mirror = value;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetGradationId(const QString &id)
+{
+    d->m_gradationId = id;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetGradationId() const -> QString
+{
+    return d->m_gradationId;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetXScale() const -> qreal
+{
+    return d->m_xScale;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetXScale(qreal xs)
+{
+    d->m_xScale = xs;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutPiece::GetYScale() const -> qreal
+{
+    return d->m_yScale;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutPiece::SetYScale(qreal ys)
+{
+    d->m_yScale = ys;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QLineF VLayoutPiece::Edge(const QVector<QPointF> &path, int i) const
 {
