@@ -48,6 +48,7 @@
 #include "../vmisc/vmath.h"
 #include "../vmisc/def.h"
 #include "../vmisc/vabstractvalapplication.h"
+#include "../vmisc/compatibility.h"
 #include "../ifc/exception/vexception.h"
 
 namespace
@@ -95,7 +96,6 @@ QPixmap WatermarkImageFromCache(const VWatermarkData &watermarkData, const QStri
         if (watermarkData.grayscale)
         {
             watermark = Grayscale(watermark);
-            watermark.save("/home/dismine/grayscale.png", "PNG");
         }
 
         // Workaround for QGraphicsPixmapItem opacity problem.
@@ -272,6 +272,11 @@ QVector<QGraphicsItem *> VPoster::TextWatermark(QGraphicsItem *parent, const Pos
 
     QGraphicsSimpleTextItem *text = new QGraphicsSimpleTextItem(watermarkData.text, parent);
     text->setFont(watermarkData.font);
+
+    QPen pen = text->pen();
+    pen.setColor(watermarkData.textColor);
+    text->setPen(pen);
+
     text->setOpacity(watermarkData.opacity/100.);
     text->setTransformOriginPoint(text->boundingRect().center());
     text->setRotation(-watermarkData.textRotation);
@@ -490,11 +495,7 @@ void VPoster::Ruler(QVector<QGraphicsItem *> &data, QGraphicsItem *parent, QRect
 
             qreal unitsWidth = 0;
             QFontMetrics fm(fnt);
-        #if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-            unitsWidth = fm.horizontalAdvance(units->toPlainText());
-        #else
-            unitsWidth = fm.width(units->toPlainText());
-        #endif
+            unitsWidth = TextWidth(fm, units->toPlainText());
             units->setPos(rec.x() + step*0.5-unitsWidth*0.7,
                           rec.y() + rec.height()-static_cast<int>(allowance)-shortNotchHeight);
             units->setFont(fnt);
