@@ -50,6 +50,8 @@
 #include "../ifc/xml/vwatermarkconverter.h"
 #include "../ifc/exception/vexception.h"
 #include "../vmisc/vmath.h"
+#include "../vpropertyexplorer/checkablemessagebox.h"
+#include "../vmisc/compatibility.h"
 
 namespace
 {
@@ -124,10 +126,10 @@ auto PreparePrinter(const QPrinterInfo &info, QPrinter::PrinterMode mode) -> QSh
         const QStringList list = QPrinterInfo::availablePrinterNames();
         if(list.isEmpty())
         {
-            return QSharedPointer<QPrinter>();
+            return {};
         }
 
-        tmpInfo = QPrinterInfo::printerInfo(list.first());
+        tmpInfo = QPrinterInfo::printerInfo(ConstFirst<QString>(list));
     }
 
     auto printer = QSharedPointer<QPrinter>(new QPrinter(tmpInfo, mode));
@@ -386,14 +388,6 @@ void VPrintLayout::PrintPages(QPrinter *printer)
 
     VWatermarkData data = WatermarkData();
 
-    // Here we try understand difference between printer's dpi and our.
-    // Get printer rect acording to our dpi.
-    const QRectF printerPageRect(0, 0, ToPixel(printer->pageRect(QPrinter::Millimeter).width(), Unit::Mm),
-                                 ToPixel(printer->pageRect(QPrinter::Millimeter).height(), Unit::Mm));
-    const QRect pageRect = printer->pageLayout().paintRectPixels(printer->resolution());
-    const double xscale = pageRect.width() / printerPageRect.width();
-    const double yscale = pageRect.height() / printerPageRect.height();
-
     for (int i = 0; i < copyCount; ++i)
     {
         for (int j = 0; j < numPages; ++j)
@@ -437,24 +431,8 @@ void VPrintLayout::PrintPages(QPrinter *printer)
                 QRectF source;
                 m_isTiled ? source = poster->at(index).rect : source = paper->rect();
 
-                qreal x;
-                qreal y;
-                if(printer->fullPage())
-                {
-                    QPageLayout layout = printer->pageLayout();
-                    layout.setUnits(QPageLayout::Millimeter);
-                    QMarginsF printerMargins = layout.margins();
-                    x = qFloor(ToPixel(printerMargins.left(), Unit::Mm));
-                    y = qFloor(ToPixel(printerMargins.top(), Unit::Mm));
-                }
-                else
-                {
-                    x = 0; y = 0;
-                }
-
-                QRectF target(x * xscale, y * yscale, source.width() * xscale, source.height() * yscale);
-
-                m_layoutScenes.at(paperIndex)->render(&painter, target, source, Qt::IgnoreAspectRatio);
+                m_layoutScenes.at(paperIndex)->render(&painter, VPrintLayout::SceneTargetRect(printer, source), source,
+                                                      Qt::IgnoreAspectRatio);
 
                 if (m_isTiled)
                 {
@@ -744,16 +722,60 @@ auto VPrintLayout::WatermarkData() const -> VWatermarkData
 //---------------------------------------------------------------------------------------------------------------------
 auto VPrintLayout::ContinueIfLayoutStale(QWidget *parent) -> int
 {
-    QMessageBox msgBox(parent);
-    msgBox.setIcon(QMessageBox::Question);
-    msgBox.setWindowTitle(tr("The layout is stale."));
-    msgBox.setText(tr("The layout was not updated since last pattern modification. Do you want to continue?"));
-    msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
-    msgBox.setDefaultButton(QMessageBox::No);
-    const int width = 500;
-    auto* horizontalSpacer = new QSpacerItem(width, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
-    auto* layout = qobject_cast<QGridLayout*>(msgBox.layout());
-    SCASSERT(layout != nullptr)
-    layout->addItem(horizontalSpacer, layout->rowCount(), 0, 1, layout->columnCount());
-    return msgBox.exec();
+    if (VAbstractApplication::VApp()->IsAppInGUIMode())
+    {
+        if (not VAbstractApplication::VApp()->Settings()->GetAskContinueIfLayoutStale())
+        {
+            return QMessageBox::Yes;
+        }
+
+        Utils::CheckableMessageBox msgBox(parent);
+        msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32) );
+        msgBox.setWindowTitle(tr("The layout is stale."));
+        msgBox.setText(tr("The layout was not updated since last pattern modification. Do you want to continue?"));
+        msgBox.setStandardButtons(QDialogButtonBox::Yes|QDialogButtonBox::No);
+        msgBox.setDefaultButton(QDialogButtonBox::No);
+
+        int dialogResult = msgBox.exec();
+
+        if (msgBox.isChecked())
+        {
+            VAbstractApplication::VApp()->Settings()->SetAskContinueIfLayoutStale(false);
+        }
+
+        return dialogResult == QDialog::Accepted ? QMessageBox::Yes : QMessageBox::No;
+    }
+
+    return QDialogButtonBox::Yes;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QRectF VPrintLayout::SceneTargetRect(QPrinter *printer, const QRectF &source)
+{
+    SCASSERT(printer != nullptr)
+
+    qreal x;
+    qreal y;
+    if(printer->fullPage())
+    {
+        QPageLayout layout = printer->pageLayout();
+        layout.setUnits(QPageLayout::Millimeter);
+        QMarginsF printerMargins = layout.margins();
+        x = qFloor(ToPixel(printerMargins.left(), Unit::Mm));
+        y = qFloor(ToPixel(printerMargins.top(), Unit::Mm));
+    }
+    else
+    {
+        x = 0; y = 0;
+    }
+
+    // Here we try understand difference between printer's dpi and our.
+    // Get printer rect according to our dpi.
+    const QRectF printerPageRect(0, 0, ToPixel(printer->pageRect(QPrinter::Millimeter).width(), Unit::Mm),
+                                 ToPixel(printer->pageRect(QPrinter::Millimeter).height(), Unit::Mm));
+    const QRect pageRect = printer->pageLayout().paintRectPixels(printer->resolution());
+    const double xscale = pageRect.width() / printerPageRect.width();
+    const double yscale = pageRect.height() / printerPageRect.height();
+
+    return QRectF(x * xscale, y * yscale, source.width() * xscale, source.height() * yscale);
 }
