@@ -43,7 +43,6 @@
 #include <QMargins>
 #include <QLineF>
 
-#include "literals.h"
 #include "debugbreak.h"
 #include "defglobal.h"
 
@@ -205,6 +204,10 @@ enum class Tool : ToolVisHolderType
     InsertNode,
     PlaceLabel,
     DuplicateDetail,
+    BackgroundImage,
+    BackgroundImageControls,
+    BackgroundPixmapImage,
+    BackgroundSVGImage,
     LAST_ONE_DO_NOT_USE //add new stuffs above this, this constant must be last and never used
 };
 
@@ -267,13 +270,18 @@ enum class Vis : ToolVisHolderType
     LAST_ONE_DO_NOT_USE //add new stuffs above this, this constant must be last and never used
 };
 
-enum class VarType : qint8 { Measurement, Increment, IncrementSeparator, LineLength, CurveLength, CurveCLength,
-                             LineAngle, CurveAngle, ArcRadius, Unknown };
+enum class VarType : qint8 { Measurement, MeasurementSeparator, Increment, IncrementSeparator, LineLength, CurveLength,
+                             CurveCLength, LineAngle, CurveAngle, ArcRadius, Unknown };
 
 enum class IncrementType : qint8 { Increment, Separator };
 
-QString       IncrementTypeToString(IncrementType type);
-IncrementType StringToIncrementType(const QString &value);
+auto IncrementTypeToString(IncrementType type) -> QString;
+auto StringToIncrementType(const QString &value) -> IncrementType;
+
+enum class MeasurementType : qint8 { Measurement, Separator };
+
+auto MeasurementTypeToString(MeasurementType type) -> QString;
+auto StringToMeasurementType(const QString &value) -> MeasurementType;
 
 enum class IMD: qint8 // Individual measurement dimension
 {
@@ -309,16 +317,14 @@ enum class IMD: qint8 // Individual measurement dimension
  */
 #ifndef V_NO_ASSERT
 
-#define SCASSERT(cond)                                      \
-{                                                           \
-    if (!(cond))                                            \
-    {                                                       \
-        qCritical("ASSERT: %s in %s (%s:%u)",               \
-                  #cond, Q_FUNC_INFO , __FILE__, __LINE__); \
-        debug_break();                                      \
-        abort();                                            \
-    }                                                       \
-}                                                           \
+#define SCASSERT(cond)                                  \
+if (!(cond))                                            \
+{                                                       \
+    qCritical("ASSERT: %s in %s (%s:%u)",               \
+              #cond, Q_FUNC_INFO , __FILE__, __LINE__); \
+    debug_break();                                      \
+    abort();                                            \
+}
 
 #else // define but disable this function if debugging is not set
 #define SCASSERT(cond) qt_noop();
@@ -359,118 +365,9 @@ enum class IMD: qint8 // Individual measurement dimension
 bool IsOptionSet(int argc, char *argv[], const char *option);
 void InitHighDpiScaling(int argc, char *argv[]);
 
-// functions
-extern const QString degTorad_F;
-extern const QString radTodeg_F;
-extern const QString sin_F;
-extern const QString cos_F;
-extern const QString tan_F;
-extern const QString asin_F;
-extern const QString acos_F;
-extern const QString atan_F;
-extern const QString sinh_F;
-extern const QString cosh_F;
-extern const QString tanh_F;
-extern const QString asinh_F;
-extern const QString acosh_F;
-extern const QString atanh_F;
-extern const QString sinD_F;
-extern const QString cosD_F;
-extern const QString tanD_F;
-extern const QString asinD_F;
-extern const QString acosD_F;
-extern const QString atanD_F;
-extern const QString log2_F;
-extern const QString log10_F;
-extern const QString log_F;
-extern const QString ln_F;
-extern const QString exp_F;
-extern const QString sqrt_F;
-extern const QString sign_F;
-extern const QString rint_F;
-extern const QString r2cm_F;
-extern const QString csrCm_F;
-extern const QString csrInch_F;
-extern const QString abs_F;
-extern const QString min_F;
-extern const QString max_F;
-extern const QString sum_F;
-extern const QString avg_F;
-extern const QString fmod_F;
-extern const QString warning_F;
-
-extern const QStringList builInFunctions;
-
-// Placeholders
-extern const QString pl_size;
-extern const QString pl_height;
-extern const QString pl_hip;
-extern const QString pl_waist;
-extern const QString pl_sizeLabel;
-extern const QString pl_heightLabel;
-extern const QString pl_hipLabel;
-extern const QString pl_waistLabel;
-extern const QString pl_date;
-extern const QString pl_time;
-extern const QString pl_birthDate;
-extern const QString pl_patternName;
-extern const QString pl_patternNumber;
-extern const QString pl_author;
-extern const QString pl_customer;
-extern const QString pl_email;
-extern const QString pl_userMaterial;
-extern const QString pl_pExt;
-extern const QString pl_pUnits;
-extern const QString pl_pFileName;
-extern const QString pl_mFileName;
-extern const QString pl_mExt;
-extern const QString pl_mUnits;
-extern const QString pl_mSizeUnits;
-extern const QString pl_pLetter;
-extern const QString pl_pAnnotation;
-extern const QString pl_pOrientation;
-extern const QString pl_pRotation;
-extern const QString pl_pTilt;
-extern const QString pl_pFoldPosition;
-extern const QString pl_pName;
-extern const QString pl_pQuantity;
-extern const QString pl_mFabric;
-extern const QString pl_mLining;
-extern const QString pl_mInterfacing;
-extern const QString pl_mInterlining;
-extern const QString pl_wCut;
-extern const QString pl_wOnFold;
-extern const QString pl_measurement;
-extern const QString pl_finalMeasurement;
-
 // Don't forget to syncronize with XSD schema.
 const int userMaterialPlaceholdersQuantity = 20;
 
-extern const QString cursorArrowOpenHand;
-extern const QString cursorArrowCloseHand;
-
-extern const QString strOne;
-extern const QString strTwo;
-extern const QString strThree;
-
-extern const QString strStraightforward;
-extern const QString strBisector;
-extern const QString strIntersection;
-extern const QString strIntersectionOnlyLeft;
-extern const QString strIntersectionOnlyRight;
-extern const QString strIntersection2;
-extern const QString strIntersection2OnlyLeft;
-extern const QString strIntersection2OnlyRight;
-extern const QString strTypeIncrement;
-extern const QString strTypeSeparator;
-
-extern const QString unitMM;
-extern const QString unitCM;
-extern const QString unitINCH;
-extern const QString unitPX;
-
-extern const QString valentinaNamespace;
-
 QPixmap QPixmapFromCache(const QString &pixmapPath);
 void SetItemOverrideCursor(QGraphicsItem *item, const QString & pixmapPath, int hotX = -1, int hotY = -1);
 
@@ -525,7 +422,7 @@ Q_DECL_RELAXED_CONSTEXPR inline qreal UnitConvertor(qreal value, const Unit &fro
                 case Unit::Cm:
                     return value / 10.0;
                 case Unit::Inch:
-                    return value / 25.4;
+                    return value / 10.0 / 2.54;
                 case Unit::Px:
                     return (value / 25.4) * PrintDPI;
                 default:
@@ -551,7 +448,7 @@ Q_DECL_RELAXED_CONSTEXPR inline qreal UnitConvertor(qreal value, const Unit &fro
             switch (to)
             {
                 case Unit::Mm:
-                    return value * 25.4;
+                    return value * 2.54 * 10.0;
                 case Unit::Cm:
                     return value * 2.54;
                 case Unit::Inch:
@@ -678,6 +575,10 @@ Q_DECLARE_TYPEINFO(CustomSARecord, Q_MOVABLE_TYPE);
 #define QXT_D(PUB) PUB##Private& d = qxt_d()
 #define QXT_P(PUB) PUB& p = qxt_p()
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
+
 template <typename PUB>
 class QxtPrivate
 {
@@ -714,6 +615,8 @@ private:
     PUB* qxt_p_ptr;
 };
 
+QT_WARNING_POP
+
 template <typename PUB, typename PVT>
 class QxtPrivateInterface
 {
