@@ -49,6 +49,10 @@ class QUndoStack;
 class VAbstractApplication;// use in define
 class VCommonSettings;
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
+QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
+
 class VAbstractApplication : public QApplication
 {
     Q_OBJECT
@@ -111,6 +115,8 @@ private:
     void ClearTranslation();
 };
 
+QT_WARNING_POP
+
 //---------------------------------------------------------------------------------------------------------------------
 template <typename T>
 inline QString VAbstractApplication::LocaleToString(const T &value)
