@@ -38,10 +38,15 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
 
-class VMeasurementData : public QSharedData
+class VMeasurementData final : public QSharedData
 {
 public:
 
+    explicit VMeasurementData(quint32 index, MeasurementType varType)
+        : index(index),
+          varType(varType)
+    {}
+
     VMeasurementData(quint32 index, qreal baseA, qreal baseB, qreal baseC, qreal base)
         : index(index),
           shiftBase(base),
@@ -80,7 +85,8 @@ public:
           baseC(m.baseC),
           corrections(m.corrections),
           specialUnits(m.specialUnits),
-          dimension(m.dimension)
+          dimension(m.dimension),
+          varType(m.varType)
     {}
 
     virtual  ~VMeasurementData();
@@ -115,6 +121,8 @@ public:
 
     IMD dimension{IMD::N};
 
+    MeasurementType varType{MeasurementType::Measurement};
+
 private:
     Q_DISABLE_ASSIGN(VMeasurementData)
 };
