@@ -45,6 +45,7 @@
 #include "../vgeometry/vellipticalarc.h"
 #include "../vmisc/diagnostic.h"
 #include "../vmisc/vabstractapplication.h"
+#include "../vmisc/literals.h"
 #include "variables/varcradius.h"
 #include "variables/vcurveangle.h"
 #include "variables/vcurvelength.h"
@@ -193,7 +194,7 @@ const QSharedPointer<VGObject> VContainer::GetGObject(quint32 id) const
 //---------------------------------------------------------------------------------------------------------------------
 const QSharedPointer<VGObject> VContainer::GetFakeGObject(quint32 id)
 {
-    VGObject *obj = new VGObject();
+    auto *obj = new VGObject();
     obj->setId(id);
     QSharedPointer<VGObject> pointer(obj);
     return pointer;
@@ -393,7 +394,7 @@ void VContainer::ClearForFullParse()
 
     d->pieces->clear();
     d->piecePaths->clear();
-    Q_STATIC_ASSERT_X(static_cast<int>(VarType::Unknown) == 9, "Check that you used all types");
+    Q_STATIC_ASSERT_X(static_cast<int>(VarType::Unknown) == 10, "Check that you used all types");
     ClearVariables(QVector<VarType>({VarType::Increment,
                                      VarType::IncrementSeparator,
                                      VarType::LineAngle,
@@ -578,6 +579,22 @@ const QMap<QString, QSharedPointer<VMeasurement> > VContainer::DataMeasurements(
     return DataVar<VMeasurement>(VarType::Measurement);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+const QMap<QString, QSharedPointer<VMeasurement> > VContainer::DataMeasurementsWithSeparators() const
+{
+    QMap<QString, QSharedPointer<VMeasurement> > measurements = DataVar<VMeasurement>(VarType::Measurement);
+    QMap<QString, QSharedPointer<VMeasurement> > separators = DataVar<VMeasurement>(VarType::MeasurementSeparator);
+
+    QMap<QString, QSharedPointer<VMeasurement>>::const_iterator i = separators.constBegin();
+    while (i != separators.constEnd())
+    {
+        measurements.insert(i.key(), i.value());
+        ++i;
+    }
+
+    return measurements;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 const QMap<QString, QSharedPointer<VIncrement> > VContainer::DataIncrements() const
 {
