@@ -37,7 +37,7 @@
 #include "../vmisc/vabstractvalapplication.h"
 #include "../vmisc/compatibility.h"
 #include "../ifc/exception/vexceptioninvalidnotch.h"
-#include "../vlayout/testpath.h"
+#include "../vmisc/testpath.h"
 #include "../ifc/xml/vabstractpattern.h"
 
 #include <QSharedPointer>
@@ -173,7 +173,7 @@ void VPiece::SetPath(const VPiecePath &path)
 //---------------------------------------------------------------------------------------------------------------------
 QVector<QPointF> VPiece::MainPathPoints(const VContainer *data) const
 {
-//    DumpPiece(*this, data);  // Uncomment for dumping test data
+//    DumpPiece(*this, data, QStringLiteral("input.json.XXXXXX"));  // Uncomment for dumping test data
 
     VPiecePath mainPath = GetPath();
     mainPath.SetName(tr("Main path of piece %1").arg(GetName()));
@@ -181,7 +181,7 @@ QVector<QPointF> VPiece::MainPathPoints(const VContainer *data) const
     QVector<QPointF> points = mainPath.PathPoints(data);
     points = CheckLoops(CorrectEquidistantPoints(points));//A path can contains loops
 
-//    DumpVector(points); // Uncomment for dumping test data
+//    DumpVector(points, QStringLiteral("output.json.XXXXXX")); // Uncomment for dumping test data
     return points;
 }
 
@@ -748,6 +748,18 @@ QVector<QPointF> VPiece::SeamAllowancePointsWithRotation(const VContainer *data,
     return Equidistant(pointsEkv, width, GetName());
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPiece::SetGradationLabel(const QString &label)
+{
+    d->m_gradationLabel = label;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+QString VPiece::GetGradationLabel() const
+{
+    return d->m_gradationLabel;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 QVector<VPieceNode> VPiece::GetUnitedPath(const VContainer *data) const
 {
@@ -921,7 +933,7 @@ bool VPiece::GetPassmarkSAPoint(const QVector<VPieceNode> &path, int index, cons
         return false;
     }
 
-    point = points.first();
+    point = ConstFirst(points);
     return true;
 }
 
@@ -1187,7 +1199,7 @@ auto VPiece::GlobalPassmarkLength(const VContainer *data) const -> qreal
         QSharedPointer<VInternalVariable> var = data->GetVariable<VInternalVariable>(passmarkLengthVariable);
         length = *var->GetValue();
 
-        if (length <= accuracyPointOnLine)
+        if (VAbstractValApplication::VApp()->toPixel(length) <= accuracyPointOnLine)
         {
             const QString errorMsg = QObject::tr("Invalid global value for a passmark length. Piece '%1'. Length is "
                                                  "less than minimal allowed.")
@@ -1206,11 +1218,17 @@ auto VPiece::GlobalPassmarkLength(const VContainer *data) const -> qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPiece::DumpPiece(const VPiece &piece, const VContainer *data)
+void VPiece::DumpPiece(const VPiece &piece, const VContainer *data, const QString &templateName)
 {
     SCASSERT(data != nullptr)
     QTemporaryFile temp; // Go to tmp folder to find dump
     temp.setAutoRemove(false); // Remove dump manually
+
+    if (not templateName.isEmpty())
+    {
+        temp.setFileTemplate(QDir::tempPath() + QDir::separator() + templateName);
+    }
+
     if (temp.open())
     {
 #if defined(Q_OS_LINUX)
