@@ -134,7 +134,10 @@ public:
 
     QVector<QPointF> SeamAllowancePointsWithRotation(const VContainer *data, int makeFirst) const;
 
-    static void DumpPiece(const VPiece &piece, const VContainer *data);
+    void SetGradationLabel(const QString &label);
+    auto GetGradationLabel() const -> QString;
+
+    static void DumpPiece(const VPiece &piece, const VContainer *data, const QString &templateName=QString());
 private:
     QSharedDataPointer<VPieceData> d;
 
