@@ -73,7 +73,8 @@ public:
           m_ppData(detail.m_ppData),
           m_piPatternInfo(detail.m_piPatternInfo),
           m_glGrainline(detail.m_glGrainline),
-          m_formulaWidth(detail.m_formulaWidth)
+          m_formulaWidth(detail.m_formulaWidth),
+          m_gradationLabel(detail.m_gradationLabel)
     {}
 
     ~VPieceData();
@@ -100,6 +101,8 @@ public:
 
     QString m_formulaWidth;
 
+    QString m_gradationLabel{};
+
 private:
     Q_DISABLE_ASSIGN(VPieceData)
 };
