@@ -64,14 +64,38 @@ namespace
 const int dialogMaxFormulaHeight = 80;
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data)
+auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data,
+                 QString &error) -> bool
 {
     if (firstNode.GetTypeTool() == Tool::NodePoint && not (firstNode.GetId() == NULL_ID)
             && secondNode.GetTypeTool() == Tool::NodePoint && not (secondNode.GetId() == NULL_ID))
     {
+        QSharedPointer<VPointF> firstPoint;
+        QSharedPointer<VPointF> secondPoint;
+
+        try
+        {
+            firstPoint = data->GeometricObject<VPointF>(firstNode.GetId());
+            secondPoint = data->GeometricObject<VPointF>(secondNode.GetId());
+        }
+        catch(const VExceptionBadId &)
+        {
+            return false;
+        }
+
         // don't ignore the same point twice
         if (firstNode.GetId() == secondNode.GetId())
         {
+            error = QObject::tr("Point '%1' repeats twice").arg(firstPoint->name());
+            return true;
+        }
+
+        // The same point, but different modeling objects
+        if (firstPoint->getIdObject() != NULL_ID && secondPoint->getIdObject() != NULL_ID &&
+                firstPoint->getMode() == Draw::Modeling && secondPoint->getMode() == Draw::Modeling &&
+                firstPoint->getIdObject() == secondPoint->getIdObject())
+        {
+            error = QObject::tr("Point '%1' repeats twice").arg(firstPoint->name());
             return true;
         }
 
@@ -81,31 +105,51 @@ bool DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
             return false;
         }
 
-        try
+        bool sameCoordinates = VFuzzyComparePoints(firstPoint->toQPointF(), secondPoint->toQPointF());
+        if (sameCoordinates)
         {
-            const QSharedPointer<VPointF> firstPoint = data->GeometricObject<VPointF>(firstNode.GetId());
-            const QSharedPointer<VPointF> secondPoint = data->GeometricObject<VPointF>(secondNode.GetId());
+            error = QObject::tr("Points '%1' and '%2' have the same coordinates.")
+                    .arg(firstPoint->name(), secondPoint->name());
+        }
 
-            return firstPoint->toQPointF() == secondPoint->toQPointF();
-        }
-        catch(const VExceptionBadId &)
-        {
-            return true;
-        }
+        return sameCoordinates;
     }
 
     return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode)
+auto DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data,
+                 QString &error) -> bool
 {
     if (firstNode.GetTypeTool() != Tool::NodePoint && not (firstNode.GetId() == NULL_ID)
             && secondNode.GetTypeTool() != Tool::NodePoint && not (secondNode.GetId() == NULL_ID))
     {
+        QSharedPointer<VGObject> curve1;
+        QSharedPointer<VGObject> curve2;
+
+        try
+        {
+            curve1 = data->GetGObject(firstNode.GetId());
+            curve2 = data->GetGObject(secondNode.GetId());
+        }
+        catch (const VExceptionBadId &)
+        {
+            return false;
+        }
+
         // don't ignore the same curve twice
         if (firstNode.GetId() == secondNode.GetId())
         {
+            error = QObject::tr("Leave only one copy of curve '%1'").arg(curve1->name());
+            return true;
+        }
+
+        // The same curve, but different modeling objects
+        if (curve1->getIdObject() != NULL_ID && curve2->getIdObject() != NULL_ID &&
+                curve1->getIdObject() == curve2->getIdObject())
+        {
+            error = QObject::tr("Leave only one copy of curve '%1'").arg(curve1->name());
             return true;
         }
     }
@@ -396,7 +440,7 @@ int FindNotExcludedNodeUp(QListWidget *listWidget, int candidate)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool FirstPointEqualLast(QListWidget *listWidget, const VContainer *data)
+bool FirstPointEqualLast(QListWidget *listWidget, const VContainer *data, QString &error)
 {
     SCASSERT(listWidget != nullptr);
     if (listWidget->count() > 1)
@@ -404,13 +448,13 @@ bool FirstPointEqualLast(QListWidget *listWidget, const VContainer *data)
         const VPieceNode topNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, 0));
         const VPieceNode bottomNode = RowNode(listWidget, FindNotExcludedNodeUp(listWidget, listWidget->count()-1));
 
-        return DoublePoint(topNode, bottomNode, data);
+        return DoublePoint(topNode, bottomNode, data, error);
     }
     return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DoublePoints(QListWidget *listWidget, const VContainer *data)
+bool DoublePoints(QListWidget *listWidget, const VContainer *data, QString &error)
 {
     SCASSERT(listWidget != nullptr);
     for (int i=0, sz = listWidget->count()-1; i<sz; ++i)
@@ -419,7 +463,7 @@ bool DoublePoints(QListWidget *listWidget, const VContainer *data)
         const VPieceNode firstNode = RowNode(listWidget, firstIndex);
         const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex+1));
 
-        if (DoublePoint(firstNode, secondNode, data))
+        if (DoublePoint(firstNode, secondNode, data, error))
         {
             return true;
         }
@@ -428,7 +472,7 @@ bool DoublePoints(QListWidget *listWidget, const VContainer *data)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DoubleCurves(QListWidget *listWidget)
+auto DoubleCurves(QListWidget *listWidget, const VContainer *data, QString &error) -> bool
 {
     SCASSERT(listWidget != nullptr);
     for (int i=0, sz = listWidget->count()-1; i<sz; ++i)
@@ -437,7 +481,7 @@ bool DoubleCurves(QListWidget *listWidget)
         const VPieceNode firstNode = RowNode(listWidget, firstIndex);
         const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex+1));
 
-        if (DoubleCurve(firstNode, secondNode))
+        if (DoubleCurve(firstNode, secondNode, data, error))
         {
             return true;
         }
@@ -446,7 +490,7 @@ bool DoubleCurves(QListWidget *listWidget)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool EachPointLabelIsUnique(QListWidget *listWidget)
+auto EachPointLabelIsUnique(QListWidget *listWidget) -> bool
 {
     SCASSERT(listWidget != nullptr);
     QSet<quint32> pointLabels;
@@ -455,8 +499,8 @@ bool EachPointLabelIsUnique(QListWidget *listWidget)
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
         SCASSERT(rowItem != nullptr);
-        const VPieceNode rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
-        if (rowNode.GetTypeTool() == Tool::NodePoint)
+        const auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+        if (rowNode.GetTypeTool() == Tool::NodePoint && not rowNode.IsExcluded())
         {
             ++countPoints;
             pointLabels.insert(rowNode.GetId());
@@ -523,11 +567,7 @@ void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar)
 #else
     // compute the size of a char in double-precision
     static constexpr int bigNumber = 1000; // arbitrary big number.
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
-    const int many_char_width = fontMetrics.horizontalAdvance(testString.repeated(bigNumber));
-#else
-    const int many_char_width = fontMetrics.width(testString.repeated(bigNumber));
-#endif
+    const int many_char_width = TextWidth(fontMetrics, testString.repeated(bigNumber));
     const double singleCharWidthDouble = many_char_width / double(bigNumber);
     // set the tab stop with double precision
     edit->setTabStopDistance(tabWidthChar * singleCharWidthDouble);
@@ -576,3 +616,217 @@ auto SegmentAliases(GOType curveType, const QString &alias1, const QString &alia
     return {};
 }
 QT_WARNING_POP
+
+//---------------------------------------------------------------------------------------------------------------------
+QString GetNodeName(const VContainer *data, const VPieceNode &node, bool showPassmarkDetails)
+{
+    const QSharedPointer<VGObject> obj = data->GetGObject(node.GetId());
+    QString name = obj->ObjectName();
+
+    if (node.GetTypeTool() != Tool::NodePoint)
+    {
+        if (node.GetReverse())
+        {
+            name = QStringLiteral("- ") + name;
+        }
+    }
+    else
+    {
+        if (showPassmarkDetails && node.IsPassmark())
+        {
+            switch(node.GetPassmarkLineType())
+            {
+                case PassmarkLineType::OneLine:
+                    name += QLatin1Char('|');
+                    break;
+                case PassmarkLineType::TwoLines:
+                    name += QLatin1String("||");
+                    break;
+                case PassmarkLineType::ThreeLines:
+                    name += QLatin1String("|||");
+                    break;
+                case PassmarkLineType::TMark:
+                    name += QStringLiteral("┴");
+                    break;
+                case PassmarkLineType::VMark:
+                    name += QStringLiteral("⊼");
+                    break;
+                case PassmarkLineType::VMark2:
+                    name += QStringLiteral("⊽");
+                    break;
+                case PassmarkLineType::UMark:
+                    name += QStringLiteral("⋃");
+                    break;
+                case PassmarkLineType::BoxMark:
+                    name += QStringLiteral("⎕");
+                    break;
+                default:
+                    break;
+            }
+        }
+
+        if (not node.IsCheckUniqueness())
+        {
+            name = QLatin1Char('[') + name + QLatin1Char(']');
+        }
+    }
+
+    return name;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto FindNotExcludedPointDown(QListWidget *listWidget, int start) -> int
+{
+    SCASSERT(listWidget != nullptr);
+
+    int index = -1;
+    if (start < 0 || start >= listWidget->count())
+    {
+        return index;
+    }
+
+    int i = start;
+    int count = 0;
+    do
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr);
+        auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (not rowNode.IsExcluded() && rowNode.GetTypeTool() == Tool::NodePoint && rowNode.GetId() != NULL_ID)
+        {
+            index = i;
+            break;
+        }
+
+        ++i;
+        if (i >= listWidget->count())
+        {
+            i = 0;
+        }
+
+        ++count;
+    }
+    while (count < listWidget->count());
+
+    return index;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto FindNotExcludedCurveDown(QListWidget *listWidget, int start) -> int
+{
+    SCASSERT(listWidget != nullptr);
+
+    int index = -1;
+    if (start < 0 || start >= listWidget->count())
+    {
+        return index;
+    }
+
+    int i = start;
+    int count = 0;
+    do
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr);
+        auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (not rowNode.IsExcluded() && rowNode.GetTypeTool() != Tool::NodePoint && rowNode.GetId() != NULL_ID)
+        {
+            index = i;
+            break;
+        }
+
+        ++i;
+        if (i >= listWidget->count())
+        {
+            i = 0;
+        }
+
+        ++count;
+    }
+    while (count < listWidget->count());
+
+    return index;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto InvalidSegment(QListWidget *listWidget, const VContainer *data, QString &error) -> bool
+{
+    SCASSERT(listWidget != nullptr);
+
+    for (int index=0; index < listWidget->count(); ++index)
+    {
+        int firstCurveIndex = -1;
+        int pointIndex = -1;
+        int secondCurveIndex = -1;
+
+        auto FindPair = [listWidget, &firstCurveIndex, &pointIndex, &secondCurveIndex]( int start)
+        {
+            for (int i=start; i < listWidget->count(); ++i)
+            {
+                firstCurveIndex = FindNotExcludedCurveDown(listWidget, i);
+                if (firstCurveIndex == -1)
+                {
+                    continue;
+                }
+
+                pointIndex = FindNotExcludedPointDown(listWidget, firstCurveIndex+1);
+                if (pointIndex == -1)
+                {
+                    continue;
+                }
+
+                secondCurveIndex = FindNotExcludedCurveDown(listWidget, pointIndex+1);
+                if (secondCurveIndex == -1 || firstCurveIndex == secondCurveIndex)
+                {
+                    continue;
+                }
+
+                return true;
+            }
+
+            return false;
+        };
+
+        if (not FindPair(index))
+        {
+            continue;
+        }
+
+        const VPieceNode firstCurveNode = RowNode(listWidget, firstCurveIndex);
+        const VPieceNode secondCurveNode = RowNode(listWidget, secondCurveIndex);
+
+        QString errorDoubleCurve;
+        if (not DoubleCurve(firstCurveNode, secondCurveNode, data, errorDoubleCurve))
+        {
+            continue;
+        }
+
+        const VPieceNode pointNode = RowNode(listWidget, pointIndex);
+        if (pointNode.GetId() == NULL_ID)
+        {
+            continue;
+        }
+
+        try
+        {
+            const QSharedPointer<VAbstractCurve> curve1 = data->GeometricObject<VAbstractCurve>(firstCurveNode.GetId());
+            const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(pointNode.GetId());
+
+            error = QObject::tr("Point '%1' does not lie on a curve '%2'").arg(point->name(), curve1->name());
+
+            bool validSegment = curve1->IsPointOnCurve(point->toQPointF());
+            if (not validSegment)
+            {
+                return true;
+            }
+        }
+        catch (const VExceptionBadId &)
+        {
+            continue;
+        }
+    }
+
+    return false;
+}
