@@ -296,7 +296,10 @@ void DialogArcWithLength::ChosenObject(quint32 id, const SceneObject &type)
         {
             if (SetObject(id, ui->comboBoxCenter, QString()))
             {
-                vis->VisualMode(id);
+                if (vis != nullptr)
+                {
+                    vis->VisualMode(id);
+                }
                 prepare = true;
                 this->setModal(true);
                 this->show();
