@@ -170,7 +170,10 @@ void DialogCutArc::ChosenObject(quint32 id, const SceneObject &type)
         {
             if (SetObject(id, ui->comboBoxArc, QString()))
             {
-                vis->VisualMode(id);
+                if (vis != nullptr)
+                {
+                    vis->VisualMode(id);
+                }
                 prepare = true;
                 this->setModal(true);
                 this->show();
