@@ -178,7 +178,10 @@ void DialogCutSplinePath::ChosenObject(quint32 id, const SceneObject &type)
         {
             if (SetObject(id, ui->comboBoxSplinePath, QString()))
             {
-                vis->VisualMode(id);
+                if (vis != nullptr)
+                {
+                    vis->VisualMode(id);
+                }
                 prepare = true;
                 this->setModal(true);
                 this->show();
