@@ -202,7 +202,7 @@ void DialogSpline::ChosenObject(quint32 id, const SceneObject &type)
                         {
                             ++number;
 
-                            path->setObject4Id(id);
+                            path->SetObject4Id(id);
                             path->RefreshGeometry();
                             prepare = true;
                         }
@@ -228,7 +228,7 @@ void DialogSpline::SaveData()
     SCASSERT(path != nullptr)
 
     path->setObject1Id(GetP1()->id());
-    path->setObject4Id(GetP4()->id());
+    path->SetObject4Id(GetP4()->id());
     path->SetAngle1(spl.GetStartAngle());
     path->SetAngle2(spl.GetEndAngle());
     path->SetKAsm1(spl.GetKasm1());
@@ -636,7 +636,7 @@ void DialogSpline::SetSpline(const VSpline &spline)
     SCASSERT(path != nullptr)
 
     path->setObject1Id(spl.GetP1().id());
-    path->setObject4Id(spl.GetP4().id());
+    path->SetObject4Id(spl.GetP4().id());
     path->SetAngle1(spl.GetStartAngle());
     path->SetAngle2(spl.GetEndAngle());
     path->SetKAsm1(spl.GetKasm1());
