@@ -391,63 +391,6 @@ quint32 DialogTool::DNumber(const QString &baseName) const
     return num;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-QString DialogTool::GetNodeName(const VPieceNode &node, bool showPassmarkDetails) const
-{
-    const QSharedPointer<VGObject> obj = data->GetGObject(node.GetId());
-    QString name = obj->ObjectName();
-
-    if (node.GetTypeTool() != Tool::NodePoint)
-    {
-        if (node.GetReverse())
-        {
-            name = QStringLiteral("- ") + name;
-        }
-    }
-    else
-    {
-        if (showPassmarkDetails && node.IsPassmark())
-        {
-            switch(node.GetPassmarkLineType())
-            {
-                case PassmarkLineType::OneLine:
-                    name += QLatin1Char('|');
-                    break;
-                case PassmarkLineType::TwoLines:
-                    name += QLatin1String("||");
-                    break;
-                case PassmarkLineType::ThreeLines:
-                    name += QLatin1String("|||");
-                    break;
-                case PassmarkLineType::TMark:
-                    name += QStringLiteral("┴");
-                    break;
-                case PassmarkLineType::VMark:
-                    name += QStringLiteral("⊼");
-                    break;
-                case PassmarkLineType::VMark2:
-                    name += QStringLiteral("⊽");
-                    break;
-                case PassmarkLineType::UMark:
-                    name += QStringLiteral("⋃");
-                    break;
-                case PassmarkLineType::BoxMark:
-                    name += QStringLiteral("⎕");
-                    break;
-                default:
-                    break;
-            }
-        }
-
-        if (not node.IsCheckUniqueness())
-        {
-            name = QLatin1Char('[') + name + QLatin1Char(']');
-        }
-    }
-
-    return name;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void DialogTool::NewNodeItem(QListWidget *listWidget, const VPieceNode &node, bool showPassmark, bool showExclusion)
 {
@@ -461,7 +404,7 @@ void DialogTool::NewNodeItem(QListWidget *listWidget, const VPieceNode &node, bo
         case (Tool::NodeElArc):
         case (Tool::NodeSpline):
         case (Tool::NodeSplinePath):
-            name = GetNodeName(node, showPassmark);
+            name = GetNodeName(data, node, showPassmark);
             break;
         default:
             qDebug()<<"Got wrong tools. Ignore.";
