@@ -368,7 +368,7 @@ void DialogPiecePath::ShowContextMenu(const QPoint &pos)
     {
         rowNode.SetReverse(not rowNode.GetReverse());
         rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-        rowItem->setText(GetNodeName(rowNode, IsShowNotch()));
+        rowItem->setText(GetNodeName(data, rowNode, IsShowNotch()));
     }
     else if (m_showMode && rowNode.GetTypeTool() == Tool::NodePoint && selectedAction == actionPassmark
              && GetType() == PiecePathType::CustomSeamAllowance
@@ -376,20 +376,20 @@ void DialogPiecePath::ShowContextMenu(const QPoint &pos)
     {
         rowNode.SetPassmark(not rowNode.IsPassmark());
         rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-        rowItem->setText(GetNodeName(rowNode, IsShowNotch()));
+        rowItem->setText(GetNodeName(data, rowNode, IsShowNotch()));
     }
     else if (selectedAction == actionExcluded)
     {
         rowNode.SetExcluded(not rowNode.IsExcluded());
         rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-        rowItem->setText(GetNodeName(rowNode, true));
+        rowItem->setText(GetNodeName(data, rowNode, true));
         rowItem->setFont(NodeFont(rowItem->font(), rowNode.IsExcluded()));
     }
     else if (rowNode.GetTypeTool() == Tool::NodePoint && selectedAction == actionUniqueness)
     {
         rowNode.SetCheckUniqueness(not rowNode.IsCheckUniqueness());
         rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-        rowItem->setText(GetNodeName(rowNode, IsShowNotch()));
+        rowItem->setText(GetNodeName(data, rowNode, IsShowNotch()));
     }
 
     ValidObjects(PathIsValid());
@@ -714,7 +714,7 @@ void DialogPiecePath::PassmarkLineTypeChanged(int id)
 
             rowNode.SetPassmarkLineType(lineType);
             rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-            rowItem->setText(GetNodeName(rowNode, IsShowNotch()));
+            rowItem->setText(GetNodeName(data, rowNode, IsShowNotch()));
 
             ListChanged();
         }
@@ -768,7 +768,7 @@ void DialogPiecePath::PassmarkAngleTypeChanged(int id)
 
             rowNode.SetPassmarkAngleType(angleType);
             rowItem->setData(Qt::UserRole, QVariant::fromValue(rowNode));
-            rowItem->setText(GetNodeName(rowNode, IsShowNotch()));
+            rowItem->setText(GetNodeName(data, rowNode, IsShowNotch()));
 
             ListChanged();
         }
@@ -1079,10 +1079,31 @@ void DialogPiecePath::InitPathTab()
     connect(ui->listWidget->model(), &QAbstractItemModel::rowsMoved, this, &DialogPiecePath::ListChanged);
     connect(ui->listWidget, &QListWidget::itemSelectionChanged, this, &DialogPiecePath::SetMoveControls);
 
-    connect(ui->toolButtonTop, &QToolButton::clicked, this, [this](){MoveListRowTop(ui->listWidget);});
-    connect(ui->toolButtonUp, &QToolButton::clicked, this, [this](){MoveListRowUp(ui->listWidget);});
-    connect(ui->toolButtonDown, &QToolButton::clicked, this, [this](){MoveListRowDown(ui->listWidget);});
-    connect(ui->toolButtonBottom, &QToolButton::clicked, this, [this](){MoveListRowBottom(ui->listWidget);});
+    connect(ui->listWidget->model(), &QAbstractItemModel::rowsMoved, this, [this]()
+    {
+        ValidObjects(PathIsValid());
+    });
+
+    connect(ui->toolButtonTop, &QToolButton::clicked, this, [this]()
+    {
+        MoveListRowTop(ui->listWidget);
+        ValidObjects(PathIsValid());
+    });
+    connect(ui->toolButtonUp, &QToolButton::clicked, this, [this]()
+    {
+        MoveListRowUp(ui->listWidget);
+        ValidObjects(PathIsValid());
+    });
+    connect(ui->toolButtonDown, &QToolButton::clicked, this, [this]()
+    {
+        MoveListRowDown(ui->listWidget);
+        ValidObjects(PathIsValid());
+    });
+    connect(ui->toolButtonBottom, &QToolButton::clicked, this, [this]()
+    {
+        MoveListRowBottom(ui->listWidget);
+        ValidObjects(PathIsValid());
+    });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1226,7 +1247,7 @@ void DialogPiecePath::InitNodesList()
         const VPieceNode node = path.at(i);
         if (node.GetTypeTool() == Tool::NodePoint)
         {
-            const QString name = GetNodeName(node);
+            const QString name = GetNodeName(data, node);
 
             ui->comboBoxNodes->addItem(name, node.GetId());
         }
@@ -1259,7 +1280,7 @@ void DialogPiecePath::InitPassmarksList()
     {
         if (node.GetTypeTool() == Tool::NodePoint && node.IsPassmark())
         {
-            const QString name = GetNodeName(node);
+            const QString name = GetNodeName(data, node);
 
             ui->comboBoxPassmarks->addItem(name, node.GetId());
         }
@@ -1602,54 +1623,61 @@ VPiecePath DialogPiecePath::CreatePath() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogPiecePath::PathIsValid() const
+auto DialogPiecePath::PathIsValid() const -> bool
 {
-    QString url = DialogWarningIcon();
-
     if(CreatePath().PathPoints(data).count() < 2)
     {
-        url += tr("You need more points!");
-        ui->helpLabel->setText(url);
+        ui->helpLabel->setText(DialogWarningIcon() + tr("You need more points!"));
         return false;
     }
-    else
+
+    QString error;
+    if (GetType() == PiecePathType::CustomSeamAllowance && FirstPointEqualLast(ui->listWidget, data, error))
     {
-        if (GetType() == PiecePathType::CustomSeamAllowance && FirstPointEqualLast(ui->listWidget, data))
-        {
-            url += tr("First point of <b>custom seam allowance</b> cannot be equal to the last point!");
-            ui->helpLabel->setText(url);
-            return false;
-        }
-        else if (DoublePoints(ui->listWidget, data))
-        {
-            url += tr("You have double points!");
-            ui->helpLabel->setText(url);
-            return false;
-        }
-        else if (DoubleCurves(ui->listWidget))
-        {
-            url += tr("The same curve repeats twice!");
-            ui->helpLabel->setText(url);
-            return false;
-        }
-        else if (GetType() == PiecePathType::CustomSeamAllowance && not EachPointLabelIsUnique(ui->listWidget))
-        {
-            url += tr("Each point in the <b>custom seam allowance</b> path must be unique!");
-            ui->helpLabel->setText(url);
-            return false;
-        }
+        ui->helpLabel->setText(
+                    QString("%1%2 %3")
+                    .arg(DialogWarningIcon(),
+                         tr("First point of <b>custom seam allowance</b> cannot be equal to the last point!"), error));
+        return false;
+    }
+
+    error.clear();
+    if (DoublePoints(ui->listWidget, data, error))
+    {
+        ui->helpLabel->setText(QString("%1%2 %3").arg(DialogWarningIcon(), tr("You have double points!"), error));
+        return false;
+    }
+
+    error.clear();
+    if (DoubleCurves(ui->listWidget, data, error))
+    {
+        ui->helpLabel->setText(QString("%1%2 %3").arg(DialogWarningIcon(), tr("The same curve repeats twice!"), error));
+        return false;
+    }
+
+    if (GetType() == PiecePathType::CustomSeamAllowance && not EachPointLabelIsUnique(ui->listWidget))
+    {
+        ui->helpLabel->setText(DialogWarningIcon() +
+                               tr("Each point in the <b>custom seam allowance</b> path must be unique!"));
+        return false;
     }
 
     if (not m_showMode && ui->comboBoxPiece->count() <= 0)
     {
-        url += tr("List of details is empty!");
-        ui->helpLabel->setText(url);
+        ui->helpLabel->setText(DialogWarningIcon() + tr("List of details is empty!"));
         return false;
     }
-    else if (not m_showMode && ui->comboBoxPiece->currentIndex() == -1)
+
+    if (not m_showMode && ui->comboBoxPiece->currentIndex() == -1)
     {
-        url += tr("Please, select a detail to insert into!");
-        ui->helpLabel->setText(url);
+        ui->helpLabel->setText(DialogWarningIcon() + tr("Please, select a detail to insert into!"));
+        return false;
+    }
+
+    error.clear();
+    if (InvalidSegment(ui->listWidget, data, error))
+    {
+        ui->helpLabel->setText(QString("%1%2 %3").arg(DialogWarningIcon(), tr("Invalid segment!"), error));
         return false;
     }
 
