@@ -255,7 +255,10 @@ void DialogPlaceLabel::ChosenObject(quint32 id, const SceneObject &type)
         {
             if (SetObject(id, ui->comboBoxPoint, QString()))
             {
-                vis->VisualMode(id);
+                if (vis != nullptr)
+                {
+                    vis->VisualMode(id);
+                }
                 CheckPoint();
                 prepare = true;
 
