@@ -30,15 +30,11 @@
 
 #include <QBrush>
 #include <QDialog>
-#include <QDialogButtonBox>
 #include <QFlags>
 #include <QGraphicsEllipseItem>
 #include <QGraphicsLineItem>
 #include <QHash>
-#include <QIcon>
 #include <QLineF>
-#include <QMessageBox>
-#include <QPainter>
 #include <QPen>
 #include <QPixmap>
 #include <QPoint>
@@ -48,14 +44,13 @@
 #include <QStaticStringData>
 #include <QStringData>
 #include <QStringDataPtr>
-#include <QStyle>
 #include <QUndoStack>
 #include <QVector>
 #include <new>
 #include <qnumeric.h>
+#include <QMessageBox>
 
 #include "../vgeometry/vpointf.h"
-#include "../vpropertyexplorer/checkablemessagebox.h"
 #include "../vwidgets/vmaingraphicsview.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionundo.h"
@@ -77,6 +72,7 @@
 #include "nodeDetails/nodedetails.h"
 #include "../dialogs/support/dialogundo.h"
 #include "../dialogs/support/dialogeditwrongformula.h"
+#include "toolsdef.h"
 
 template <class T> class QSharedPointer;
 
@@ -246,31 +242,6 @@ void VAbstractTool::PerformDelete()
     VAbstractApplication::VApp()->getUndoStack()->push(delTool);
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-int VAbstractTool::ConfirmDeletion()
-{
-    if (false == VAbstractApplication::VApp()->Settings()->GetConfirmItemDelete())
-    {
-        return QMessageBox::Yes;
-    }
-
-    Utils::CheckableMessageBox msgBox(VAbstractValApplication::VApp()->getMainWindow());
-    msgBox.setWindowTitle(tr("Confirm deletion"));
-    msgBox.setText(tr("Do you really want to delete?"));
-    msgBox.setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
-    msgBox.setDefaultButton(QDialogButtonBox::No);
-    msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32) );
-
-    int dialogResult = msgBox.exec();
-
-    if (dialogResult == QDialog::Accepted)
-    {
-        VAbstractApplication::VApp()->Settings()->SetConfirmItemDelete(not msgBox.isChecked());
-    }
-
-    return dialogResult == QDialog::Accepted ? QMessageBox::Yes : QMessageBox::No;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 const QStringList VAbstractTool::Colors()
 {
@@ -541,9 +512,10 @@ QDomElement VAbstractTool::AddSANode(VAbstractPattern *doc, const QString &tagNa
         }
     }
 
-    doc->SetAttributeOrRemoveIf(nod, VAbstractPattern::AttrNodeExcluded, node.IsExcluded(), not node.IsExcluded());
-    doc->SetAttributeOrRemoveIf(nod, VAbstractPattern::AttrCheckUniqueness, node.IsCheckUniqueness(),
-                                node.IsCheckUniqueness());
+    doc->SetAttributeOrRemoveIf<bool>(nod, VAbstractPattern::AttrNodeExcluded, node.IsExcluded(),
+                                      [](bool exclude) noexcept {return not exclude;});
+    doc->SetAttributeOrRemoveIf<bool>(nod, VAbstractPattern::AttrCheckUniqueness, node.IsCheckUniqueness(),
+                                      [](bool uniqueness) noexcept {return uniqueness;});
 
     switch (type)
     {
@@ -600,13 +572,13 @@ QDomElement VAbstractTool::AddSANode(VAbstractPattern *doc, const QString &tagNa
         nod.removeAttribute(VAbstractPattern::AttrNodePassmarkAngle);
     }
 
-    doc->SetAttributeOrRemoveIf(nod, VAbstractPattern::AttrNodeShowSecondPassmark, node.IsShowSecondPassmark(),
-                                node.IsShowSecondPassmark());
+    doc->SetAttributeOrRemoveIf<bool>(nod, VAbstractPattern::AttrNodeShowSecondPassmark, node.IsShowSecondPassmark(),
+                                      [](bool show) noexcept {return show;});
 
-    doc->SetAttributeOrRemoveIf(nod, VAbstractPattern::AttrManualPassmarkLength, node.IsManualPassmarkLength(),
-                                not node.IsManualPassmarkLength());
-    doc->SetAttributeOrRemoveIf(nod, VAbstractPattern::AttrPassmarkLength, node.GetFormulaPassmarkLength(),
-                                not node.IsManualPassmarkLength());
+    doc->SetAttributeOrRemoveIf<bool>(nod, VAbstractPattern::AttrManualPassmarkLength, node.IsManualPassmarkLength(),
+                                      [](bool manualPassmarkLength) noexcept {return not manualPassmarkLength;});
+    doc->SetAttributeOrRemoveIf<QString>(nod, VAbstractPattern::AttrPassmarkLength, node.GetFormulaPassmarkLength(),
+                                         [node](const QString &) noexcept {return not node.IsManualPassmarkLength();});
 
     return nod;
 }
