@@ -40,6 +40,7 @@
 #include <QStringData>
 #include <QStringDataPtr>
 #include <Qt>
+#include <QGraphicsView>
 
 #include "global.h"
 #include "../vmisc/vabstractapplication.h"
@@ -94,13 +95,17 @@ void VMainGraphicsScene::mousePressEvent(QGraphicsSceneMouseEvent *event)
     if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
         emit MouseLeftPressed();
+
+        QTransform deviceTransform;
+        auto *view = qobject_cast<QGraphicsView *>(event->widget());
+        if (view != nullptr)
+        {
+            deviceTransform = view->transform();
+        }
+        emit ItemByMousePress(itemAt(event->scenePos(), deviceTransform));
     }
 
     QGraphicsScene::mousePressEvent(event);
-
-    QTransform t;
-    QGraphicsItem* pItem = itemAt(event->scenePos(), t);
-    emit ItemClicked(pItem);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -109,10 +114,30 @@ void VMainGraphicsScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
     if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
         emit MouseLeftReleased();
+
+        QTransform deviceTransform;
+        auto *view = qobject_cast<QGraphicsView *>(event->widget());
+        if (view != nullptr)
+        {
+            deviceTransform = view->transform();
+        }
+        emit ItemByMouseRelease(itemAt(event->scenePos(), deviceTransform));
     }
     QGraphicsScene::mouseReleaseEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VMainGraphicsScene::SetAcceptDrop(bool newAcceptDrop)
+{
+    m_acceptDrop = newAcceptDrop;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+bool VMainGraphicsScene::AcceptDrop() const
+{
+    return m_acceptDrop;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 bool VMainGraphicsScene::IsNonInteractive() const
 {
@@ -138,10 +163,10 @@ void VMainGraphicsScene::InitOrigins()
     {
         // X axis
         const QLineF lineX(QPointF(25, 0), QPointF(-5, 0));
-        QGraphicsLineItem *xLine1 = new QGraphicsLineItem(lineX);
+        auto *xLine1 = new QGraphicsLineItem(lineX);
         xLine1->setPen(originsPen);
         xLine1->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        xLine1->setZValue(-1.0);
+        xLine1->setZValue(-0.5);
         addItem(xLine1);
         origins.append(xLine1);
 
@@ -149,10 +174,10 @@ void VMainGraphicsScene::InitOrigins()
         QLineF arrowLeftLine = lineX;
         arrowLeftLine.setAngle(arrowLeftLine.angle()-arrowAngle);
         arrowLeftLine.setLength(arrowLength);
-        QGraphicsLineItem *xLine2 = new QGraphicsLineItem(arrowLeftLine);
+        auto *xLine2 = new QGraphicsLineItem(arrowLeftLine);
         xLine2->setPen(originsPen);
         xLine2->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        xLine2->setZValue(-1.0);
+        xLine2->setZValue(-0.5);
         addItem(xLine2);
         origins.append(xLine2);
 
@@ -160,18 +185,18 @@ void VMainGraphicsScene::InitOrigins()
         QLineF arrowRightLine = lineX;
         arrowRightLine.setAngle(arrowRightLine.angle()+arrowAngle);
         arrowRightLine.setLength(arrowLength);
-        QGraphicsLineItem *xLine3 = new QGraphicsLineItem(arrowRightLine);
+        auto *xLine3 = new QGraphicsLineItem(arrowRightLine);
         xLine3->setPen(originsPen);
         xLine3->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        xLine3->setZValue(-1.0);
+        xLine3->setZValue(-0.5);
         addItem(xLine3);
         origins.append(xLine3);
 
         // X axis text
-        QGraphicsSimpleTextItem *xOrigin = new QGraphicsSimpleTextItem(QStringLiteral("X"), xLine1);
+        auto *xOrigin = new QGraphicsSimpleTextItem(QStringLiteral("X"), xLine1);
         xOrigin->setBrush(axisTextBrush);
         xOrigin->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        xOrigin->setZValue(-1.0);
+        xOrigin->setZValue(-0.5);
         xOrigin->setPos(30, -(xOrigin->boundingRect().height()/2));
         origins.append(xOrigin);
     }
@@ -179,10 +204,10 @@ void VMainGraphicsScene::InitOrigins()
     {
         // Y axis
         const QLineF lineY(QPointF(0, 25), QPointF(0, -5));
-        QGraphicsLineItem *yLine1 = new QGraphicsLineItem(lineY);
+        auto *yLine1 = new QGraphicsLineItem(lineY);
         yLine1->setPen(originsPen);
         yLine1->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        yLine1->setZValue(-1.0);
+        yLine1->setZValue(-0.5);
         addItem(yLine1);
         origins.append(yLine1);
 
@@ -190,10 +215,10 @@ void VMainGraphicsScene::InitOrigins()
         QLineF arrowLeftLine = lineY;
         arrowLeftLine.setAngle(arrowLeftLine.angle()-arrowAngle);
         arrowLeftLine.setLength(arrowLength);
-        QGraphicsLineItem *yLine2 = new QGraphicsLineItem(arrowLeftLine);
+        auto *yLine2 = new QGraphicsLineItem(arrowLeftLine);
         yLine2->setPen(originsPen);
         yLine2->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        yLine2->setZValue(-1.0);
+        yLine2->setZValue(-0.5);
         addItem(yLine2);
         origins.append(yLine2);
 
@@ -201,18 +226,18 @@ void VMainGraphicsScene::InitOrigins()
         QLineF arrowRightLine = lineY;
         arrowRightLine.setAngle(arrowRightLine.angle()+arrowAngle);
         arrowRightLine.setLength(arrowLength);
-        QGraphicsLineItem *yLine3 = new QGraphicsLineItem(arrowRightLine);
+        auto *yLine3 = new QGraphicsLineItem(arrowRightLine);
         yLine3->setPen(originsPen);
         yLine3->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        yLine3->setZValue(-1.0);
+        yLine3->setZValue(-0.5);
         addItem(yLine3);
         origins.append(yLine3);
 
         // Y axis text
-        QGraphicsSimpleTextItem *yOrigin = new QGraphicsSimpleTextItem(QStringLiteral("Y"), yLine1);
+        auto *yOrigin = new QGraphicsSimpleTextItem(QStringLiteral("Y"), yLine1);
         yOrigin->setBrush(axisTextBrush);
         yOrigin->setFlag(QGraphicsItem::ItemIgnoresTransformations);
-        yOrigin->setZValue(-1.0);
+        yOrigin->setZValue(-0.5);
         yOrigin->setPos(-(yOrigin->boundingRect().width()/2), 30);
         origins.append(yOrigin);
     }
