@@ -49,6 +49,8 @@
 #include <QGestureEvent>
 #include <QScreen>
 #include <QOpenGLWidget>
+#include <QMimeData>
+#include <QMimeDatabase>
 
 #include "../vmisc/def.h"
 #include "../vmisc/vmath.h"
@@ -56,9 +58,11 @@
 #include "vsimplecurve.h"
 #include "vcontrolpointspline.h"
 #include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vsettings.h"
+#include "../vmisc/vcommonsettings.h"
+#include "../vmisc/literals.h"
 #include "vabstractmainwindow.h"
 #include "global.h"
+#include "../ifc/xml/utils.h"
 
 const qreal maxSceneSize = ((20.0 * 1000.0) / 25.4) * PrintDPI; // 20 meters in pixels
 
@@ -71,7 +75,7 @@ qreal ScrollingSteps(QWheelEvent* wheel_event)
     const QPoint numPixels = wheel_event->pixelDelta();
     const QPoint numDegrees = wheel_event->angleDelta() / 8;
     qreal numSteps = 0;
-    VSettings *settings = qobject_cast<VSettings *>(VAbstractApplication::VApp()->Settings());
+    VCommonSettings *settings = qobject_cast<VCommonSettings *>(VAbstractApplication::VApp()->Settings());
 
     if (not numPixels.isNull())
     {
@@ -107,7 +111,7 @@ qreal PrepareScrolling(qreal scheduledScrollings, QWheelEvent *wheel_event)
     }
 
     scheduledScrollings *=
-            qobject_cast<VSettings *>(VAbstractApplication::VApp()->Settings())->GetScrollingAcceleration();
+            qobject_cast<VCommonSettings *>(VAbstractApplication::VApp()->Settings())->GetScrollingAcceleration();
 
     return scheduledScrollings;
 }
@@ -199,7 +203,7 @@ void GraphicsViewZoom::set_zoom_factor_base(double value)
 //---------------------------------------------------------------------------------------------------------------------
 void GraphicsViewZoom::InitScrollingAnimation()
 {
-    VSettings *settings = qobject_cast<VSettings *>(VAbstractApplication::VApp()->Settings());
+    VCommonSettings *settings = qobject_cast<VCommonSettings *>(VAbstractApplication::VApp()->Settings());
 
     if (not verticalScrollAnim.isNull())
     {
@@ -430,7 +434,9 @@ VMainGraphicsView::VMainGraphicsView(QWidget *parent)
       m_oldCursor(),
       m_currentCursor(Qt::ArrowCursor)
 {
-    VSettings *settings = qobject_cast<VSettings *>(VAbstractApplication::VApp()->Settings());
+    setAcceptDrops(true);
+
+    VCommonSettings *settings = qobject_cast<VCommonSettings *>(VAbstractApplication::VApp()->Settings());
     if (settings && settings->IsOpenGLRender())
     {
         QOpenGLWidget *viewport = new QOpenGLWidget();
@@ -653,6 +659,67 @@ void VMainGraphicsView::mouseDoubleClickEvent(QMouseEvent *event)
     QGraphicsView::mouseDoubleClickEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
+{
+    const QMimeData *mime = event->mimeData();
+    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+    {
+        QUrl urlPath(mime->text().simplified());
+        if (urlPath.isLocalFile())
+        {
+            const QString fileName = urlPath.toLocalFile();
+            QFileInfo f(fileName);
+            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            {
+                event->acceptProposedAction();
+            }
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
+{
+    const QMimeData *mime = event->mimeData();
+    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+    {
+        QUrl urlPath(mime->text().simplified());
+        if (urlPath.isLocalFile())
+        {
+            const QString fileName = urlPath.toLocalFile();
+            QFileInfo f(fileName);
+            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            {
+                event->acceptProposedAction();
+            }
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VMainGraphicsView::dropEvent(QDropEvent *event)
+{
+    const QMimeData *mime = event->mimeData();
+    auto *currentScene = qobject_cast<VMainGraphicsScene *>(scene());
+    if (currentScene != nullptr && currentScene->AcceptDrop() && mime != nullptr && mime->hasText())
+    {
+        QUrl urlPath(mime->text().simplified());
+        if (urlPath.isLocalFile())
+        {
+            const QString fileName = urlPath.toLocalFile();
+            QFileInfo f(fileName);
+            if (f.exists() && IsMimeTypeImage(QMimeDatabase().mimeTypeForFile(fileName)))
+            {
+                emit currentScene->AddBackgroundImage(mapToScene(event->pos()), fileName);
+                event->acceptProposedAction();
+            }
+        }
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 qreal VMainGraphicsView::MinScale()
 {
@@ -793,7 +860,7 @@ void VMainGraphicsView::NewSceneRect(QGraphicsScene *sc, QGraphicsView *view, QG
     {
         QRectF rect = item->sceneBoundingRect();
         const QList<QGraphicsItem *> children = item->childItems();
-        for (auto child : children)
+        for (auto *child : children)
         {
             if(child->isVisible())
             {
