@@ -943,6 +943,12 @@ void TST_VAbstractPiece::BrokenDetailEquidistant_data()
                      QStringLiteral("://doll/input.json"),
                      QStringLiteral("://doll/output.json"),
                      26.45669291338583 /*seam allowance width 0.7 cm*/);
+
+    // See the file "collection/bugs/smart_pattern_#145.val"
+    ASSERT_TEST_CASE("Issue #145",
+                     QStringLiteral("://smart_pattern_#145/input.json"),
+                     QStringLiteral("://smart_pattern_#145/output.json"),
+                     37.795275590551185 /*seam allowance width*/);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1266,6 +1272,42 @@ void TST_VAbstractPiece::PossibleInfiniteClearLoops() const
     Comparison(res, expect);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VAbstractPiece::IsAllowanceValid_data() const
+{
+    QTest::addColumn<QVector<QPointF>>("base");
+    QTest::addColumn<QVector<QPointF>>("allowance");
+    QTest::addColumn<bool>("valid");
+
+    auto ASSERT_TEST_CASE = [this](const char *title, const QString &base, const QString &allowance, bool valid)
+    {
+        QVector<QPointF> basePoints;
+        AbstractTest::VectorFromJson(base, basePoints);
+
+        QVector<QPointF> allowancePoints;
+        AbstractTest::VectorFromJson(allowance, allowancePoints);
+
+        QTest::newRow(title) << basePoints << allowancePoints << valid ;
+    };
+
+    // See file src/app/share/collection/valid_allowance/case3.val (private collection)
+    ASSERT_TEST_CASE("Valid seam allowance. Case 3",
+                     QStringLiteral("://valid_allowance_case3/base.json"),
+                     QStringLiteral("://valid_allowance_case3/allowance.json"),
+                     true);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void TST_VAbstractPiece::IsAllowanceValid() const
+{
+    QFETCH(QVector<QPointF>, base);
+    QFETCH(QVector<QPointF>, allowance);
+    QFETCH(bool, valid);
+
+    bool result = VAbstractPiece::IsAllowanceValid(base, allowance);
+    QVERIFY(result == valid);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void TST_VAbstractPiece::Case3() const
 {
